@@ -54,7 +54,7 @@ KDevelopSessions::KDevelopSessions(QObject *parent, const QVariantList& args)
     KDirWatch *historyWatch = new KDirWatch(this);
     const QStringList sessiondirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation,
                                                               QStringLiteral("kdevelop/sessions"), QStandardPaths::LocateDirectory);
-    foreach (const QString &dir, sessiondirs) {
+    for (const QString& dir : sessiondirs) {
         historyWatch->addDir(dir);
     }
     connect(historyWatch, &KDirWatch::dirty, this, &KDevelopSessions::loadSessions);
@@ -72,11 +72,11 @@ KDevelopSessions::~KDevelopSessions() = default;
 
 QStringList findSessions()
 {
-    QStringList sessionDirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation,
-                                                        QStringLiteral("kdevelop/sessions"),
-                                                        QStandardPaths::LocateDirectory);
+    const QStringList sessionDirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation,
+                                                              QStringLiteral("kdevelop/sessions"),
+                                                              QStandardPaths::LocateDirectory);
     QStringList sessionrcs;
-    Q_FOREACH(const QString& dir, sessionDirs) {
+    for (const QString& dir : sessionDirs) {
         QDir d(dir);
         Q_FOREACH(const QString& sessionDir, d.entryList(QDir::Dirs)) {
             QDir sd(d.absoluteFilePath(sessionDir));
@@ -95,13 +95,13 @@ void KDevelopSessions::loadSessions()
     // Switch kdevelop session: -u
     // Should we add a match for this option or would that clutter the matches too much?
     const QStringList list = findSessions();
-    foreach (const QString &sessionfile, list)
-    {
+    m_sessions.reserve(list.size());
+    for (const QString& sessionfile : list) {
         Session session;
-        session.id = sessionfile.section('/', -2, -2);
+        session.id = sessionfile.section(QLatin1Char('/'), -2, -2);
         KConfig cfg(sessionfile, KConfig::SimpleConfig);
         KConfigGroup group = cfg.group(QString());
-        session.name = group.readEntry("SessionPrettyContents");;
+        session.name = group.readEntry("SessionPrettyContents");
         m_sessions << session;
     }
     std::sort(m_sessions.begin(), m_sessions.end(), kdevelopsessions_runner_compare_sessions);
