@@ -221,8 +221,8 @@ build_project kdev-python $KDEVELOP_VERSION
 build_project kdev-clang-tidy $KDEV_CLANG_TIDY_VERSION
 
 # Install some colorschemes
-cd $SRC
-$SCRIPT_DIR/install_colorschemes.sh
+cd $BUILD
+$SCRIPT_DIR/../release-scripts/install_colorschemes.py /kdevelop.appdir/usr/share
 
 cd /kdevelop.appdir
 
@@ -292,7 +292,7 @@ rm -f usr/lib/libcom_err.so.2 || true
 rm -f usr/lib/libcrypt.so.1 || true
 rm -f usr/lib/libdl.so.2 || true
 rm -f usr/lib/libexpat.so.1 || true
-#rm -f usr/lib/libfontconfig.so.1 || true
+rm -f usr/lib/libfontconfig.so.1 || true
 rm -f usr/lib/libgcc_s.so.1 || true
 rm -f usr/lib/libglib-2.0.so.0 || true
 rm -f usr/lib/libgpg-error.so.0 || true
@@ -423,21 +423,9 @@ kdevelop \$@
 EOF
 chmod +x AppRun
 
-cat > kdevelop.desktop << EOF
-[Desktop Entry]
-GenericName=Integrated development environment
-Name=KDevelop
-MimeType=text/plain;
-Exec=AppRun -b %U
-StartupNotify=true
-X-KDE-HasTempFileOption=true
-Icon=kdevelop
-X-DocPath=kdevelop/index.html
-Type=Application
-Terminal=false
-InitialPreference=9
-Categories=Qt;KDE;Utility;TextEditor;
-EOF
+# use normal desktop file, but remove actions, not yet handled by appimaged & Co
+cp $SRC/kdevelop/app/org.kde.kdevelop.desktop kdevelop.desktop
+sed -i -e '/^Actions=/d;/^\[Desktop Action /Q' kdevelop.desktop
 
 cp $SRC/kdevelop/app/icons/48-apps-kdevelop.png kdevelop.png
 cp -R /usr/lib/python3.6 /kdevelop.appdir/usr/lib/
