@@ -57,8 +57,8 @@ public:
     int m_subsequentFrameFetchOperations = 0;
     bool m_updateCurrentFrameOnNextFetch = false;
 
-    QList<FrameStackModel::ThreadItem> m_threads;
-    QHash<int, QList<FrameStackModel::FrameItem> > m_frames;
+    QVector<FrameStackModel::ThreadItem> m_threads;
+    QHash<int, QVector<FrameStackModel::FrameItem>> m_frames;
     QHash<int, bool> m_hasMoreFrames;
 
     // Caches
@@ -76,7 +76,7 @@ FrameStackModel::~FrameStackModel()
 {
 }
 
-void FrameStackModel::setThreads(const QList<ThreadItem> &threads)
+void FrameStackModel::setThreads(const QVector<ThreadItem>& threads)
 {
     qCDebug(DEBUGGER) << threads.count();
 
@@ -105,7 +105,7 @@ QModelIndex FrameStackModelPrivate::indexForThreadNumber(int threadNumber)
     return QModelIndex();
 }
 
-void FrameStackModel::setFrames(int threadNumber, const QList<FrameItem>& frames)
+void FrameStackModel::setFrames(int threadNumber, const QVector<FrameItem>& frames)
 {
     QModelIndex threadIndex = d->indexForThreadNumber(threadNumber);
     Q_ASSERT(threadIndex.isValid());
@@ -137,7 +137,7 @@ void FrameStackModel::setFrames(int threadNumber, const QList<FrameItem>& frames
     emit currentFrameChanged(d->m_currentFrame);
 }
 
-void FrameStackModel::insertFrames(int threadNumber, const QList<FrameItem> &frames)
+void FrameStackModel::insertFrames(int threadNumber, const QVector<FrameItem>& frames)
 {
     QModelIndex threadIndex = d->indexForThreadNumber(threadNumber);
     Q_ASSERT(threadIndex.isValid());
@@ -161,7 +161,7 @@ FrameStackModel::FrameItem FrameStackModel::frame(const QModelIndex& index)
     return d->m_frames[thread.nr].at(index.row());
 }
 
-QList<FrameStackModel::FrameItem> FrameStackModel::frames(int threadNumber) const
+QVector<FrameStackModel::FrameItem> FrameStackModel::frames(int threadNumber) const
 {
     return d->m_frames.value(threadNumber);
 }
@@ -205,7 +205,7 @@ QVariant FrameStackModel::data(const QModelIndex& index, int role) const
                 QString ret = ICore::self()->projectController()
                     ->prettyFileName(frame.file, IProjectController::FormatPlain);
                 if (frame.line != -1) {
-                    ret += ':' + QString::number(frame.line + 1);
+                    ret += QLatin1Char(':') + QString::number(frame.line + 1);
                 }
                 return ret;
             } else if (role == Qt::DecorationRole) {
@@ -388,7 +388,7 @@ void FrameStackModel::stateChanged(IDebugSession::DebuggerState state)
         setCurrentFrame(-1);
         d->m_updateCurrentFrameOnNextFetch = true;
     } else if (state == IDebugSession::EndedState || state == IDebugSession::NotStartedState) {
-        setThreads(QList<FrameStackModel::ThreadItem>());
+        setThreads(QVector<FrameStackModel::ThreadItem>());
     }
 }
 
