@@ -78,9 +78,9 @@ Variable::Variable(TreeModel* model, TreeItem* parent,
     // FIXME: should not duplicate the data, instead overload 'data'
     // and return expression_ directly.
     if (display.isEmpty())
-        setData(QVector<QVariant>() << expression << QString() << QString());
+        setData(QVector<QVariant>{expression, QString(), QString()});
     else
-        setData(QVector<QVariant>() << display << QString() << QString());
+        setData(QVector<QVariant>{display, QString(), QString()});
 }
 
 QString Variable::expression() const
@@ -189,8 +189,8 @@ QString Variable::format2str(format_t format)
         case Octal:         return QStringLiteral("octal");
         case Decimal:       return QStringLiteral("decimal");
         case Hexadecimal:   return QStringLiteral("hexadecimal");
-        default:            return QString();
     }
+    return QString();
 }
 
 
@@ -245,7 +245,7 @@ QVariant Variable::data(int column, int role) const
 Watches::Watches(TreeModel* model, TreeItem* parent)
 : TreeItem(model, parent), finishResult_(nullptr)
 {
-    setData(QVector<QVariant>() << i18n("Auto") << QString());
+    setData(QVector<QVariant>{i18n("Auto"), QString()});
 }
 
 Variable* Watches::add(const QString& expression)
@@ -323,10 +323,10 @@ void Watches::reinstall()
 Locals::Locals(TreeModel* model, TreeItem* parent, const QString &name)
 : TreeItem(model, parent)
 {
-    setData(QVector<QVariant>() << name << QString());
+    setData(QVector<QVariant>{name, QString()});
 }
 
-QList<Variable*> Locals::updateLocals(QStringList locals)
+QList<Variable*> Locals::updateLocals(const QStringList& locals)
 {
     QSet<QString> existing, current;
     for (int i = 0; i < childItems.size(); i++)
@@ -370,6 +370,7 @@ QList<Variable*> Locals::updateLocals(QStringList locals)
     // Variables that changed type -- likewise.
 
     QList<Variable*> ret;
+    ret.reserve(childItems.size());
     foreach (TreeItem *i, childItems) {
         Q_ASSERT(qobject_cast<Variable*>(i));
         ret << static_cast<Variable*>(i);
@@ -544,7 +545,7 @@ QString VariableProvider::textHint(KTextEditor::View* view, const KTextEditor::C
         w = view;
 
     m_collection->m_activeTooltip = new VariableToolTip(w, global+QPoint(30,30), expression);
-    m_collection->m_activeTooltip->setHandleRect(KTextEditorHelpers::getItemBoundingRect(view, expressionRange));
+    m_collection->m_activeTooltip->setHandleRect(KTextEditorHelpers::itemBoundingRect(view, expressionRange));
     return QString();
 }
 
