@@ -36,8 +36,6 @@
 #include <KSharedConfig>
 #include <KLocalizedString>
 
-#include <ktexteditor/document.h>
-
 #include <ThreadWeaver/State>
 #include <ThreadWeaver/ThreadWeaver>
 #include <ThreadWeaver/DebuggingAids>
@@ -130,7 +128,7 @@ inline uint qHash(const DocumentParseTarget& target)
 {
     return target.features * 7 + target.priority * 13 + target.sequentialProcessingFlags * 17
                                + reinterpret_cast<size_t>(target.notifyWhenReady.data());
-};
+}
 
 struct DocumentParsePlan
 {
@@ -140,7 +138,7 @@ struct DocumentParsePlan
     {
         //Pick the strictest possible flags
         ParseJob::SequentialProcessingFlags ret = ParseJob::IgnoresSequentialProcessing;
-        foreach(const DocumentParseTarget &target, targets) {
+        for (const DocumentParseTarget& target : targets) {
             ret |= target.sequentialProcessingFlags;
         }
         return ret;
@@ -150,7 +148,7 @@ struct DocumentParsePlan
     {
         //Pick the best priority
         int ret = BackgroundParser::WorstPriority;
-        foreach(const DocumentParseTarget &target, targets) {
+        for (const DocumentParseTarget& target : targets) {
             if(target.priority < ret) {
                 ret = target.priority;
             }
@@ -162,17 +160,17 @@ struct DocumentParsePlan
     {
         //Pick the best features
         TopDUContext::Features ret = (TopDUContext::Features)0;
-        foreach(const DocumentParseTarget &target, targets) {
+        for (const DocumentParseTarget& target : targets) {
             ret = (TopDUContext::Features) (ret | target.features);
         }
         return ret;
     }
 
-    QList<QPointer<QObject> > notifyWhenReady() const
+    QVector<QPointer<QObject>> notifyWhenReady() const
     {
-        QList<QPointer<QObject> > ret;
+        QVector<QPointer<QObject>> ret;
 
-        foreach(const DocumentParseTarget &target, targets) {
+        for (const DocumentParseTarget& target : targets) {
             if(target.notifyWhenReady)
                 ret << target.notifyWhenReady;
         }
@@ -423,7 +421,7 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
         m_threads = 0;
 
         if (qEnvironmentVariableIsSet("KDEV_BACKGROUNDPARSER_MAXTHREADS")) {
-            m_parser->setThreadCount(qgetenv("KDEV_BACKGROUNDPARSER_MAXTHREADS").toInt());
+            m_parser->setThreadCount(qEnvironmentVariableIntValue("KDEV_BACKGROUNDPARSER_MAXTHREADS"));
         } else {
             m_parser->setThreadCount(BACKWARDS_COMPATIBLE_ENTRY("Number of Threads", QThread::idealThreadCount()));
         }
@@ -437,14 +435,17 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
         }
     }
 
+    bool isSuspended() const
+    {
+        return m_weaver.state()->stateId() == ThreadWeaver::Suspended ||
+               m_weaver.state()->stateId() == ThreadWeaver::Suspending;
+    }
+
     void suspend()
     {
         qCDebug(LANGUAGE) << "Suspending background parser";
 
-        bool s = m_weaver.state()->stateId() == ThreadWeaver::Suspended ||
-                 m_weaver.state()->stateId() == ThreadWeaver::Suspending;
-
-        if (s) { // Already suspending
+        if (isSuspended()) { // Already suspending
             qCWarning(LANGUAGE) << "Already suspended or suspending";
             return;
         }
@@ -455,10 +456,10 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
 
     void resume()
     {
-        bool s = m_weaver.state()->stateId() == ThreadWeaver::Suspended ||
-                 m_weaver.state()->stateId() == ThreadWeaver::Suspending;
+        qCDebug(LANGUAGE) << "Resuming background parser";
 
-        if (m_timer.isActive() && !s) { // Not suspending
+        if (m_timer.isActive() && !isSuspended()) { // Not suspended
+            qCWarning(LANGUAGE) << "Not suspended";
             return;
         }
 
@@ -518,19 +519,15 @@ BackgroundParser::BackgroundParser(ILanguageController *languageController)
     connect(ICore::self()->documentController(), &IDocumentController::documentClosed, this, &BackgroundParser::documentClosed);
     connect(ICore::self(), &ICore::aboutToShutdown, this, &BackgroundParser::aboutToQuit);
 
-    bool connected = QObject::connect(ICore::self()->projectController(),
+    QObject::connect(ICore::self()->projectController(),
                                       &IProjectController::projectAboutToBeOpened,
                                       this, &BackgroundParser::projectAboutToBeOpened);
-    Q_ASSERT(connected);
-    connected = QObject::connect(ICore::self()->projectController(),
+    QObject::connect(ICore::self()->projectController(),
                                  &IProjectController::projectOpened,
                                  this, &BackgroundParser::projectOpened);
-    Q_ASSERT(connected);
-    connected = QObject::connect(ICore::self()->projectController(),
+    QObject::connect(ICore::self()->projectController(),
                                  &IProjectController::projectOpeningAborted,
                                  this, &BackgroundParser::projectOpeningAborted);
-    Q_ASSERT(connected);
-    Q_UNUSED(connected);
 }
 
 void BackgroundParser::aboutToQuit()
@@ -553,7 +550,7 @@ void BackgroundParser::loadSettings()
     d->loadSettings();
 }
 
-void BackgroundParser::parseProgress(KDevelop::ParseJob* job, float value, QString text)
+void BackgroundParser::parseProgress(KDevelop::ParseJob* job, float value, const QString& text)
 {
     Q_UNUSED(text)
     d->m_jobProgress[job] = value;
@@ -588,7 +585,7 @@ void BackgroundParser::revertAllRequests(QObject* notifyWhenReady)
 void BackgroundParser::addDocument(const IndexedString& url, TopDUContext::Features features, int priority,
                                    QObject* notifyWhenReady, ParseJob::SequentialProcessingFlags flags, int delay)
 {
-//     qCDebug(LANGUAGE) << "BackgroundParser::addDocument" << url.toUrl();
+    qCDebug(LANGUAGE) << "BackgroundParser::addDocument" << url << url.toUrl();
     Q_ASSERT(isValidURL(url));
     QMutexLocker lock(&d->m_mutex);
     {
@@ -648,7 +645,7 @@ void BackgroundParser::removeDocument(const IndexedString& url, QObject* notifyW
 
 void BackgroundParser::parseDocuments()
 {
-    if (!d->m_loadingProjects.empty()) {
+    if (d->isSuspended() || !d->m_loadingProjects.empty()) {
         startTimer(d->m_delay);
         return;
     }
@@ -917,7 +914,9 @@ void BackgroundParser::documentUrlChanged(IDocument* document)
 }
 
 void BackgroundParser::startTimer(int delay) {
-    d->m_timer.start(delay);
+    if (!d->isSuspended()) {
+        d->m_timer.start(delay);
+    }
 }
 
 void BackgroundParser::projectAboutToBeOpened(IProject* project)
