@@ -49,7 +49,7 @@ public:
 
 public: // Node overrides
   bool getIcon(QIcon& a_resultIcon) override;
-  int getScore() const override { return 101; }
+  int score() const override { return 101; }
 
 private:
   /// The namespace identifier.
@@ -84,6 +84,8 @@ DocumentClassesFolder::DocumentClassesFolder(const QString& a_displayName, Nodes
   : DynamicFolderNode(a_displayName, a_model)
   , m_updateTimer( new QTimer(this) )
 {
+  // this is the required delay.
+  m_updateTimer->setInterval(2000);
   connect( m_updateTimer, &QTimer::timeout, this, &DocumentClassesFolder::updateChangedFiles);
 }
 
@@ -122,11 +124,11 @@ void DocumentClassesFolder::nodeCleared()
 
 void DocumentClassesFolder::populateNode()
 {
-  // Start updates timer - this is the required delay.
-  m_updateTimer->start(2000);
+    // Start updates timer
+    m_updateTimer->start();
 }
 
-QSet< KDevelop::IndexedString > DocumentClassesFolder::getAllOpenDocuments()
+QSet<KDevelop::IndexedString> DocumentClassesFolder::allOpenDocuments() const
 {
   return m_openFiles;
 }
@@ -243,7 +245,7 @@ bool DocumentClassesFolder::updateDocument(const KDevelop::IndexedString& a_file
     if ( item.kind & CodeModelItem::Namespace )
     {
       // This should create the namespace folder and add it to the cache.
-      getNamespaceFolder(id);
+      namespaceFolder(id);
 
       // Add to the locally created namespaces.
       declaredNamespaces.insert(id);
@@ -304,7 +306,7 @@ bool DocumentClassesFolder::updateDocument(const KDevelop::IndexedString& a_file
               if ( decls->declaration()->kind() == Declaration::Namespace )
               {
                 // This should create the namespace folder and add it to the cache.
-                parentNode = getNamespaceFolder(parentIdentifier);
+                parentNode = namespaceFolder(parentIdentifier);
                 
                 // Add to the locally created namespaces.
                 declaredNamespaces.insert(parentIdentifier);
@@ -383,7 +385,7 @@ void DocumentClassesFolder::removeClassNode(ClassModelNodes::ClassNode* a_node)
 {
   // Get the parent namespace identifier.
   QualifiedIdentifier parentNamespaceIdentifier;
-  if ( auto namespaceParent = dynamic_cast<StaticNamespaceFolderNode*>(a_node->getParent()) )
+  if ( auto namespaceParent = dynamic_cast<StaticNamespaceFolderNode*>(a_node->parent()) )
   {
     parentNamespaceIdentifier = namespaceParent->qualifiedIdentifier();
   }
@@ -416,7 +418,7 @@ void DocumentClassesFolder::removeEmptyNamespace(const QualifiedIdentifier& a_id
   }
 }
 
-StaticNamespaceFolderNode* DocumentClassesFolder::getNamespaceFolder(const KDevelop::QualifiedIdentifier& a_identifier)
+StaticNamespaceFolderNode* DocumentClassesFolder::namespaceFolder(const KDevelop::QualifiedIdentifier& a_identifier)
 {
   // Stop condition.
   if ( a_identifier.count() == 0 )
@@ -427,7 +429,7 @@ StaticNamespaceFolderNode* DocumentClassesFolder::getNamespaceFolder(const KDeve
   if ( iter == m_namespaces.end() )
   {
     // It's not in the cache - create folders up to it.
-    Node* parentNode = getNamespaceFolder(a_identifier.left(-1));
+    Node* parentNode = namespaceFolder(a_identifier.left(-1));
     if ( parentNode == nullptr )
       parentNode = this;
 
