@@ -42,7 +42,9 @@ const bool NormalDeclarationCompletionItem::shortenArgumentHintReturnValues = tr
 const int NormalDeclarationCompletionItem::maximumArgumentHintReturnValueLength = 30;
 const int NormalDeclarationCompletionItem::desiredTypeLength = 20;
 
-NormalDeclarationCompletionItem::NormalDeclarationCompletionItem(const KDevelop::DeclarationPointer& decl, QExplicitlySharedDataPointer<CodeCompletionContext> context, int inheritanceDepth)
+NormalDeclarationCompletionItem::NormalDeclarationCompletionItem(const KDevelop::DeclarationPointer& decl,
+                                                                 const QExplicitlySharedDataPointer<CodeCompletionContext>& context,
+                                                                 int inheritanceDepth)
   : m_completionContext(context), m_declaration(decl), m_inheritanceDepth(inheritanceDepth) {
 }
 
@@ -115,7 +117,7 @@ bool NormalDeclarationCompletionItem::createsExpandingWidget() const
   return false;
 }
 
-QString NormalDeclarationCompletionItem::shortenedTypeString(KDevelop::DeclarationPointer decl, int desiredTypeLength) const
+QString NormalDeclarationCompletionItem::shortenedTypeString(const KDevelop::DeclarationPointer& decl, int desiredTypeLength) const
 {
   Q_UNUSED(desiredTypeLength);
   return decl->abstractType()->toString();
@@ -156,7 +158,7 @@ QVariant NormalDeclarationCompletionItem::data(const QModelIndex& index, int rol
                 if(!m_declaration->context()->owner()->identifier().isEmpty())
                   return shortenedTypeString(DeclarationPointer(m_declaration->context()->owner()), desiredTypeLength);
                 else
-                  return "enum";
+                  return QStringLiteral("enum");
               }
             }
             if (FunctionType::Ptr functionType = m_declaration->type<FunctionType>()) {
@@ -171,17 +173,17 @@ QVariant NormalDeclarationCompletionItem::data(const QModelIndex& index, int rol
               }else if(argumentHintDepth()) {
                 return QString();//Don't show useless prefixes in the argument-hints
               }else if(funDecl && funDecl->isConstructor() )
-                return "<constructor>";
+                return QStringLiteral("<constructor>");
               else if(funDecl && funDecl->isDestructor() )
-                return "<destructor>";
+                return QStringLiteral("<destructor>");
               else
-                return "<incomplete type>";
+                return QStringLiteral("<incomplete type>");
 
             } else {
               return shortenedTypeString(m_declaration, desiredTypeLength);
             }
           } else {
-            return "<incomplete type>";
+            return QStringLiteral("<incomplete type>");
           }
         } else if (index.column() == CodeCompletionModel::Arguments) {
             if (m_declaration->isFunctionDeclaration()) {
@@ -198,7 +200,6 @@ QVariant NormalDeclarationCompletionItem::data(const QModelIndex& index, int rol
     case CodeCompletionModel::ExpandingWidget: {
       QWidget* nav = createExpandingWidget(model);
       Q_ASSERT(nav);
-      model->addNavigationWidget(this, nav);
 
       QVariant v;
       v.setValue<QWidget*>(nav);
