@@ -19,8 +19,7 @@
 
 #include "applychangeswidget.h"
 
-#include <ktexteditor/document.h>
-#include <ktexteditor/view.h>
+#include <KTextEditor/Document>
 
 #include <KMimeTypeTrader>
 
@@ -173,7 +172,7 @@ void ApplyChangesWidgetPrivate::createEditPart(const IndexedString & file)
     CodeRepresentation::Ptr repr = createCodeRepresentation(file);
     if(!repr->fileExists())
     {
-        const QString templateName = QDir::tempPath() + QLatin1Char('/') + url.fileName().split('.').last();
+        const QString templateName = QDir::tempPath() + QLatin1Char('/') + url.fileName().split(QLatin1Char('.')).last();
         QTemporaryFile * temp(new QTemporaryFile(templateName));
         temp->open();
         temp->write(repr->text().toUtf8());
@@ -186,7 +185,7 @@ void ApplyChangesWidgetPrivate::createEditPart(const IndexedString & file)
     m_editParts[m_index]->openUrl(url);
 
     v->addWidget(m_editParts[m_index]->widget());
-    v->setSizes(QList<int>() << 400 << 100);
+    v->setSizes(QList<int>{400, 100});
 }
 
 void ApplyChangesWidget::indexChanged(int newIndex)
