@@ -118,7 +118,7 @@ inline QString rangeText(const KTextEditor::Range& range, const QStringList& tex
         }
         ret << lineText.mid(startColumn, endColumn - startColumn);
     }
-    return ret.join(QStringLiteral("\n"));
+    return ret.join(QLatin1Char('\n'));
 }
 
 // need to have it as otherwise the arguments can exceed the maximum of 10
@@ -206,7 +206,9 @@ DocumentChangeSet::ChangeResult DocumentChangeSet::applyAllChanges()
     }
 
     QList<QUrl> allFiles;
-    foreach (IndexedString file, d->documentsRename.keys().toSet() + d->changes.keys().toSet()) {
+    const auto changedFiles = d->documentsRename.keys().toSet() + d->changes.keys().toSet();
+    allFiles.reserve(changedFiles.size());
+    for (const IndexedString& file : changedFiles) {
         allFiles << file.toUrl();
     }
 
@@ -264,9 +266,9 @@ DocumentChangeSet::ChangeResult DocumentChangeSet::applyAllChanges()
     ChangesHash filteredSortedChanges;
     ChangeResult result = ChangeResult::successfulResult();
 
-    QList<IndexedString> files(d->changes.keys());
+    const QList<IndexedString> files(d->changes.keys());
 
-    foreach(const IndexedString &file, files) {
+    for (const IndexedString& file : files) {
         CodeRepresentation::Ptr repr = createCodeRepresentation(file);
         if(!repr) {
             return ChangeResult(QStringLiteral("Could not create a Representation for %1").arg(file.str()));
@@ -291,7 +293,7 @@ DocumentChangeSet::ChangeResult DocumentChangeSet::applyAllChanges()
     QMap<IndexedString, QString> oldTexts;
 
     //Apply the changes to the files
-    foreach(const IndexedString &file, files) {
+    for (const IndexedString& file : files) {
         oldTexts[file] = codeRepresentations[file]->text();
 
         result = d->replaceOldText(codeRepresentations[file].data(), newTexts[file], filteredSortedChanges[file]);
@@ -308,7 +310,7 @@ DocumentChangeSet::ChangeResult DocumentChangeSet::applyAllChanges()
     d->updateFiles();
 
     if(d->activationPolicy == Activate) {
-        foreach(const IndexedString& file, files) {
+        for (const IndexedString& file : files) {
             ICore::self()->documentController()->openDocument(file.toUrl());
         }
     }
@@ -379,7 +381,7 @@ DocumentChangeSet::ChangeResult DocumentChangeSetPrivate::generateNewText(const
     }
 
     //Create the actual new modified file
-    QStringList textLines = repr->text().split('\n');
+    QStringList textLines = repr->text().split(QLatin1Char('\n'));
 
     QUrl url = file.toUrl();
 
@@ -393,10 +395,10 @@ DocumentChangeSet::ChangeResult DocumentChangeSetPrivate::generateNewText(const
             ((encountered = rangeText(change.m_range, textLines)) == change.m_oldText || change.m_ignoreOldText))
         {
             ///Problem: This does not work if the other changes significantly alter the context @todo Use the changed context
-            QString leftContext = QStringList(textLines.mid(0, change.m_range.start().line()+1)).join(QStringLiteral("\n"));
+            QString leftContext = QStringList(textLines.mid(0, change.m_range.start().line()+1)).join(QLatin1Char('\n'));
             leftContext.chop(textLines[change.m_range.start().line()].length() - change.m_range.start().column());
 
-            QString rightContext = QStringList(textLines.mid(change.m_range.end().line())).join(QStringLiteral("\n")).mid(change.m_range.end().column());
+            QString rightContext = QStringList(textLines.mid(change.m_range.end().line())).join(QLatin1Char('\n')).mid(change.m_range.end().column());
 
             if(formatter && (formatPolicy == DocumentChangeSet::AutoFormatChanges
                                 || formatPolicy == DocumentChangeSet::AutoFormatChangesKeepIndentation))
@@ -406,8 +408,8 @@ DocumentChangeSet::ChangeResult DocumentChangeSetPrivate::generateNewText(const
 
                 if(formatPolicy == DocumentChangeSet::AutoFormatChangesKeepIndentation) {
                     // Reproduce the previous indentation
-                    QStringList oldLines = oldNewText.split('\n');
-                    QStringList newLines = change.m_newText.split('\n');
+                    QStringList oldLines = oldNewText.split(QLatin1Char('\n'));
+                    QStringList newLines = change.m_newText.split(QLatin1Char('\n'));
 
                     if(oldLines.size() == newLines.size()) {
                         for(int line = 0; line < newLines.size(); ++line) {
@@ -433,7 +435,7 @@ DocumentChangeSet::ChangeResult DocumentChangeSetPrivate::generateNewText(const
 
                             newLines[line].replace(0, newIndentationLength, oldIndentation);
                         }
-                        change.m_newText = newLines.join(QStringLiteral("\n"));
+                        change.m_newText = newLines.join(QLatin1Char('\n'));
                     } else {
                         qCDebug(LANGUAGE) << "Cannot keep the indentation because the line count has changed" << oldNewText;
                     }
@@ -451,7 +453,10 @@ DocumentChangeSet::ChangeResult DocumentChangeSetPrivate::generateNewText(const
                 line.replace(change.m_range.start().column(), line.length() - change.m_range.start().column(),
                              change.m_newText);
                 // null other lines and remember for deletion
-                for(int i = change.m_range.start().line() + 1; i <= change.m_range.end().line(); ++i) {
+                const int firstLine = change.m_range.start().line() + 1;
+                const int lastLine = change.m_range.end().line();
+                removedLines.reserve(removedLines.size() + lastLine - firstLine + 1);
+                for (int i = firstLine; i <= lastLine; ++i) {
                     textLines[i].clear();
                     removedLines << i;
                 }
@@ -485,7 +490,7 @@ DocumentChangeSet::ChangeResult DocumentChangeSetPrivate::generateNewText(const
             ++offset;
         }
     }
-    output = textLines.join(QStringLiteral("\n"));
+    output = textLines.join(QLatin1Char('\n'));
     return DocumentChangeSet::ChangeResult::successfulResult();
 }
 
