@@ -93,8 +93,8 @@ public:
 TemplatesModelPrivate::TemplatesModelPrivate(const QString& _typePrefix)
 : typePrefix(_typePrefix)
 {
-    if (!typePrefix.endsWith('/')) {
-        typePrefix.append('/');
+    if (!typePrefix.endsWith(QLatin1Char('/'))) {
+        typePrefix.append(QLatin1Char('/'));
     }
 }
 
@@ -116,16 +116,16 @@ void TemplatesModel::refresh()
     QStringList templateArchives;
     foreach(const QString& archivePath, d->searchPaths) {
         const QStringList files = QDir(archivePath).entryList(QDir::Files);
-        foreach(const QString& file, files) {
+        for (const QString& file : files) {
             templateArchives.append(archivePath + file);
         }
     }
 
     QStringList templateDescriptions;
-    const QStringList templatePaths = {QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) +'/'+ d->resourceFilter(TemplatesModelPrivate::Description)};
-    foreach(const QString& templateDescription, templatePaths) {
+    const QStringList templatePaths = {QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + d->resourceFilter(TemplatesModelPrivate::Description)};
+    for (const QString& templateDescription : templatePaths) {
         const QStringList files = QDir(templateDescription).entryList(QDir::Files);
-        foreach(const QString& file, files) {
+        for (const QString& file : files) {
             templateDescriptions.append(templateDescription + file);
         }
     }
@@ -163,11 +163,11 @@ void TemplatesModel::refresh()
 
 QStandardItem *TemplatesModelPrivate::createItem(const QString& name, const QString& category, QStandardItem* parent)
 {
-    QStringList path = category.split('/');
+    const QStringList path = category.split(QLatin1Char('/'));
 
     QStringList currentPath;
-    foreach (const QString& entry, path)
-    {
+    currentPath.reserve(path.size());
+    for (const QString& entry : path) {
         currentPath << entry;
         if (!templateItems.contains(currentPath.join(QLatin1Char('/')))) {
             QStandardItem *item = new QStandardItem(entry);
@@ -193,7 +193,7 @@ void TemplatesModelPrivate::extractTemplateDescriptions()
     searchPaths.removeDuplicates();
     foreach(const QString &archivePath, searchPaths) {
         const QStringList files = QDir(archivePath).entryList(QDir::Files);
-        foreach(const QString& file, files) {
+        for (const QString& file : files) {
             if(file.endsWith(QLatin1String(".zip")) || file.endsWith(QLatin1String(".tar.bz2"))) {
                 QString archfile = archivePath + file;
                 templateArchives.append(archfile);
@@ -201,7 +201,7 @@ void TemplatesModelPrivate::extractTemplateDescriptions()
         }
     }
 
-    QString localDescriptionsDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) +'/'+ resourceFilter(Description);
+    QString localDescriptionsDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + resourceFilter(Description);
 
     QDir dir(localDescriptionsDir);
     if(!dir.exists())
@@ -247,8 +247,8 @@ void TemplatesModelPrivate::extractTemplateDescriptions()
                  *
                  * This is needed because kde-files.org renames downloaded files
                  */
-                foreach (const QString& entryName, templateArchive->directory()->entries())
-                {
+                const auto dirEntries = templateArchive->directory()->entries();
+                for (const QString& entryName : dirEntries) {
                     if (entryName.endsWith(suffix)) {
                         templateEntry = templateArchive->directory()->entry(entryName);
                         break;
@@ -264,8 +264,8 @@ void TemplatesModelPrivate::extractTemplateDescriptions()
 
             if (!templateEntry || !templateEntry->isFile())
             {
-                foreach (const QString& entryName, templateArchive->directory()->entries())
-                {
+                const auto dirEntries = templateArchive->directory()->entries();
+                for (const QString& entryName : dirEntries) {
                     if (entryName.endsWith(suffix)) {
                         templateEntry = templateArchive->directory()->entry(entryName);
                         break;
@@ -304,10 +304,10 @@ void TemplatesModelPrivate::extractTemplateDescriptions()
 QModelIndexList TemplatesModel::templateIndexes(const QString& fileName) const
 {
     QFileInfo info(fileName);
-    QString description = QStandardPaths::locate(QStandardPaths::GenericDataLocation, d->resourceFilter(TemplatesModelPrivate::Description, info.baseName() + ".kdevtemplate"));
+    QString description = QStandardPaths::locate(QStandardPaths::GenericDataLocation, d->resourceFilter(TemplatesModelPrivate::Description, info.baseName() + QLatin1String(".kdevtemplate")));
     if (description.isEmpty())
     {
-        description = QStandardPaths::locate(QStandardPaths::GenericDataLocation, d->resourceFilter(TemplatesModelPrivate::Description, info.baseName() + ".desktop"));
+        description = QStandardPaths::locate(QStandardPaths::GenericDataLocation, d->resourceFilter(TemplatesModelPrivate::Description, info.baseName() + QLatin1String(".desktop")));
     }
 
     QModelIndexList indexes;
@@ -316,19 +316,19 @@ QModelIndexList TemplatesModel::templateIndexes(const QString& fileName) const
     {
         KConfig templateConfig(description);
         KConfigGroup general(&templateConfig, "General");
-        QStringList categories = general.readEntry("Category").split('/');
+        const QStringList categories = general.readEntry("Category").split(QLatin1Char('/'));
 
         QStringList levels;
-        foreach (const QString& category, categories)
-        {
+        levels.reserve(categories.size());
+        for (const QString& category : categories) {
             levels << category;
-            indexes << d->templateItems[levels.join(QString('/'))]->index();
+            indexes << d->templateItems[levels.join(QLatin1Char('/'))]->index();
         }
 
         if (!indexes.isEmpty())
         {
             QString name = general.readEntry("Name");
-            QStandardItem* categoryItem = d->templateItems[levels.join(QString('/'))];
+            QStandardItem* categoryItem = d->templateItems[levels.join(QLatin1Char('/'))];
             for (int i = 0; i < categoryItem->rowCount(); ++i)
             {
                 QStandardItem* templateItem = categoryItem->child(i);
@@ -357,7 +357,7 @@ void TemplatesModel::addDataPath(const QString& path)
 
 QString TemplatesModel::loadTemplateFile(const QString& fileName)
 {
-    QString saveLocation = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) +'/'+ d->resourceFilter(TemplatesModelPrivate::Template);
+    QString saveLocation = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + d->resourceFilter(TemplatesModelPrivate::Template);
 
     QDir dir(saveLocation);
     if(!dir.exists())
@@ -383,9 +383,8 @@ QString TemplatesModel::loadTemplateFile(const QString& fileName)
         archive.open(QIODevice::WriteOnly);
 
         QDir dir(info.absoluteDir());
-        QDir::Filters filter = QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot;
-        foreach (const QFileInfo& entry, dir.entryInfoList(filter))
-        {
+        const auto dirEntryInfos = dir.entryInfoList(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot);
+        for (const QFileInfo& entry : dirEntryInfos) {
             if (entry.isFile())
             {
                 archive.addLocalFile(entry.absoluteFilePath(), entry.fileName());
