@@ -61,6 +61,7 @@ DeclarationData::DeclarationData()
   , m_alwaysForceDirect(false)
   , m_isAutoDeclaration(false)
   , m_isExplicitlyDeleted(false)
+  , m_isExplicitlyTyped(false)
 {
 }
 
@@ -181,7 +182,7 @@ void Declaration::setComment(const QByteArray& str) {
   if(str.isEmpty())
     d->m_comment = 0;
   else
-    d->m_comment = commentRepository().index(Repositories::StringRepositoryItemRequest(str, IndexedString::hashString(str, str.length()), str.length()));
+    d->m_comment = commentRepository().index(Repositories::StringRepositoryItemRequest(str.constData(), IndexedString::hashString(str.constData(), str.length()), str.length()));
 }
 
 void Declaration::setComment(const QString& str) {
@@ -349,7 +350,7 @@ void Declaration::allocateOwnIndex() {
   m_indexInTopContext = m_topContext->m_dynamicData->allocateDeclarationIndex(this, d_func()->m_anonymousInContext || !context() || context()->isAnonymous());
   Q_ASSERT(m_indexInTopContext);
 
-  if(!m_topContext->m_dynamicData->getDeclarationForIndex(m_indexInTopContext))
+  if(!m_topContext->m_dynamicData->declarationForIndex(m_indexInTopContext))
     qFatal("Could not re-retrieve declaration\nindex: %d", m_indexInTopContext);
 
 }
@@ -511,6 +512,16 @@ void Declaration::setExplicitlyDeleted(bool deleted)
   d_func_dynamic()->m_isExplicitlyDeleted = deleted;
 }
 
+bool Declaration::isExplicitlyTyped() const
+{
+  return d_func()->m_isExplicitlyTyped;
+}
+
+void Declaration::setExplicitlyTyped(bool explicitlyTyped)
+{
+  d_func_dynamic()->m_isExplicitlyTyped = explicitlyTyped;
+}
+
 ///@todo see whether it would be useful to create an own TypeAliasDeclaration sub-class for this
 bool Declaration::isTypeAlias() const {
   DUCHAIN_D(Declaration);
@@ -644,7 +655,7 @@ bool Declaration::equalQualifiedIdentifier(const Declaration* rhs) const {
   return m_context->equalScopeIdentifier(m_context);
 }
 
-QMap<IndexedString, QList<RangeInRevision> > Declaration::uses() const
+QMap<IndexedString, QVector<RangeInRevision> > Declaration::uses() const
 {
   ENSURE_CAN_READ
   QMap<IndexedString, QMap<RangeInRevision, bool> > tempUses;
@@ -673,11 +684,12 @@ QMap<IndexedString, QList<RangeInRevision> > Declaration::uses() const
     }
   }
 
-  QMap<IndexedString, QList<RangeInRevision> > ret;
+  QMap<IndexedString, QVector<RangeInRevision>> ret;
 
   for(QMap<IndexedString, QMap<RangeInRevision, bool> >::const_iterator it = tempUses.constBegin(); it != tempUses.constEnd(); ++it) {
     if(!(*it).isEmpty()) {
-      QList<RangeInRevision>& list(ret[it.key()]);
+      auto& list = ret[it.key()];
+      list.reserve((*it).size());
       for(QMap<RangeInRevision, bool>::const_iterator it2 = (*it).constBegin(); it2 != (*it).constEnd(); ++it2)
         list << it2.key();
     }
@@ -724,7 +736,7 @@ bool Declaration::hasUses() const
   return ret;
 }
 
-QMap<IndexedString, QList<KTextEditor::Range> > Declaration::usesCurrentRevision() const
+QMap<IndexedString, QVector<KTextEditor::Range>> Declaration::usesCurrentRevision() const
 {
   ENSURE_CAN_READ
   QMap<IndexedString, QMap<KTextEditor::Range, bool> > tempUses;
@@ -755,11 +767,12 @@ QMap<IndexedString, QList<KTextEditor::Range> > Declaration::usesCurrentRevision
     }
   }
 
-QMap<IndexedString, QList<KTextEditor::Range> > ret;
+  QMap<IndexedString, QVector<KTextEditor::Range>> ret;
 
   for(QMap<IndexedString, QMap<KTextEditor::Range, bool> >::const_iterator it = tempUses.constBegin(); it != tempUses.constEnd(); ++it) {
     if(!(*it).isEmpty()) {
-      QList<KTextEditor::Range>& list(ret[it.key()]);
+      auto& list = ret[it.key()];
+      list.reserve((*it).size());
       for(QMap<KTextEditor::Range, bool>::const_iterator it2 = (*it).constBegin(); it2 != (*it).constEnd(); ++it2)
         list << it2.key();
     }
