@@ -100,7 +100,7 @@ void AbstractNavigationContext::addExternalHtml( const QString& text )
     pos += fileMark.length();
 
     if( pos != text.length() ) {
-      int fileEnd = text.indexOf('}', pos);
+      int fileEnd = text.indexOf(QLatin1Char('}'), pos);
       if( fileEnd != -1 ) {
         QString file = text.mid( pos, fileEnd - pos );
         pos = fileEnd + 1;
@@ -115,7 +115,7 @@ void AbstractNavigationContext::addExternalHtml( const QString& text )
   modifyHtml() +=  text.mid(lastPos, text.length()-lastPos);
 }
 
-void AbstractNavigationContext::makeLink( const QString& name, DeclarationPointer declaration, NavigationAction::Type actionType )
+void AbstractNavigationContext::makeLink(const QString& name, const DeclarationPointer& declaration, NavigationAction::Type actionType)
 {
   NavigationAction action( declaration, actionType );
   makeLink(name, QString(), action);
@@ -144,9 +144,9 @@ QString AbstractNavigationContext::createLink(const QString& name, const QString
 
   QString str = name.toHtmlEscaped();
   if( d->m_linkCount == d->m_selectedLink )
-    str = "<font style=\"background-color:#f1f1f1;\" color=\"#880088\">" + str + "</font>";
+    str = QLatin1String("<font style=\"background-color:#f1f1f1;\" color=\"#880088\">") + str + QLatin1String("</font>");
 
-  QString ret =  "<a href=\"" + hrefId + "\"" + ((d->m_linkCount == d->m_selectedLink && d->m_currentPositionLine == -1) ? QStringLiteral(" name = \"currentPosition\"") : QString()) + ">" + str + "</a>";
+  QString ret = QLatin1String("<a href=\"") + hrefId + QLatin1Char('\"') + ((d->m_linkCount == d->m_selectedLink && d->m_currentPositionLine == -1) ? QStringLiteral(" name = \"currentPosition\"") : QString()) + QLatin1Char('>') + str + QLatin1String("</a>");
 
   if( d->m_selectedLink == d->m_linkCount )
     d->m_selectedLinkAction = action;
@@ -155,7 +155,7 @@ QString AbstractNavigationContext::createLink(const QString& name, const QString
   return ret;
 }
 
-void AbstractNavigationContext::makeLink( const QString& name, QString targetId, const NavigationAction& action)
+void AbstractNavigationContext::makeLink(const QString& name, const QString& targetId, const NavigationAction& action)
 {
   modifyHtml() += createLink(name, targetId, action);
 }
@@ -178,7 +178,8 @@ void AbstractNavigationContext::executeLink(const QString& link)
   execute(d->m_links[link]);
 }
 
-NavigationContextPointer AbstractNavigationContext::executeKeyAction(QString key){
+NavigationContextPointer AbstractNavigationContext::executeKeyAction(const QString& key)
+{
   Q_UNUSED(key);
   return NavigationContextPointer(this);
 }
@@ -443,7 +444,7 @@ NavigationAction AbstractNavigationContext::currentAction() const {
 }
 
 
-QString AbstractNavigationContext::declarationKind(DeclarationPointer decl)
+QString AbstractNavigationContext::declarationKind(const DeclarationPointer& decl)
 {
   const AbstractFunctionDeclaration* function = dynamic_cast<const AbstractFunctionDeclaration*>(decl.data());
 
@@ -500,7 +501,7 @@ static QStringList splitAndKeep(QString str, const QRegExp& regExp) {
   int place = regExp.indexIn(str);
   while(place != -1) {
     ret << str.left(place + regExp.matchedLength());
-    str = str.mid(place + regExp.matchedLength());
+    str.remove(0, place + regExp.matchedLength());
     place = regExp.indexIn(str);
   }
   ret << str;
@@ -508,7 +509,7 @@ static QStringList splitAndKeep(QString str, const QRegExp& regExp) {
 }
 
 void AbstractNavigationContext::addHtml(const QString& html) {
-  QRegExp newLineRegExp("<br>|<br */>");
+  QRegExp newLineRegExp(QStringLiteral("<br>|<br */>"));
   foreach(const QString& line, splitAndKeep(html, newLineRegExp)) {
     d->m_currentText +=  line;
     if(line.indexOf(newLineRegExp) != -1) {
@@ -536,14 +537,14 @@ QString AbstractNavigationContext::fontSizeSuffix(bool /*shorten*/) const
 
 QString Colorizer::operator() ( const QString& str ) const
 {
-  QString ret = "<font color=\"#" + m_color + "\">" + str + "</font>";
+  QString ret = QLatin1String("<font color=\"#") + m_color + QLatin1String("\">") + str + QLatin1String("</font>");
 
   if( m_formatting & Fixed )
-    ret = "<tt>"+ret+"</tt>";
+    ret = QLatin1String("<tt>") + ret + QLatin1String("</tt>");
   if ( m_formatting & Bold )
-    ret = "<b>"+ret+"</b>";
+    ret = QLatin1String("<b>") + ret + QLatin1String("</b>");
   if ( m_formatting & Italic )
-    ret = "<i>"+ret+"</i>";
+    ret = QLatin1String("<i>") + ret + QLatin1String("</i>");
 
   return ret;
 }
