@@ -72,7 +72,7 @@ ProblemNavigationContext::ProblemNavigationContext(const QVector<IProblem::Ptr>&
   // Sort problems vector:
   // 1) By severity
   // 2) By sourceString, if severities are equals
-  std::sort(m_problems.begin(), m_problems.end(), [](const IProblem::Ptr a, const IProblem::Ptr b) {
+  std::sort(m_problems.begin(), m_problems.end(), [](const IProblem::Ptr& a, const IProblem::Ptr& b) {
     if (a->severity() < b->severity())
       return true;
 
@@ -157,7 +157,7 @@ void ProblemNavigationContext::html(IProblem::Ptr problem)
   // Add only non-empty explanation which differs from the problem description.
   // Skip this if we have more than one problem.
   if (m_problems.size() == 1 && !explanation.isEmpty() && explanation != description)
-    modifyHtml() += "<p><i style=\"white-space:pre-wrap\">" + explanation + "</i></p>";
+    modifyHtml() += QLatin1String("<p><i style=\"white-space:pre-wrap\">") + explanation + QLatin1String("</i></p>");
 
   modifyHtml() += QStringLiteral("</td>");
   // END: right column
@@ -212,7 +212,7 @@ void ProblemNavigationContext::html(IProblem::Ptr problem)
 
       makeLink(i18n("Solution (%1)", currentIndex + 1), KEY_INVOKE_ACTION( currentIndex ),
                NavigationAction(KEY_INVOKE_ACTION( currentIndex )));
-      modifyHtml() += ": " + assistantAction->description().toHtmlEscaped();
+      modifyHtml() += QLatin1String(": ") + assistantAction->description().toHtmlEscaped();
 
       ++currentIndex;
     }
@@ -240,10 +240,10 @@ QString ProblemNavigationContext::html(bool shorten)
   return currentHtml();
 }
 
-NavigationContextPointer ProblemNavigationContext::executeKeyAction(QString key)
+NavigationContextPointer ProblemNavigationContext::executeKeyAction(const QString& key)
 {
   if (key.startsWith(QLatin1String("invoke_action_"))) {
-    const int index = key.replace(QLatin1String("invoke_action_"), QString()).toInt();
+    const int index = QString(key).remove(QLatin1String("invoke_action_")).toInt();
     executeAction(index);
   }
 
