@@ -228,7 +228,7 @@ public:
 
 
     QSet<QPair<TopDUContext*, const TopDUContext*> > rebuild;
-    foreach(TopDUContext* context, contexts) {
+    for (TopDUContext* context : contexts) {
 
       context->m_local->m_directImporters.remove(m_ctxt);
 
@@ -596,7 +596,7 @@ void TopDUContext::setFeatures(Features features)
     parsingEnvironmentFile()->setFeatures(this->features());
 }
 
-void TopDUContext::setAst(QExplicitlySharedDataPointer<IAstContainer> ast)
+void TopDUContext::setAst(const QExplicitlySharedDataPointer<IAstContainer>& ast)
 {
   ENSURE_CAN_WRITE
   m_local->m_ast = ast;
@@ -642,10 +642,10 @@ struct TopDUContext::FindDeclarationsAcceptor {
     //This is used if filtering is disabled
     PersistentSymbolTable::Declarations::Iterator unchecked;
     if(check.flags & DUContext::NoImportsCheck) {
-      allDecls = PersistentSymbolTable::self().getDeclarations(id);
+      allDecls = PersistentSymbolTable::self().declarations(id);
       unchecked = allDecls.iterator();
     } else
-      filter = PersistentSymbolTable::self().getFilteredDeclarations(id, top->recursiveImportIndices());
+      filter = PersistentSymbolTable::self().filteredDeclarations(id, top->recursiveImportIndices());
 
     while(filter || unchecked) {
 
@@ -737,7 +737,7 @@ template<class Acceptor>
 bool TopDUContext::applyAliases( const QualifiedIdentifier& previous, const SearchItem::Ptr& identifier, Acceptor& accept, const CursorInRevision& position, bool canBeNamespace, ApplyAliasesBuddyInfo* buddy, uint recursionDepth ) const
 {
   if(recursionDepth > maxApplyAliasesRecursion) {
-    QList<QualifiedIdentifier> searches = identifier->toList();
+    const auto searches = identifier->toList();
     QualifiedIdentifier id;
     if(!searches.isEmpty())
       id = searches.first();
@@ -764,7 +764,7 @@ bool TopDUContext::applyAliases( const QualifiedIdentifier& previous, const Sear
 
     if(aliasId.inRepository()) {
     //This iterator efficiently filters the visible declarations out of all declarations
-      PersistentSymbolTable::FilteredDeclarationIterator filter = PersistentSymbolTable::self().getFilteredDeclarations(aliasId, recursiveImportIndices());
+      PersistentSymbolTable::FilteredDeclarationIterator filter = PersistentSymbolTable::self().filteredDeclarations(aliasId, recursiveImportIndices());
 
       if(filter) {
         DeclarationChecker check(this, position, AbstractType::Ptr(), NoSearchFlags, nullptr);
@@ -845,7 +845,7 @@ bool TopDUContext::applyAliases( const QualifiedIdentifier& previous, const Sear
 
     if(importId.inRepository()) {
       //This iterator efficiently filters the visible declarations out of all declarations
-      PersistentSymbolTable::FilteredDeclarationIterator filter = PersistentSymbolTable::self().getFilteredDeclarations(importId, recursiveImportIndices());
+      PersistentSymbolTable::FilteredDeclarationIterator filter = PersistentSymbolTable::self().filteredDeclarations(importId, recursiveImportIndices());
 
       if(filter) {
         DeclarationChecker check(this, position, AbstractType::Ptr(), NoSearchFlags, nullptr);
@@ -1030,16 +1030,18 @@ void TopDUContext::removeImportedParentContext(DUContext* context) {
   m_local->removeImportedContextRecursively(static_cast<TopDUContext*>(context), true);
 }
 
-void TopDUContext::addImportedParentContexts(const QList<QPair<TopDUContext*, CursorInRevision> >& contexts, bool temporary) {
+void TopDUContext::addImportedParentContexts(const QVector<QPair<TopDUContext*, CursorInRevision>>& contexts, bool temporary) {
   typedef QPair<TopDUContext*, CursorInRevision> Pair;
 
-  foreach(const Pair pair, contexts)
+  for (const Pair pair : contexts) {
     addImportedParentContext(pair.first, pair.second, false, temporary);
+  }
 }
 
 void TopDUContext::removeImportedParentContexts(const QList<TopDUContext*>& contexts) {
-  foreach(TopDUContext* context, contexts)
+  for (TopDUContext* context : contexts) {
     DUContext::removeImportedParentContext(context);
+  }
 
   m_local->removeImportedContextsRecursively(contexts, true);
 }
@@ -1078,9 +1080,9 @@ Declaration* TopDUContext::usedDeclarationForIndex(unsigned int declarationIndex
   if(declarationIndex & (1<<31)) {
     //We use the highest bit to mark direct indices into the local declarations
     declarationIndex &= ~(1<<31); //unset the highest bit
-    return m_dynamicData->getDeclarationForIndex(declarationIndex);
+    return m_dynamicData->declarationForIndex(declarationIndex);
   }else if(declarationIndex < d_func()->m_usedDeclarationIdsSize())
-    return d_func()->m_usedDeclarationIds()[declarationIndex].getDeclaration(this);
+    return d_func()->m_usedDeclarationIds()[declarationIndex].declaration(this);
   else
     return nullptr;
 }
@@ -1133,8 +1135,9 @@ int TopDUContext::indexForUsedDeclaration(Declaration* declaration, bool create)
   return d_func()->m_usedDeclarationIdsSize()-1;
 }
 
-QList<RangeInRevision> allUses(TopDUContext* context, Declaration* declaration, bool noEmptyRanges) {
-  QList<RangeInRevision> ret;
+QVector<RangeInRevision> allUses(TopDUContext* context, Declaration* declaration, bool noEmptyRanges)
+{
+  QVector<RangeInRevision> ret;
   int declarationIndex = context->indexForUsedDeclaration(declaration, false);
   if(declarationIndex == std::numeric_limits<int>::max())
     return ret;
