@@ -158,7 +158,7 @@ void verifyDataInfo(const TopDUContextDynamicData::ItemDataInfo& info, const QVe
 
 QString basePath()
 {
-  return globalItemRepositoryRegistry().path() + "/topcontexts/";
+  return globalItemRepositoryRegistry().path() + QLatin1String("/topcontexts/");
 }
 
 QString pathForTopContext(const uint topContextIndex)
@@ -287,6 +287,7 @@ void TopDUContextDynamicData::DUChainItemStorage<Item>::storeData(uint& currentD
 {
   auto const oldOffsets = offsets;
   offsets.clear();
+  offsets.reserve(items.size());
   for (int a = 0; a < items.size(); ++a) {
     auto item = items[a];
     if (!item) {
@@ -363,7 +364,7 @@ bool TopDUContextDynamicData::DUChainItemStorage<Item>::isItemForIndexLoaded(uin
 }
 
 template<class Item>
-Item TopDUContextDynamicData::DUChainItemStorage<Item>::getItemForIndex(uint index) const
+Item TopDUContextDynamicData::DUChainItemStorage<Item>::itemForIndex(uint index) const
 {
   if (index >= (0x0fffffff/2)) {
     index = 0x0fffffff - index; //We always keep the highest bit at zero
@@ -377,7 +378,7 @@ Item TopDUContextDynamicData::DUChainItemStorage<Item>::getItemForIndex(uint ind
     qCWarning(LANGUAGE) << "item index out of bounds:" << index << "count:" << items.size();
     return {};
   }
-  const uint realIndex = index - 1;;
+  const uint realIndex = index - 1;
   const auto& item = items.at(realIndex);
   if (item) {
     //Shortcut, because this is the most common case
@@ -409,7 +410,7 @@ Item TopDUContextDynamicData::DUChainItemStorage<Item>::getItemForIndex(uint ind
       item->makeDynamic();
     }
 
-    auto parent = data->getContextForIndex(offsets[realIndex].parentContext);
+    auto parent = data->contextForIndex(offsets[realIndex].parentContext);
     Q_ASSERT_X(parent, Q_FUNC_INFO, "Could not find parent context for loaded item.\n"
                                     "Potentially, the context has been deleted without deleting its children.");
     item->rebuildDynamicData(parent, index);
@@ -589,8 +590,6 @@ TopDUContext* TopDUContextDynamicData::load(uint topContextIndex) {
       qCWarning(LANGUAGE) << "Top-context file is empty" << file.fileName();
       return nullptr;
     }
-    QVector<ItemDataInfo> contextDataOffsets;
-    QVector<ItemDataInfo> declarationDataOffsets;
 
     uint readValue;
     file.read((char*)&readValue, sizeof(uint));
@@ -693,8 +692,9 @@ void TopDUContextDynamicData::store() {
     m_data.clear();
 
     uint newDataSize = 0;
-    foreach(const ArrayWithPosition &array, oldData)
+    for (const ArrayWithPosition& array : oldData) {
         newDataSize += array.position;
+    }
 
     newDataSize = std::max(newDataSize, 10000u);
 
@@ -811,7 +811,7 @@ bool TopDUContextDynamicData::isTemporaryDeclarationIndex(uint index) const {
   return !(index < (0x0fffffff/2));
 }
 
-DUContext* TopDUContextDynamicData::getContextForIndex(uint index) const
+DUContext* TopDUContextDynamicData::contextForIndex(uint index) const
 {
   if(!m_dataLoaded)
     loadData();
@@ -820,23 +820,23 @@ DUContext* TopDUContextDynamicData::getContextForIndex(uint index) const
     return m_topContext;
   }
 
-  return m_contexts.getItemForIndex(index);
+  return m_contexts.itemForIndex(index);
 }
 
-Declaration* TopDUContextDynamicData::getDeclarationForIndex(uint index) const
+Declaration* TopDUContextDynamicData::declarationForIndex(uint index) const
 {
   if(!m_dataLoaded)
     loadData();
 
-  return m_declarations.getItemForIndex(index);
+  return m_declarations.itemForIndex(index);
 }
 
-ProblemPointer TopDUContextDynamicData::getProblemForIndex(uint index) const
+ProblemPointer TopDUContextDynamicData::problemForIndex(uint index) const
 {
   if(!m_dataLoaded)
     loadData();
 
-  return m_problems.getItemForIndex(index);
+  return m_problems.itemForIndex(index);
 }
 
 void TopDUContextDynamicData::clearDeclarationIndex(Declaration* decl)
