@@ -46,7 +46,7 @@ public:
     void emitProgress(const IFilterStrategy::Progress& progress);
 
     QString joinCommandLine() const;
-    QString getJobName();
+    QString jobDisplayName() const;
 
     template< typename T >
     static void mergeEnvironment( QProcessEnvironment& dest, const T& src );
@@ -149,9 +149,10 @@ void OutputExecuteJob::setPrivilegedExecutionCommand( const QStringList& command
 void OutputExecuteJob::setJobName( const QString& name )
 {
     d->m_jobName = name;
-    QString jobName = d->getJobName();
-    setObjectName( jobName );
-    setTitle( jobName );
+
+    const QString jobDisplayName = d->jobDisplayName();
+    setObjectName(jobDisplayName);
+    setTitle(jobDisplayName);
 }
 
 QUrl OutputExecuteJob::workingDirectory() const
@@ -181,7 +182,8 @@ void OutputExecuteJob::start()
             } else {
                 setErrorText( i18n( "No working directory specified for a process." ) );
             }
-            return emitResult();
+            emitResult();
+            return;
         }
 
         setModel( new OutputModel );
@@ -194,7 +196,8 @@ void OutputExecuteJob::start()
             } else {
                 setErrorText( i18n( "Invalid working directory '%1'", effectiveWorkingDirectory.toDisplayString(QUrl::PreferLocalFile) ) );
             }
-            return emitResult();
+            emitResult();
+            return;
         } else if( !effectiveWorkingDirectory.isLocalFile() ) {
             setError( InvalidWorkingDirectoryError );
             if( isBuilder ) {
@@ -202,7 +205,8 @@ void OutputExecuteJob::start()
             } else {
                 setErrorText( i18n( "Working directory '%1' is not a local path", effectiveWorkingDirectory.toDisplayString(QUrl::PreferLocalFile) ) );
             }
-            return emitResult();
+            emitResult();
+            return;
         }
 
         QFileInfo workingDirInfo( effectiveWorkingDirectory.toLocalFile() );
@@ -222,7 +226,8 @@ void OutputExecuteJob::start()
                 } else {
                     setErrorText( i18n( "Working directory '%1' does not exist or is not a directory", effectiveWorkingDirectory.toDisplayString(QUrl::PreferLocalFile) ) );
                 }
-                return emitResult();
+                emitResult();
+                return;
             }
         }
 
@@ -344,13 +349,12 @@ void OutputExecuteJob::childProcessError( QProcess::ProcessError processError )
             errorValue = i18n("Waiting for the process has timed out");
             break;
 
-        default:
         case QProcess::UnknownError:
             errorValue = i18n("Exit code %1", d->m_process->exitCode());
             break;
     }
 
-    // Show the toolview if it's hidden for the user to be able to diagnose errors.
+    // Show the tool view if it's hidden for the user to be able to diagnose errors.
     if( !d->m_outputStarted ) {
         d->m_outputStarted = true;
         startOutput();
@@ -531,12 +535,12 @@ QStringList OutputExecuteJobPrivate::effectiveCommandLine() const
     }
 }
 
-QString OutputExecuteJobPrivate::getJobName()
+QString OutputExecuteJobPrivate::jobDisplayName() const
 {
     const QString joinedCommandLine = joinCommandLine();
     if( m_properties.testFlag( OutputExecuteJob::AppendProcessString ) ) {
         if( !m_jobName.isEmpty() ) {
-            return m_jobName + ": " + joinedCommandLine;
+            return m_jobName + QLatin1String(": ") + joinedCommandLine;
         } else {
             return joinedCommandLine;
         }
