@@ -54,7 +54,7 @@ namespace {
 /**
  * Returns the parent folder item for a given item or the project root item if there is no parent.
  */
-ProjectFolderItem* getParentFolder(ProjectBaseItem* item)
+ProjectFolderItem* parentFolder(ProjectBaseItem* item)
 {
     if ( item->parent() ) {
         return static_cast<ProjectFolderItem*>(item->parent());
@@ -177,7 +177,7 @@ void AbstractFileManagerPluginPrivate::addJobItems(FileManagerListJob* job,
     // build lists of valid files and folders with paths relative to the project folder
     Path::List files;
     Path::List folders;
-    foreach ( const KIO::UDSEntry& entry, entries ) {
+    for (const KIO::UDSEntry& entry : entries) {
         QString name = entry.stringValue( KIO::UDSEntry::UDS_NAME );
         if (name == QLatin1String(".") || name == QLatin1String("..")) {
             continue;
@@ -564,11 +564,10 @@ bool AbstractFileManagerPlugin::renameFile(ProjectFileItem* file, const Path& ne
 bool AbstractFileManagerPlugin::removeFilesAndFolders(const QList<ProjectBaseItem*> &items)
 {
     bool success = true;
-    foreach(ProjectBaseItem* item, items)
-    {
+    for (ProjectBaseItem* item : items) {
         Q_ASSERT(item->folder() || item->file());
 
-        ProjectFolderItem* parent = getParentFolder(item);
+        ProjectFolderItem* parent = parentFolder(item);
         d->stopWatcher(parent);
 
         success &= removeUrl(parent->project(), item->path().toUrl(), true);
@@ -592,11 +591,10 @@ bool AbstractFileManagerPlugin::removeFilesAndFolders(const QList<ProjectBaseIte
 bool AbstractFileManagerPlugin::moveFilesAndFolders(const QList< ProjectBaseItem* >& items, ProjectFolderItem* newParent)
 {
     bool success = true;
-    foreach(ProjectBaseItem* item, items)
-    {
+    for (ProjectBaseItem* item : items) {
         Q_ASSERT(item->folder() || item->file());
 
-        ProjectFolderItem* oldParent = getParentFolder(item);
+        ProjectFolderItem* oldParent = parentFolder(item);
         d->stopWatcher(oldParent);
         d->stopWatcher(newParent);
 
@@ -629,8 +627,7 @@ bool AbstractFileManagerPlugin::moveFilesAndFolders(const QList< ProjectBaseItem
 bool AbstractFileManagerPlugin::copyFilesAndFolders(const Path::List& items, ProjectFolderItem* newParent)
 {
     bool success = true;
-    foreach(const Path& item, items)
-    {
+    for (const Path& item : items) {
         d->stopWatcher(newParent);
 
         success &= copyUrl(newParent->project(), item.toUrl(), newParent->path().toUrl());
