@@ -100,17 +100,17 @@ public:
 class ProjectBaseItemPrivate
 {
 public:
-    ProjectBaseItemPrivate() : project(nullptr), parent(nullptr), row(-1), model(nullptr), m_pathIndex(0) {}
-    IProject* project;
-    ProjectBaseItem* parent;
-    int row;
+    ProjectBaseItemPrivate() {}
+    IProject* project = nullptr;
+    ProjectBaseItem* parent = nullptr;
+    int row = -1;
     QList<ProjectBaseItem*> children;
     QString text;
     ProjectBaseItem::ProjectItemType type;
     Qt::ItemFlags flags;
-    ProjectModel* model;
+    ProjectModel* model = nullptr;
     Path m_path;
-    uint m_pathIndex;
+    uint m_pathIndex = 0;
     QString iconName;
 
     ProjectBaseItem::RenameStatus renameBaseItem(ProjectBaseItem* item, const QString& newName)
@@ -130,7 +130,7 @@ public:
     {
         Q_ASSERT(item->file() || item->folder());
 
-        if (newName.contains('/')) {
+        if (newName.contains(QLatin1Char('/'))) {
             return ProjectBaseItem::InvalidNewName;
         }
 
@@ -784,7 +784,7 @@ public:
     QHash<QString, QString> fileExtensionToIcon;
 };
 
-Q_GLOBAL_STATIC(IconNameCache, s_cache);
+Q_GLOBAL_STATIC(IconNameCache, s_cache)
 
 QString ProjectFileItem::iconName() const
 {
@@ -898,8 +898,8 @@ QModelIndex ProjectModel::pathToIndex(const QStringList& tofetch_) const
         const QString& currentName = tofetch[a];
 
         bool matched = false;
-        QModelIndexList l = match(current, Qt::DisplayRole, currentName, -1, Qt::MatchExactly);
-        foreach(const QModelIndex& idx, l) {
+        const QModelIndexList l = match(current, Qt::DisplayRole, currentName, -1, Qt::MatchExactly);
+        for (const QModelIndex& idx : l) {
             //If this is not the last item, only match folders, as there may be targets and folders with the same name
             if(a == tofetch.size()-1 || itemFromIndex(idx)->folder()) {
                 ret = idx;
