@@ -21,7 +21,6 @@
 #include "core_p.h"
 
 #include <QApplication>
-#include <QTimer>
 
 #include <KLocalizedString>
 
@@ -49,9 +48,6 @@
 #include "runtimecontroller.h"
 #include "debug.h"
 
-#include <KTextEditor/Document>
-#include <ktexteditor/movinginterface.h>
-
 #include <csignal>
 
 namespace {
@@ -98,7 +94,7 @@ KAboutData createAboutData()
     KAboutData aboutData( QStringLiteral("kdevplatform"),
                           i18n("KDevelop Platform"), QStringLiteral(KDEVPLATFORM_VERSION_STRING),
                           i18n("Development Platform for IDE-like Applications"),
-                          KAboutLicense::LGPL_V2, i18n("Copyright 2004-2017, The KDevelop developers"),
+                          KAboutLicense::LGPL_V2, i18n("Copyright 2004-2018, The KDevelop developers"),
                           QString(), QStringLiteral("https://www.kdevelop.org/"));
 
     aboutData.addAuthor( i18n("Andreas Pakulat"), i18n( "Architecture, VCS Support, Project Management Support, QMake Projectmanager" ), QStringLiteral("apaku@gmx.de") );
@@ -119,6 +115,7 @@ KAboutData createAboutData()
     aboutData.addAuthor( i18n("Milian Wolff"), i18n( "Generic manager, Webdevelopment Plugins, Snippets, Performance" ), QStringLiteral("mail@milianw.de") );
     aboutData.addAuthor( i18n("Kevin Funk"), i18n( "Co-maintainer, C++/Clang, QA, Windows Support, Performance, Website" ), QStringLiteral("kfunk@kde.org") );
     aboutData.addAuthor( i18n("Sven Brauch"), i18n( "Co-maintainer, AppImage, Python Support, User Interface improvements" ), QStringLiteral("svenbrauch@gmx.de") );
+    aboutData.addAuthor( i18n("Friedrich W. H. Kossebau"), QString(), QStringLiteral("kossebau@kde.org") );
 
     return aboutData;
 }
@@ -166,7 +163,7 @@ bool CorePrivate::initialize(Core::Setup mode, const QString& session )
     }
     if( !partController && !(mode & Core::NoUi))
     {
-        partController = new PartController(m_core, uiController.data()->defaultMainWindow());
+        partController = new PartController(m_core, uiController->defaultMainWindow());
     }
 
     if( !projectController )
@@ -230,8 +227,8 @@ bool CorePrivate::initialize(Core::Setup mode, const QString& session )
 
     qCDebug(SHELL) << "Initializing controllers";
 
-    sessionController.data()->initialize( session );
-    if( !sessionController.data()->activeSessionLock() ) {
+    sessionController->initialize( session );
+    if( !sessionController->activeSessionLock() ) {
         return false;
     }
 
@@ -240,14 +237,23 @@ bool CorePrivate::initialize(Core::Setup mode, const QString& session )
     DUChain::initialize();
 
     if (!(mode & Core::NoUi)) {
-        uiController.data()->initialize();
+        uiController->initialize();
     }
-    languageController.data()->initialize();
+    languageController->initialize();
+    languageController->backgroundParser()->suspend();
+    // eventually resume the background parser once the project controller
+    // has been initialized. At that point we know whether there are projects loading
+    // which the background parser is handling internally to defer parse jobs
+    QObject::connect(projectController.data(), &ProjectController::initialized,
+                     m_core, [this]() {
+                         languageController->backgroundParser()->resume();
+                     });
+
     if (partController) {
-        partController.data()->initialize();
+        partController->initialize();
     }
-    projectController.data()->initialize();
-    documentController.data()->initialize();
+    projectController->initialize();
+    documentController->initialize();
 
     /* This is somewhat messy.  We want to load the areas before
         loading the plugins, so that when each plugin is loaded we
@@ -259,29 +265,29 @@ bool CorePrivate::initialize(Core::Setup mode, const QString& session )
         those tool views when loading an area.  */
 
     qCDebug(SHELL) << "Initializing plugin controller (loading session plugins)";
-    pluginController.data()->initialize();
+    pluginController->initialize();
 
     qCDebug(SHELL) << "Initializing working set controller";
     if(!(mode & Core::NoUi))
     {
-        workingSetController.data()->initialize();
+        workingSetController->initialize();
         /* Need to do this after everything else is loaded.  It's too
             hard to restore position of views, and toolbars, and whatever
             that are not created yet.  */
-        uiController.data()->loadAllAreas(KSharedConfig::openConfig());
-        uiController.data()->defaultMainWindow()->show();
+        uiController->loadAllAreas(KSharedConfig::openConfig());
+        uiController->defaultMainWindow()->show();
     }
 
     qCDebug(SHELL) << "Initializing remaining controllers";
-    runController.data()->initialize();
-    sourceFormatterController.data()->initialize();
-    selectionController.data()->initialize();
+    runController->initialize();
+    sourceFormatterController->initialize();
+    selectionController->initialize();
     if (documentationController) {
-        documentationController.data()->initialize();
+        documentationController->initialize();
     }
-    debugController.data()->initialize();
-    testController.data()->initialize();
-    runtimeController.data()->initialize();
+    debugController->initialize();
+    testController->initialize();
+    runtimeController->initialize();
 
     installSignalHandler();
 
@@ -324,14 +330,6 @@ CorePrivate::~CorePrivate()
     runtimeController.clear();
 }
 
-bool Core::initialize(QObject* splash, Setup mode, const QString& session )
-{
-    if (splash) {
-        QTimer::singleShot( 200, splash, &QObject::deleteLater );
-    }
-    return initialize(mode, session);
-}
-
 bool Core::initialize(Setup mode, const QString& session)
 {
     if (m_self)
@@ -408,34 +406,34 @@ void Core::cleanup()
         d->languageController->backgroundParser()->abortAllJobs();
         d->languageController->backgroundParser()->suspend();
 
-        d->debugController.data()->cleanup();
-        d->selectionController.data()->cleanup();
+        d->debugController->cleanup();
+        d->selectionController->cleanup();
         // Save the layout of the ui here, so run it first
-        d->uiController.data()->cleanup();
+        d->uiController->cleanup();
 
         if (d->workingSetController)
-            d->workingSetController.data()->cleanup();
+            d->workingSetController->cleanup();
 
-        /* Must be called before projectController.data()->cleanup(). */
+        /* Must be called before projectController->cleanup(). */
         // Closes all documents (discards, as already saved if the user wished earlier)
-        d->documentController.data()->cleanup();
-        d->runController.data()->cleanup();
+        d->documentController->cleanup();
+        d->runController->cleanup();
         if (d->partController) {
             d->partController->cleanup();
         }
-        d->projectController.data()->cleanup();
-        d->sourceFormatterController.data()->cleanup();
+        d->projectController->cleanup();
+        d->sourceFormatterController->cleanup();
 
         // before unloading language plugins, we need to make sure all parse jobs are done
         d->languageController->backgroundParser()->waitForIdle();
-        d->pluginController.data()->cleanup();
+        d->pluginController->cleanup();
 
-        d->sessionController.data()->cleanup();
+        d->sessionController->cleanup();
 
-        d->testController.data()->cleanup();
+        d->testController->cleanup();
 
         //Disable the functionality of the language controller
-        d->languageController.data()->cleanup();
+        d->languageController->cleanup();
 
         DUChain::self()->shutdown();
     }
