@@ -193,12 +193,11 @@ IDocumentation::Ptr DocumentationController::documentationForDeclaration(Declara
 
 QList< IDocumentationProvider* > DocumentationController::documentationProviders() const
 {
-    QList<IPlugin*> plugins=ICore::self()->pluginController()->allPluginsForExtension(QStringLiteral("org.kdevelop.IDocumentationProvider"));
-    QList<IPlugin*> pluginsProvider=ICore::self()->pluginController()->allPluginsForExtension(QStringLiteral("org.kdevelop.IDocumentationProviderProvider"));
+    const QList<IPlugin*> plugins = ICore::self()->pluginController()->allPluginsForExtension(QStringLiteral("org.kdevelop.IDocumentationProvider"));
+    const QList<IPlugin*> pluginsProvider = ICore::self()->pluginController()->allPluginsForExtension(QStringLiteral("org.kdevelop.IDocumentationProviderProvider"));
 
     QList<IDocumentationProvider*> ret;
-    foreach(IPlugin* p, pluginsProvider)
-    {
+    for (IPlugin* p : pluginsProvider) {
         IDocumentationProviderProvider *docProvider=p->extension<IDocumentationProviderProvider>();
         if (!docProvider) {
             qCWarning(SHELL) << "plugin" << p << "does not implement ProviderProvider extension, rerun kbuildsycoca5";
@@ -207,8 +206,7 @@ QList< IDocumentationProvider* > DocumentationController::documentationProviders
         ret.append(docProvider->providers());
     }
 
-    foreach(IPlugin* p, plugins)
-    {
+    for (IPlugin* p : plugins) {
         IDocumentationProvider *doc=p->extension<IDocumentationProvider>();
         if (!doc) {
             qCWarning(SHELL) << "plugin" << p << "does not implement Provider extension, rerun kbuildsycoca5";
@@ -224,13 +222,13 @@ void KDevelop::DocumentationController::showDocumentation(const IDocumentation::
 {
     QWidget* w = ICore::self()->uiController()->findToolView(i18n("Documentation"), m_factory, KDevelop::IUiController::CreateAndRaise);
     if(!w) {
-        qCWarning(SHELL) << "Could not add documentation toolview";
+        qCWarning(SHELL) << "Could not add documentation tool view";
         return;
     }
 
     DocumentationView* view = dynamic_cast<DocumentationView*>(w);
     if( !view ) {
-        qCWarning(SHELL) << "Could not cast toolview" << w << "to DocumentationView class!";
+        qCWarning(SHELL) << "Could not cast tool view" << w << "to DocumentationView class!";
         return;
     }
     view->showDocumentation(doc);
