@@ -70,11 +70,10 @@ Boston, MA 02110-1301, USA.
 
 #define EMPTY_DOCUMENT_URL i18n("Untitled")
 
-namespace KDevelop
-{
+using namespace KDevelop;
 
 
-class DocumentControllerPrivate
+class KDevelop::DocumentControllerPrivate
 {
 public:
     struct OpenFileResult
@@ -109,9 +108,8 @@ public:
 
     void removeDocument(Sublime::Document *doc)
     {
-        QList<QUrl> urlsForDoc = documents.keys(dynamic_cast<KDevelop::IDocument*>(doc));
-        foreach (const QUrl &url, urlsForDoc)
-        {
+        const QList<QUrl> urlsForDoc = documents.keys(dynamic_cast<KDevelop::IDocument*>(doc));
+        for (const QUrl& url : urlsForDoc) {
             qCDebug(SHELL) << "destroying document" << doc;
             documents.remove(url);
         }
@@ -191,8 +189,8 @@ public:
 
     KDevelop::IDocument* findBuddyDocument(const QUrl &url, IBuddyDocumentFinder* finder)
     {
-        QList<KDevelop::IDocument*> allDocs = controller->openDocuments();
-        foreach( KDevelop::IDocument* doc, allDocs ) {
+        const QList<KDevelop::IDocument*> allDocs = controller->openDocuments();
+        for (KDevelop::IDocument* doc : allDocs) {
             if(finder->areBuddies(url, doc->url())) {
                 return doc;
             }
@@ -542,11 +540,7 @@ public:
         return true;
     }
 
-    DocumentController* controller;
-
-    QList<HistoryEntry> backHistory;
-    QList<HistoryEntry> forwardHistory;
-    bool isJumping;
+    DocumentController* const controller;
 
     QPointer<QAction> saveAll;
     QPointer<QAction> revertAll;
@@ -556,6 +550,7 @@ public:
     KRecentFilesAction* fileOpenRecent;
     KTextEditor::Document* globalTextEditorInstance;
 };
+Q_DECLARE_TYPEINFO(KDevelop::DocumentControllerPrivate::HistoryEntry, Q_MOVABLE_TYPE);
 
 DocumentController::DocumentController( QObject *parent )
         : IDocumentController( parent )
@@ -689,7 +684,7 @@ IDocument* DocumentController::openDocument( const QUrl & inputUrl,
         DocumentActivationParams activationParams,
         const QString& encoding, IDocument* buddy)
 {
-    return d->openDocumentInternal( inputUrl, QLatin1String(""), range, encoding, activationParams, buddy);
+    return d->openDocumentInternal(inputUrl, QString(), range, encoding, activationParams, buddy);
 }
 
 
@@ -863,9 +858,10 @@ QList< IDocument * > KDevelop::DocumentController::documentsExclusivelyInWindow(
 QList< IDocument * > KDevelop::DocumentController::modifiedDocuments(const QList< IDocument * > & list) const
 {
     QList< IDocument * > ret;
-    foreach (IDocument* doc, list)
+    for (IDocument* doc : list) {
         if (doc->state() == IDocument::Modified || doc->state() == IDocument::DirtyAndModified)
             ret.append(doc);
+    }
     return ret;
 }
 
@@ -879,29 +875,31 @@ bool DocumentController::saveAllDocumentsForWindow(KParts::MainWindow* mw, KDeve
 void DocumentController::reloadAllDocuments()
 {
     if (Sublime::MainWindow* mw = Core::self()->uiControllerInternal()->activeSublimeWindow()) {
-        QList<IDocument*> views = visibleDocumentsInWindow(dynamic_cast<KDevelop::MainWindow*>(mw));
+        const QList<IDocument*> views = visibleDocumentsInWindow(dynamic_cast<KDevelop::MainWindow*>(mw));
 
         if (!saveSomeDocuments(views, IDocument::Default))
             // User cancelled or other error
             return;
 
-        foreach (IDocument* doc, views)
+        for (IDocument* doc : views) {
             if(!isEmptyDocumentUrl(doc->url()))
                 doc->reload();
+        }
     }
 }
 
 bool DocumentController::closeAllDocuments()
 {
     if (Sublime::MainWindow* mw = Core::self()->uiControllerInternal()->activeSublimeWindow()) {
-        QList<IDocument*> views = visibleDocumentsInWindow(dynamic_cast<KDevelop::MainWindow*>(mw));
+        const QList<IDocument*> views = visibleDocumentsInWindow(dynamic_cast<KDevelop::MainWindow*>(mw));
 
         if (!saveSomeDocuments(views, IDocument::Default))
             // User cancelled or other error
             return false;
 
-        foreach (IDocument* doc, views)
+        for (IDocument* doc : views) {
             doc->close(IDocument::Discard);
+        }
     }
     return true;
 }
@@ -958,7 +956,7 @@ QString DocumentController::activeDocumentPath( const QString& target ) const
     if(!target.isEmpty()) {
         foreach(IProject* project, Core::self()->projectController()->projects()) {
             if(project->name().startsWith(target, Qt::CaseInsensitive)) {
-                return project->path().pathOrUrl() + "/.";
+                return project->path().pathOrUrl() + QLatin1String("/.");
             }
         }
     }
@@ -1033,7 +1031,7 @@ QUrl DocumentController::nextEmptyDocumentUrl()
     if (nextEmptyDocNumber > 0)
         url = QUrl::fromLocalFile(QStringLiteral("/%1 (%2)").arg(EMPTY_DOCUMENT_URL).arg(nextEmptyDocNumber));
     else
-        url = QUrl::fromLocalFile('/' + EMPTY_DOCUMENT_URL);
+        url = QUrl::fromLocalFile(QLatin1Char('/') + EMPTY_DOCUMENT_URL);
     return url;
 }
 
@@ -1054,7 +1052,7 @@ bool DocumentController::openDocumentsSimple( QStringList urls )
     Sublime::Area* area = Core::self()->uiControllerInternal()->activeArea();
     Sublime::AreaIndex* areaIndex = area->rootIndex();
 
-    QList<Sublime::View*> topViews = static_cast<Sublime::MainWindow*>(Core::self()->uiControllerInternal()->activeMainWindow())->getTopViews();
+    QList<Sublime::View*> topViews = static_cast<Sublime::MainWindow*>(Core::self()->uiControllerInternal()->activeMainWindow())->topViews();
 
     if(Sublime::View* activeView = Core::self()->uiControllerInternal()->activeSublimeWindow()->activeView())
         areaIndex = area->indexOf(activeView);
@@ -1083,7 +1081,7 @@ bool DocumentController::openDocumentsWithSplitSeparators( Sublime::AreaIndex* i
     Sublime::Area* area = Core::self()->uiControllerInternal()->activeArea();
 
     QList<int> topLevelSeparators; // Indices of the top-level separators (with groups skipped)
-    QStringList separators = QStringList() << QStringLiteral("/") << QStringLiteral("-");
+    const QStringList separators {QStringLiteral("/"), QStringLiteral("-")};
     QList<QStringList> groups;
 
     bool ret = true;
@@ -1229,6 +1227,4 @@ void DocumentController::vcsAnnotateCurrentDocument()
     }
 }
 
-}
-
 #include "moc_documentcontroller.cpp"
