@@ -31,7 +31,6 @@
 #include <KMimeTypeTrader>
 
 #include <KParts/Part>
-#include <KParts/OpenUrlArguments>
 
 #include <KTextEditor/View>
 #include <KTextEditor/Editor>
@@ -53,21 +52,24 @@ namespace KDevelop
 class PartControllerPrivate
 {
 public:
-    PartControllerPrivate() {}
+    explicit PartControllerPrivate(Core* core)
+        : m_core(core)
+    {}
 
     bool m_showTextEditorStatusBar = false;
     QString m_editor;
     QStringList m_textTypes;
 
-    Core *m_core;
+    Core* const m_core;
 };
 
 PartController::PartController(Core *core, QWidget *toplevel)
-        : IPartController( toplevel ), d(new PartControllerPrivate)
+    : IPartController(toplevel)
+    , d(new PartControllerPrivate(core))
 
 {
     setObjectName(QStringLiteral("PartController"));
-    d->m_core = core;
+
     //Cache this as it is too expensive when creating parts
     //     KConfig * config = Config::standard();
     //     config->setGroup( "General" );
@@ -139,18 +141,9 @@ KTextEditor::Editor* PartController::editorPart() const
     return KTextEditor::Editor::instance();
 }
 
-KTextEditor::Document* PartController::createTextPart(const QString &encoding)
+KTextEditor::Document* PartController::createTextPart()
 {
-    KTextEditor::Document* doc = editorPart()->createDocument(this);
-
-    if ( !encoding.isNull() )
-    {
-        KParts::OpenUrlArguments args = doc->arguments();
-        args.setMimeType( QLatin1String( "text/plain;" ) + encoding );
-        doc->setArguments( args );
-    }
-
-    return doc;
+    return editorPart()->createDocument(this);
 }
 
 KParts::Part* PartController::createPart( const QString & mimeType,
@@ -168,7 +161,7 @@ KParts::Part* PartController::createPart( const QString & mimeType,
         return editorFactory->create<KParts::Part>(
                    nullptr,
                    this,
-                   className.toLatin1() );
+                   className);
     }
 
     return nullptr;
