@@ -32,14 +32,13 @@ class ProblemStorePrivate
 {
 public:
     ProblemStorePrivate()
-        : m_documents(nullptr)
-        , m_severities(KDevelop::IProblem::Error | KDevelop::IProblem::Warning | KDevelop::IProblem::Hint)
+        : m_severities(KDevelop::IProblem::Error | KDevelop::IProblem::Warning | KDevelop::IProblem::Hint)
         , m_rootNode(new KDevelop::ProblemStoreNode())
     {
     }
 
     /// Watched document set. Only problems that are in files in this set are stored.
-    KDevelop::WatchedDocumentSet *m_documents;
+    KDevelop::WatchedDocumentSet *m_documents = nullptr;
 
     /// The severity filter setting
     KDevelop::IProblem::Severities m_severities;
@@ -89,7 +88,7 @@ void ProblemStore::setProblems(const QVector<IProblem::Ptr> &problems)
         clear();
     }
 
-    foreach (const IProblem::Ptr &problem, problems) {
+    for (const IProblem::Ptr& problem : problems) {
         d->m_rootNode->addChild(new ProblemNode(d->m_rootNode, problem));
     }
 
@@ -194,7 +193,7 @@ void ProblemStore::setScope(int scope)
     bool showImports = false;
 
     if (d->m_documents) {
-        if(cast_scope == d->m_documents->getScope())
+        if(cast_scope == d->m_documents->scope())
             return;
 
         showImports = d->m_documents->showImports();
@@ -232,7 +231,7 @@ int ProblemStore::scope() const
 {
     Q_ASSERT(d->m_documents);
 
-    return d->m_documents->getScope();
+    return d->m_documents->scope();
 }
 
 void ProblemStore::setGrouping(int grouping)
