@@ -17,6 +17,7 @@
 #include <vcs/interfaces/ibasicversioncontrol.h>
 #include <vcs/widgets/vcslocationwidget.h>
 #include <vcs/vcsjob.h>
+#include <vcs/vcslocation.h>
 
 #include <QVBoxLayout>
 
@@ -51,9 +52,9 @@ ProjectSourcePage::ProjectSourcePage(const QUrl& initial, const QUrl& repoUrl, I
 
     int preselectIndex = -1;
     IPluginController* pluginManager = ICore::self()->pluginController();
-    QList<IPlugin*> plugins = pluginManager->allPluginsForExtension( QStringLiteral("org.kdevelop.IBasicVersionControl") );
-    foreach( IPlugin* p, plugins )
-    {
+    const QList<IPlugin*> vcsPlugins = pluginManager->allPluginsForExtension( QStringLiteral("org.kdevelop.IBasicVersionControl") );
+    m_plugins.reserve(m_plugins.size() + vcsPlugins.size());
+    for (IPlugin* p : vcsPlugins) {
         if (p == preSelectPlugin) {
             preselectIndex = m_plugins.count();
         }
@@ -61,9 +62,9 @@ ProjectSourcePage::ProjectSourcePage(const QUrl& initial, const QUrl& repoUrl, I
         m_ui->sources->addItem(QIcon::fromTheme(pluginManager->pluginInfo(p).iconName()), p->extension<IBasicVersionControl>()->name());
     }
 
-    plugins = pluginManager->allPluginsForExtension( QStringLiteral("org.kdevelop.IProjectProvider") );
-    foreach( IPlugin* p, plugins )
-    {
+    const QList<IPlugin*> projectPlugins = pluginManager->allPluginsForExtension( QStringLiteral("org.kdevelop.IProjectProvider") );
+    m_plugins.reserve(m_plugins.size() + projectPlugins.size());
+    for (IPlugin* p : projectPlugins) {
         if (p == preSelectPlugin) {
             preselectIndex = m_plugins.count();
         }
@@ -266,7 +267,7 @@ void ProjectSourcePage::locationChanged()
     Q_ASSERT(m_locationWidget);
     if(m_locationWidget->isCorrect()) {
         QString currentUrl = m_ui->workingDir->text();
-        currentUrl = currentUrl.left(currentUrl.lastIndexOf('/')+1);
+        currentUrl = currentUrl.left(currentUrl.lastIndexOf(QLatin1Char('/'))+1);
 
         QUrl current = QUrl::fromUserInput(currentUrl + m_locationWidget->projectName());
         m_ui->workingDir->setUrl(current);
@@ -279,7 +280,7 @@ void ProjectSourcePage::projectChanged(const QString& name)
 {
     Q_ASSERT(m_providerWidget);
     QString currentUrl = m_ui->workingDir->text();
-    currentUrl = currentUrl.left(currentUrl.lastIndexOf('/')+1);
+    currentUrl = currentUrl.left(currentUrl.lastIndexOf(QLatin1Char('/'))+1);
 
     QUrl current = QUrl::fromUserInput(currentUrl + name);
     m_ui->workingDir->setUrl(current);
