@@ -48,10 +48,9 @@ class DialogProviderFake : public IProjectDialogProvider
 Q_OBJECT
 public:
     DialogProviderFake()
-        : m_reopen(true)
     {}
     ~DialogProviderFake() override {}
-    bool m_reopen;
+    bool m_reopen = true;
 
 public Q_SLOTS:
     QUrl askProjectConfigLocation(bool /*fetch*/, const QUrl& /*startUrl*/,
@@ -108,13 +107,13 @@ public:
 
     QList<ProjectFolderItem*> parse(ProjectFolderItem *dom) override
     {
-        Path::List files = m_filesInFolder[dom->path()];
-        foreach (const Path& file, files) {
+        const Path::List files = m_filesInFolder[dom->path()];
+        for (const Path& file : files) {
             new ProjectFileItem(dom->project(), file, dom);
         }
-        Path::List folderPaths = m_subFoldersInFolder[dom->path()];
+        const Path::List folderPaths = m_subFoldersInFolder[dom->path()];
         QList<ProjectFolderItem*> folders;
-        foreach (const Path& folderPath, folderPaths) {
+        for (const Path& folderPath : folderPaths) {
             folders << new ProjectFolderItem(dom->project(), folderPath, dom);
         }
         return folders;
@@ -126,8 +125,8 @@ public:
         return it;
     }
 
-    ProjectFolderItem* addFolder(const Path& /*folder*/, ProjectFolderItem */*parent*/) override { return nullptr; }
-    ProjectFileItem* addFile(const Path& /*file*/, ProjectFolderItem */*parent*/) override { return nullptr; }
+    ProjectFolderItem* addFolder(const Path& /*folder*/, ProjectFolderItem* /*parent*/) override { return nullptr; }
+    ProjectFileItem* addFile(const Path& /*file*/, ProjectFolderItem* /*parent*/) override { return nullptr; }
     bool removeFilesAndFolders(const QList<ProjectBaseItem*> &/*items*/) override { return false; }
     bool moveFilesAndFolders(const QList< KDevelop::ProjectBaseItem* > &/*items*/, KDevelop::ProjectFolderItem* /*newParent*/) override { return false; }
     bool copyFilesAndFolders(const Path::List &/*items*/, KDevelop::ProjectFolderItem* /*newParent*/) override { return false; }
@@ -172,6 +171,10 @@ void TestProjectController::initTestCase()
     m_scratchDir = QDir(QDir::tempPath());
     m_scratchDir.mkdir(QStringLiteral("prjctrltest"));
     m_scratchDir.cd(QStringLiteral("prjctrltest"));
+
+    QSignalSpy projectControllerInitializedSpy(m_core->projectControllerInternal(),
+                                               &ProjectController::initialized);
+    QVERIFY(projectControllerInitializedSpy.wait(100));
 }
 
 void TestProjectController::cleanupTestCase()
