@@ -21,13 +21,6 @@
 #include <QTest>
 #include <QAction>
 
-#include <kactioncollection.h>
-#include <kxmlguifactory.h>
-#include <kparts/mainwindow.h>
-#include <ktexteditor/view.h>
-#include <ktexteditor/document.h>
-#include <ktexteditor/movinginterface.h>
-
 #include <sublime/area.h>
 #include <sublime/view.h>
 
@@ -37,6 +30,13 @@
 #include "../documentcontroller.h"
 #include "../uicontroller.h"
 
+#include <KActionCollection>
+#include <KXMLGUIFactory>
+#include <KParts/MainWindow>
+#include <KTextEditor/View>
+#include <KTextEditor/Document>
+#include <KTextEditor/MovingInterface>
+
 using namespace KDevelop;
 
 void TestShellDocumentOperation::initTestCase()
@@ -111,7 +111,7 @@ void TestShellDocumentOperation::testKateDocumentAndViewCreation()
 {
     //create one document
     IDocumentController *documentController = Core::self()->documentController();
-    documentController->openDocumentFromText(QLatin1String(""));
+    documentController->openDocumentFromText(QString());
     QCOMPARE(documentController->openDocuments().count(), 1);
 
     //assure we have only one kate view for the newly created document
