@@ -34,8 +34,6 @@
 #include <KTextEditor/ModificationInterface>
 #include <KTextEditor/CodeCompletionInterface>
 #include <KTextEditor/MarkInterface>
-#include <KTextEditor/ConfigInterface>
-#include <KTextEditor/SessionConfigInterface>
 
 #include <interfaces/context.h>
 #include <interfaces/contextmenuextension.h>
@@ -514,13 +512,13 @@ QString TextDocument::textWord() const
         int startPos = qMax( qMin( start.column(), linestr.length() - 1 ), 0 );
         int endPos = startPos;
         startPos --;
-        while( startPos >= 0 && ( linestr[startPos].isLetterOrNumber() || linestr[startPos] == '_' || linestr[startPos] == '~' ) )
-        {
+        while (startPos >= 0 &&
+               (linestr[startPos].isLetterOrNumber() || linestr[startPos] == QLatin1Char('_') || linestr[startPos] == QLatin1Char('~'))) {
             --startPos;
         }
 
-        while( endPos < linestr.length() && ( linestr[endPos].isLetterOrNumber() || linestr[endPos] == '_' || linestr[endPos] == '~' ) )
-        {
+        while (endPos < linestr.length() &&
+               (linestr[endPos].isLetterOrNumber() || linestr[endPos] == QLatin1Char('_') || linestr[endPos] == QLatin1Char('~'))) {
             ++endPos;
         }
         if( startPos != endPos )
@@ -545,19 +543,6 @@ void TextDocument::setTextSelection(const KTextEditor::Range &range)
     }
 }
 
-bool TextDocument::close(DocumentSaveMode mode)
-{
-    if (!PartDocument::close(mode))
-        return false;
-
-    if ( d->document ) {
-        d->saveSessionConfig();
-        delete d->document; //We have to delete the document right now, to prevent random crashes in the event handler
-    }
-
-    return true;
-}
-
 Sublime::View* TextDocument::newView(Sublime::Document* doc)
 {
     Q_UNUSED(doc);
@@ -584,29 +569,6 @@ QWidget * KDevelop::TextView::createWidget(QWidget * parent)
     return widget;
 }
 
-QString KDevelop::TextView::viewState() const
-{
-    if (d->view) {
-        if (d->view->selection()) {
-            KTextEditor::Range selection = d->view->selectionRange();
-            return QStringLiteral("Selection=%1,%2,%3,%4").arg(selection.start().line())
-                                                   .arg(selection.start().column())
-                                                   .arg(selection.end().line())
-                                                   .arg(selection.end().column());
-        } else {
-            KTextEditor::Cursor cursor = d->view->cursorPosition();
-            return QStringLiteral("Cursor=%1,%2").arg(cursor.line()).arg(cursor.column());
-        }
-    }
-    else {
-        KTextEditor::Range selection = d->initialRange;
-        return QStringLiteral("Selection=%1,%2,%3,%4").arg(selection.start().line())
-                                                   .arg(selection.start().column())
-                                                   .arg(selection.end().line())
-                                                   .arg(selection.end().column());
-    }
-}
-
 void KDevelop::TextView::setInitialRange(const KTextEditor::Range& range)
 {
     if (d->view) {
@@ -621,16 +583,20 @@ KTextEditor::Range KDevelop::TextView::initialRange() const
     return d->initialRange;
 }
 
-void KDevelop::TextView::setState(const QString & state)
+void KDevelop::TextView::readSessionConfig(KConfigGroup& config)
 {
-    static QRegExp reCursor("Cursor=([\\d]+),([\\d]+)");
-    static QRegExp reSelection("Selection=([\\d]+),([\\d]+),([\\d]+),([\\d]+)");
-    if (reCursor.exactMatch(state)) {
-        setInitialRange(KTextEditor::Range(KTextEditor::Cursor(reCursor.cap(1).toInt(), reCursor.cap(2).toInt()), 0));
-    } else if (reSelection.exactMatch(state)) {
-        KTextEditor::Range range(reSelection.cap(1).toInt(), reSelection.cap(2).toInt(), reSelection.cap(3).toInt(), reSelection.cap(4).toInt());
-        setInitialRange(range);
+    if (!d->view) {
+        return;
     }
+    d->view->readSessionConfig(config);
+}
+
+void KDevelop::TextView::writeSessionConfig(KConfigGroup& config)
+{
+    if (!d->view) {
+        return;
+    }
+    d->view->writeSessionConfig(config);
 }
 
 QString KDevelop::TextDocument::documentType() const
