@@ -65,8 +65,10 @@ namespace KDevelop {
 
 class UiControllerPrivate {
 public:
-    explicit UiControllerPrivate(UiController *controller)
-    : areasRestored(false), m_controller(controller)
+    UiControllerPrivate(Core* core, UiController* controller)
+        : core(core)
+        , areasRestored(false)
+        , m_controller(controller)
     {
         if (Core::self()->workingSetControllerInternal())
             Core::self()->workingSetControllerInternal()->initializeController(m_controller);
@@ -108,7 +110,7 @@ public:
 
         a = new Sublime::Area(m_controller, QStringLiteral("review"), i18n("Review"));
         a->setDesiredToolViews(desired);
-        a->setIconName(QStringLiteral("applications-engineering"));
+        a->setIconName(QStringLiteral("text-x-patch"));
         m_controller->addDefaultArea(a);
 
         if(!(Core::self()->setupFlags() & Core::NoUi))
@@ -137,7 +139,7 @@ public:
         }
     }
 
-    Core *core;
+    Core* const core;
     QPointer<MainWindow> defaultMainWindow;
 
     QHash<IToolViewFactory*, Sublime::ToolDocument*> factoryDocuments;
@@ -176,15 +178,17 @@ public:
 
     QString id() const override { return m_factory->id(); }
 private:
-    IToolViewFactory *m_factory;
+    IToolViewFactory* const m_factory;
 };
 
 
 class ViewSelectorItem: public QListWidgetItem {
 public:
-    explicit ViewSelectorItem(const QString &text, QListWidget *parent = nullptr, int type = Type)
-        :QListWidgetItem(text, parent, type) {}
-    IToolViewFactory *factory;
+    explicit ViewSelectorItem(const QString& text, IToolViewFactory* factory, QListWidget* parent = nullptr, int type = Type)
+        : QListWidgetItem(text, parent, type)
+        , factory(factory)
+    {}
+    IToolViewFactory* const factory;
 };
 
 
@@ -205,20 +209,19 @@ private Q_SLOTS:
     void addNewToolViewByDoubleClick(const QModelIndex& index)
     {
         QListWidgetItem *item = itemFromIndex(index);
-        // Disable item so that the toolview can not be added again.
+        // Disable item so that the tool view can not be added again.
         item->setFlags(item->flags() & ~Qt::ItemIsEnabled);
         emit addNewToolView(m_mw, item);
     }
 
 private:
-    MainWindow *m_mw;
+    MainWindow* const m_mw;
 };
 
 UiController::UiController(Core *core)
-    :Sublime::Controller(nullptr), IUiController(), d(new UiControllerPrivate(this))
+    :Sublime::Controller(nullptr), IUiController(), d(new UiControllerPrivate(core, this))
 {
     setObjectName(QStringLiteral("UiController"));
-    d->core = core;
 
     if (!defaultMainWindow() || (Core::self()->setupFlags() & Core::NoUi))
         return;
@@ -276,8 +279,8 @@ QWidget* UiController::findToolView(const QString& name, IToolViewFactory *facto
     if(!d->areasRestored || !activeArea())
         return nullptr;
 
-    QList< Sublime::View* > views = activeArea()->toolViews();
-    foreach(Sublime::View* view, views) {
+    const QList<Sublime::View*> views = activeArea()->toolViews();
+    for (Sublime::View* view : views) {
         Sublime::ToolDocument *doc = dynamic_cast<Sublime::ToolDocument*>(view->document());
         if(doc && doc->title() == name && view->widget()) {
             if(flags & Raise)
@@ -312,8 +315,8 @@ void UiController::raiseToolView(QWidget* toolViewWidget)
     if(!d->areasRestored)
         return;
 
-    QList< Sublime::View* > views = activeArea()->toolViews();
-    foreach(Sublime::View* view, views) {
+    const QList<Sublime::View*> views = activeArea()->toolViews();
+    for (Sublime::View* view : views) {
         if(view->widget() == toolViewWidget) {
             view->requestRaise();
             return;
@@ -445,10 +448,9 @@ void UiController::selectNewToolViewToAdd(MainWindow *mw)
     for (QHash<IToolViewFactory*, Sublime::ToolDocument*>::const_iterator it = d->factoryDocuments.constBegin();
         it != d->factoryDocuments.constEnd(); ++it)
     {
-        ViewSelectorItem *item = new ViewSelectorItem(it.value()->title(), list);
-        item->factory = it.key();
+        ViewSelectorItem *item = new ViewSelectorItem(it.value()->title(), it.key(), list);
         if (!item->factory->allowMultiple() && toolViewPresent(it.value(), mw->area())) {
-            // Disable item if the toolview is already present.
+            // Disable item if the tool view is already present.
             item->setFlags(item->flags() & ~Qt::ItemIsEnabled);
         }
         list->addItem(item);
@@ -494,6 +496,7 @@ void UiController::showSettingsDialog()
     auto analyzersPreferences = new AnalyzersPreferences(&cfgDlg);
     auto documentationPreferences = new DocumentationPreferences(&cfgDlg);
     auto runtimesPreferences = new RuntimesPreferences(&cfgDlg);
+    auto templateConfig = new TemplateConfig(&cfgDlg);
 
     const auto configPages = QVector<KDevelop::ConfigPage*> {
         new UiPreferences(&cfgDlg),
@@ -501,7 +504,7 @@ void UiController::showSettingsDialog()
         new SourceFormatterSettings(&cfgDlg),
         new ProjectPreferences(&cfgDlg),
         new EnvironmentPreferences(QString(), &cfgDlg),
-        new TemplateConfig(&cfgDlg),
+        templateConfig,
         editorConfigPage
     };
 
@@ -529,7 +532,7 @@ void UiController::showSettingsDialog()
         }
     };
 
-    cfgDlg.insertConfigPage(configPages[5], documentationPreferences);
+    cfgDlg.insertConfigPage(templateConfig, documentationPreferences);
     cfgDlg.insertConfigPage(documentationPreferences, analyzersPreferences);
     cfgDlg.insertConfigPage(analyzersPreferences, runtimesPreferences);
 
@@ -562,7 +565,7 @@ void UiController::saveArea(Sublime::Area * area, KConfigGroup & group)
 {
     area->save(group);
     if (!area->workingSet().isEmpty()) {
-        WorkingSet* set = Core::self()->workingSetControllerInternal()->getWorkingSet(area->workingSet());
+        WorkingSet* set = Core::self()->workingSetControllerInternal()->workingSet(area->workingSet());
         set->saveFromArea(area, area->rootIndex());
     }
 }
@@ -571,7 +574,7 @@ void UiController::loadArea(Sublime::Area * area, const KConfigGroup & group)
 {
     area->load(group);
     if (!area->workingSet().isEmpty()) {
-        WorkingSet* set = Core::self()->workingSetControllerInternal()->getWorkingSet(area->workingSet());
+        WorkingSet* set = Core::self()->workingSetControllerInternal()->workingSet(area->workingSet());
         Q_ASSERT(set->isConnected(area));
         Q_UNUSED(set);
     }
@@ -592,7 +595,7 @@ void UiController::saveAllAreas(const KSharedConfigPtr& config)
             // FIXME: using object name seems ugly.
             QString type = defaultArea->objectName();
             Sublime::Area* area = this->area(w, type);
-            KConfigGroup areaConfig(&mainWindowConfig, "Area " + type);
+            KConfigGroup areaConfig(&mainWindowConfig, QLatin1String("Area ") + type);
 
             areaConfig.deleteGroup();
             areaConfig.writeEntry("id", type);
@@ -613,9 +616,7 @@ void UiController::loadAllAreas(const KSharedConfigPtr& config)
     if (wc > mainWindows().size())
         wc = mainWindows().size();
 
-    QList<Sublime::Area*> changedAreas;
-
-    /* Offer all toolviews to the default areas.  */
+    /* Offer all tool views to the default areas.  */
     foreach (Sublime::Area *area, defaultAreas())
     {
         QHash<IToolViewFactory*, Sublime::ToolDocument*>::const_iterator i, e;
@@ -645,7 +646,7 @@ void UiController::loadAllAreas(const KSharedConfigPtr& config)
             QString type = defaultArea->objectName();
             Sublime::Area* area = this->area(w, type);
 
-            KConfigGroup areaConfig(&mainWindowConfig, "Area " + type);
+            KConfigGroup areaConfig(&mainWindowConfig, QLatin1String("Area ") + type);
 
             qCDebug(SHELL) << "Trying to restore area " << type;
 
@@ -658,7 +659,7 @@ void UiController::loadAllAreas(const KSharedConfigPtr& config)
                 loadArea(area, areaConfig);
             }
 
-            // At this point we know which toolviews the area wants.
+            // At this point we know which tool views the area wants.
             // Tender all tool views we have.
             QHash<IToolViewFactory*, Sublime::ToolDocument*>::const_iterator i, e;
             for (i = d->factoryDocuments.constBegin(),
