@@ -45,7 +45,6 @@ using namespace KDevelop;
 const int toolTipTimeout = 2000;
 
 WorkingSetController::WorkingSetController()
-    : m_emptyWorkingSet(nullptr), m_changingWorkingSet(false)
 {
     m_hideToolTipTimer = new QTimer(this);
     m_hideToolTipTimer->setInterval(toolTipTimeout);
@@ -59,10 +58,10 @@ void WorkingSetController::initialize()
     foreach(const QString& set, setConfig.groupList()) {
         // do not load working set if the id contains an '|', because it then belongs to an area.
         // this is functionally equivalent to the if ( ! config->icon ) stuff which was there before.
-        if ( set.contains('|') ) {
+        if (set.contains(QLatin1Char('|'))) {
             continue;
         }
-        getWorkingSet(set);
+        workingSet(set);
     }
 
     m_emptyWorkingSet = new WorkingSet(QStringLiteral("empty"));
@@ -105,7 +104,7 @@ const QString WorkingSetController::makeSetId(const QString& prefix) const
     for(uint retry = 2; retry <= maxRetries; retry++) {
         newId = QStringLiteral("%1_%2").arg(prefix).arg(qrand() % 10000000);
         WorkingSetIconParameters params(newId);
-        foreach(WorkingSet* set, m_workingSets) {
+        for (WorkingSet* set : m_workingSets) {
             if(set->isEmpty()) {
                 continue;
             }
@@ -124,10 +123,10 @@ const QString WorkingSetController::makeSetId(const QString& prefix) const
 
 WorkingSet* WorkingSetController::newWorkingSet(const QString& prefix)
 {
-    return getWorkingSet(makeSetId(prefix));
+    return workingSet(makeSetId(prefix));
 }
 
-WorkingSet* WorkingSetController::getWorkingSet(const QString& id)
+WorkingSet* WorkingSetController::workingSet(const QString& id)
 {
     if(id.isEmpty())
         return m_emptyWorkingSet;
@@ -182,7 +181,7 @@ void WorkingSetController::showGlobalToolTip()
 {
     KDevelop::MainWindow* window = static_cast<KDevelop::MainWindow*>(Core::self()->uiControllerInternal()->activeMainWindow());
 
-    showToolTip(getWorkingSet(window->area()->workingSet()),
+    showToolTip(workingSet(window->area()->workingSet()),
                               window->mapToGlobal(window->geometry().topRight()));
 
     connect(m_hideToolTipTimer, &QTimer::timeout,  m_tooltip.data(), &ActiveToolTip::deleteLater);
@@ -196,8 +195,7 @@ WorkingSetToolTipWidget* WorkingSetController::workingSetToolTip()
     if(!m_tooltip)
         showGlobalToolTip();
 
-    m_hideToolTipTimer->stop();
-    m_hideToolTipTimer->start(toolTipTimeout);
+    m_hideToolTipTimer->start();
 
     if(m_tooltip)
     {
@@ -237,7 +235,7 @@ QList< WorkingSet* > WorkingSetController::allWorkingSets() const
 void WorkingSetController::areaCreated( Sublime::Area* area )
 {
     if (!area->workingSet().isEmpty()) {
-        WorkingSet* set = getWorkingSet( area->workingSet() );
+        WorkingSet* set = workingSet( area->workingSet() );
         set->connectArea( area );
     }
 
@@ -258,7 +256,7 @@ void WorkingSetController::changingWorkingSet(Sublime::Area* area, const QString
         return;
 
     if (!from.isEmpty()) {
-        WorkingSet* oldSet = getWorkingSet(from);
+        WorkingSet* oldSet = workingSet(from);
         oldSet->disconnectArea(area);
         if (!oldSet->id().isEmpty()) {
             oldSet->saveFromArea(area, area->rootIndex());
@@ -273,7 +271,7 @@ void WorkingSetController::changedWorkingSet(Sublime::Area* area, const QString&
         return;
 
     if (!to.isEmpty()) {
-        WorkingSet* newSet = getWorkingSet(to);
+        WorkingSet* newSet = workingSet(to);
         newSet->connectArea(area);
         newSet->loadToArea(area, area->rootIndex());
     }else{
@@ -303,16 +301,16 @@ void WorkingSetController::viewAdded( Sublime::AreaIndex* , Sublime::View* )
 
 void WorkingSetController::clearWorkingSet(Sublime::Area * area)
 {
-    const QString workingSet = area->workingSet();
-    if (workingSet.isEmpty()) {
+    const QString workingSetId = area->workingSet();
+    if (workingSetId.isEmpty()) {
         // Nothing to do - area has no working set
         return;
     }
 
-    WorkingSet* set = getWorkingSet(workingSet);
+    WorkingSet* set = workingSet(workingSetId);
     set->deleteSet(true);
 
-    WorkingSet* newSet = getWorkingSet(workingSet);
+    WorkingSet* newSet = workingSet(workingSetId);
     newSet->connectArea(area);
     newSet->loadToArea(area, area->rootIndex());
     Q_ASSERT(newSet->fileList().isEmpty());
