@@ -50,8 +50,12 @@ QIcon generateIcon(const WorkingSetIconParameters& params)
     pixmap.fill(QColor::fromRgba(qRgba(0, 0, 0, 0)));
     const uint coloredCount = params.coloredCount;
     // coordinates of the rectangles to draw, for 16x16 icons specifically
-    QList<QRect> rects;
-    rects << QRect(1, 1, 5, 5) << QRect(1, 9, 5, 5) << QRect(9, 1, 5, 5) << QRect(9, 9, 5, 5);
+    QList<QRect> rects{
+        {1, 1, 5, 5},
+        {1, 9, 5, 5},
+        {9, 1, 5, 5},
+        {9, 9, 5, 5},
+    };
     if ( params.swapDiagonal ) {
         rects.swap(1, 2);
     }
@@ -147,7 +151,8 @@ void WorkingSet::saveFromArea( Sublime::Area* a, Sublime::AreaIndex * area, KCon
             setGroup.writeEntry(QStringLiteral("View %1").arg(index), docSpec);
             //The area specific config stores the working set documents in order along with their state
             areaGroup.writeEntry(QStringLiteral("View %1").arg(index), docSpec);
-            areaGroup.writeEntry(QStringLiteral("View %1 State").arg(index), view->viewState());
+            KConfigGroup viewGroup(&areaGroup, QStringLiteral("View %1 Config").arg(index));
+            view->writeSessionConfig(viewGroup);
             ++index;
         }
     }
@@ -207,6 +212,7 @@ void loadFileList(QStringList& ret, KConfigGroup group)
 
     } else {
         int viewCount = group.readEntry("View Count", 0);
+        ret.reserve(ret.size() + viewCount);
         for (int i = 0; i < viewCount; ++i) {
             QString specifier = group.readEntry(QStringLiteral("View %1").arg(i), QString());
 
@@ -247,7 +253,7 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex)
 
     KConfigGroup setConfig(Core::self()->activeSession()->config(), "Working File Sets");
     KConfigGroup setGroup = setConfig.group(m_id);
-    KConfigGroup areaGroup = setConfig.group(m_id + '|' + area->title());
+    KConfigGroup areaGroup = setConfig.group(m_id + QLatin1Char('|') + area->title());
 
     loadToArea(area, areaIndex, setGroup, areaGroup, recycle);
 
@@ -279,7 +285,7 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex)
     }
 }
 
-void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex, KConfigGroup setGroup, KConfigGroup areaGroup, QMultiMap<QString, Sublime::View*>& recycle)
+void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex, const KConfigGroup& setGroup, const KConfigGroup& areaGroup, QMultiMap<QString, Sublime::View*>& recycle)
 {
     Q_ASSERT( !areaIndex->isSplit() );
     if (setGroup.hasKey("Orientation")) {
@@ -339,9 +345,9 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
         //Load state
         for (int i = 0; i < viewCount; ++i)
         {
-            QString state = areaGroup.readEntry(QStringLiteral("View %1 State").arg(i));
-            if (!state.isEmpty() && createdViews.contains(i))
-                createdViews[i]->setState(state);
+            KConfigGroup viewGroup(&areaGroup, QStringLiteral("View %1 Config").arg(i));
+            if (viewGroup.exists() && createdViews.contains(i))
+                createdViews[i]->readSessionConfig(viewGroup);
         }
     }
 }
@@ -390,7 +396,7 @@ void WorkingSet::saveFromArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex
     KConfigGroup setGroup = setConfig.group(m_id);
     deleteGroupRecursive(setGroup);
 
-    KConfigGroup areaGroup = setConfig.group(m_id + '|' + area->title());
+    KConfigGroup areaGroup = setConfig.group(m_id + QLatin1Char('|') + area->title());
     QString lastActiveView = areaGroup.readEntry("Active View", "");
     deleteGroupRecursive(areaGroup);
     if (area->activeView() && area->activeView()->document())
@@ -497,12 +503,12 @@ bool WorkingSet::hasConnectedAreas() const
   return !m_areas.isEmpty();
 }
 
-bool WorkingSet::hasConnectedAreas( QList< Sublime::Area* > areas ) const
+bool WorkingSet::hasConnectedAreas(const QList<Sublime::Area*>& areas) const
 {
-  foreach( Sublime::Area* area, areas )
-
-  if ( m_areas.contains( area ) )
-    return true;
+    for (Sublime::Area* area : areas) {
+        if (m_areas.contains(area))
+            return true;
+    }
 
   return false;
 }
@@ -552,7 +558,7 @@ void WorkingSet::changed( Sublime::Area* area )
     qCDebug(SHELL) << "recording change done to" << m_id;
     saveFromArea( area, area->rootIndex() );
 
-    for ( QList< QPointer< Sublime::Area > >::iterator it = m_areas.begin(); it != m_areas.end(); ++it ) {
+    for (auto it = m_areas.begin(); it != m_areas.end(); ++it ) {
       if (( *it ) != area ) {
         loadToArea(( *it ), ( *it )->rootIndex() );
       }
