@@ -43,7 +43,8 @@
 
 #include "view.h"
 #include "urldocument.h"
-#include <ksqueezedtextlabel.h>
+
+#include <KSqueezedTextLabel>
 
 namespace Sublime {
 
@@ -127,7 +128,7 @@ Q_SIGNALS:
     void newTabRequested();
 
 private:
-    Container* m_container;
+    Container* const m_container;
 };
 
 bool sortViews(const View* const lhs, const View* const rhs)
@@ -193,9 +194,9 @@ public:
                 }
                 else {
                     auto url = urlDoc->url().toString();
-                    int secondOffset = url.lastIndexOf('/');
-                    secondOffset = url.lastIndexOf('/', secondOffset - 1);
-                    visibleEntryTitle = url.right(url.length() - url.lastIndexOf('/', secondOffset) - 1);
+                    int secondOffset = url.lastIndexOf(QLatin1Char('/'));
+                    secondOffset = url.lastIndexOf(QLatin1Char('/'), secondOffset - 1);
+                    visibleEntryTitle = url.right(url.length() - url.lastIndexOf(QLatin1Char('/'), secondOffset) - 1);
                 }
             } else {
                 visibleEntryTitle = view->document()->title();
@@ -687,7 +688,7 @@ void Container::contextMenu( const QPoint& pos )
             }
             // finally close other tabs
             foreach( QWidget* tab, otherTabs ) {
-                requestClose(tab);
+                emit requestClose(tab);
             }
         } else if ( triggered == closeAllTabsAction ) {
             // activate last tab
@@ -695,7 +696,7 @@ void Container::contextMenu( const QPoint& pos )
 
             // close all
             for ( int i = 0; i < count(); ++i ) {
-                requestClose(widget(i));
+                emit requestClose(widget(i));
             }
         } else if( triggered == copyPathAction ) {
             auto view = viewForWidget( widget( currentTab ) );
