@@ -73,12 +73,12 @@ MainWindow::~MainWindow()
     qCDebug(SUBLIME) << "destroying mainwindow";
 }
 
-void MainWindow::reconstructViews(QList<View*> topViews)
+void MainWindow::reconstructViews(const QList<View*>& topViews)
 {
     d->reconstructViews(topViews);
 }
 
-QList<View*> MainWindow::getTopViews() const
+QList<View*> MainWindow::topViews() const
 {
     QList<View*> topViews;
     foreach(View* view, d->area->views())
@@ -146,12 +146,7 @@ void MainWindow::setArea(Area *area)
 void MainWindow::initializeStatusBar()
 {
     //nothing here, reimplement in the subclasses if you want to have status bar
-    //inside the bottom toolview buttons row
-}
-
-void MainWindow::resizeEvent(QResizeEvent* event)
-{
-    return KParts::MainWindow::resizeEvent(event);
+    //inside the bottom tool view buttons row
 }
 
 void MainWindow::clearArea()
@@ -187,9 +182,16 @@ View *MainWindow::activeToolView() const
 
 void MainWindow::activateView(Sublime::View* view, bool focus)
 {
-    if (!d->viewContainers.contains(view) || d->activeView == view)
+    if (!d->viewContainers.contains(view))
         return;
 
+    if (d->activeView == view)
+    {
+        if (focus && view && !view->widget()->hasFocus())
+            view->widget()->setFocus();
+        return;
+    }
+
     d->viewContainers[view]->setCurrentWidget(view->widget());
 
     setActiveView(view, focus);
@@ -220,7 +222,7 @@ void MainWindow::saveSettings()
     d->disableConcentrationMode();
     QString group = QStringLiteral("MainWindow");
     if (area())
-        group += '_' + area()->objectName();
+        group += QLatin1Char('_') + area()->objectName();
     KConfigGroup cg = KSharedConfig::openConfig()->group(group);
     // This will try to save also the window size and the enabled state of the statusbar.
     // But it's OK, since we won't use this information when loading.
@@ -244,10 +246,10 @@ void MainWindow::loadSettings()
 {
     HoldUpdates hu(this);
 
-    qCDebug(SUBLIME) << "loading settings for " << (area() ? area()->objectName() : QLatin1String(""));
+    qCDebug(SUBLIME) << "loading settings for " << (area() ? area()->objectName() : QString());
     QString group = QStringLiteral("MainWindow");
     if (area())
-        group += '_' + area()->objectName();
+        group += QLatin1Char('_') + area()->objectName();
     KConfigGroup cg = KSharedConfig::openConfig()->group(group);
 
     // What follows is copy-paste from applyMainWindowSettings.  Unfortunately,
@@ -299,7 +301,7 @@ void MainWindow::loadSettings()
         QString group(QStringLiteral("Toolbar"));
         // Give a number to the toolbar, but prefer a name if there is one,
         // because there's no real guarantee on the ordering of toolbars
-        group += (toolbar->objectName().isEmpty() ? QString::number(n) : QStringLiteral(" ")+toolbar->objectName());
+        group += (toolbar->objectName().isEmpty() ? QString::number(n) : QLatin1Char(' ')+toolbar->objectName());
 
         KConfigGroup toolbarGroup(&cg, group);
         toolbar->applySettings(toolbarGroup);
@@ -352,7 +354,7 @@ QString MainWindow::screenKey() const
         .arg(desk.width()).arg(desk.height());
 }
 
-void MainWindow::saveGeometry(KConfigGroup &config)
+void MainWindow::saveGeometry(KConfigGroup &config) const
 {
     config.writeEntry(screenKey(), geometry());
 
@@ -379,7 +381,7 @@ QWidget *MainWindow::statusBarLocation() const
     return d->idealController->statusBarLocation();
 }
 
-QWidget *MainWindow::viewBarContainer() const
+ViewBarContainer *MainWindow::viewBarContainer() const
 {
     return d->viewBarContainer;
 }
