@@ -36,6 +36,7 @@
 #include "container.h"
 #include "controller.h"
 #include "mainwindow.h"
+#include "viewbarcontainer.h"
 #include "idealcontroller.h"
 #include "holdupdates.h"
 #include "idealbuttonbarwidget.h"
@@ -70,7 +71,7 @@ class IdealToolBar : public QToolBar
         }
 
     private:
-        Sublime::IdealButtonBarWidget* m_buttons;
+        Sublime::IdealButtonBarWidget* const m_buttons;
         const bool m_hideWhenEmpty;
 };
 
@@ -162,7 +163,7 @@ MainWindowPrivate::MainWindowPrivate(MainWindow *w, Controller* controller)
 
     // this view bar container is used for the ktexteditor integration to show
     // all view bars at a central place, esp. for split view configurations
-    viewBarContainer = new QWidget;
+    viewBarContainer = new ViewBarContainer;
     viewBarContainer->setObjectName(QStringLiteral("viewBarContainer"));
     // hide by default
     viewBarContainer->setVisible(false);
@@ -177,11 +178,6 @@ MainWindowPrivate::MainWindowPrivate(MainWindow *w, Controller* controller)
             this,
             &MainWindowPrivate::slotDockShown);
 
-    connect(idealController,
-            &IdealController::widgetResized,
-            this,
-            &MainWindowPrivate::widgetResized);
-
     connect(idealController, &IdealController::dockBarContextMenuRequested,
             m_mainWindow, &MainWindow::dockBarContextMenuRequested);
 }
@@ -424,7 +420,7 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
     return Area::ContinueWalker;
 }
 
-void MainWindowPrivate::reconstructViews(QList<View*> topViews)
+void MainWindowPrivate::reconstructViews(const QList<View*>& topViews)
 {
     ViewCreator viewCreator(this, topViews);
     area->walkViews(viewCreator, area->rootIndex());
@@ -466,7 +462,7 @@ void MainWindowPrivate::clearArea()
     if(m_leftTabbarCornerWidget)
         m_leftTabbarCornerWidget->setParent(nullptr);
 
-    //reparent toolview widgets to 0 to prevent their deletion together with dockwidgets
+    //reparent tool view widgets to nullptr to prevent their deletion together with dockwidgets
     foreach (View *view, area->toolViews())
     {
         // FIXME should we really delete here??
@@ -523,6 +519,7 @@ void MainWindowPrivate::slotDockShown(Sublime::View* /*view*/, Sublime::Position
     m_mainWindow->area()->walkToolViews(finder, pos);
 
     QStringList ids;
+    ids.reserve(finder.views.size());
     foreach (View *v, finder.views) {
         ids << v->document()->documentSpecifier();
     }
@@ -616,8 +613,10 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
             container->removeWidget(view->widget());
             view->widget()->setParent(nullptr);
             //activate what is visible currently in the container if the removed view was active
-            if (wasActive)
-                return m_mainWindow->setActiveView(container->viewForWidget(container->currentWidget()));
+            if (wasActive) {
+                m_mainWindow->setActiveView(container->viewForWidget(container->currentWidget()));
+                return;
+            }
         }
     }
     else
@@ -744,12 +743,6 @@ Qt::DockWidgetArea MainWindowPrivate::positionToDockArea(Position position)
     }
 }
 
-void MainWindowPrivate::switchToArea(QAction *action)
-{
-    qCDebug(SUBLIME) << "for" << action;
-    controller->showArea(m_actionAreas.value(action), m_mainWindow);
-}
-
 void MainWindowPrivate::updateAreaSwitcher(Sublime::Area *area)
 {
     QAction* action = m_areaActions.value(area);
@@ -764,11 +757,6 @@ void MainWindowPrivate::activateFirstVisibleView()
         m_mainWindow->activateView(views.first());
 }
 
-void MainWindowPrivate::widgetResized(Qt::DockWidgetArea /*dockArea*/, int /*thickness*/)
-{
-    //TODO: adymo: remove all thickness business
-}
-
 void MainWindowPrivate::widgetCloseRequest(QWidget* widget)
 {
     if (View *view = widgetToView.value(widget))
