@@ -55,7 +55,7 @@ public:
         explicit IdealToolViewCreator(MainWindowPrivate *_d): d(_d) {}
         Area::WalkerMode operator() (View *view, Sublime::Position position);
     private:
-        MainWindowPrivate *d;
+        MainWindowPrivate* const d;
     };
 
     /**Use this to create views for an area.*/
@@ -64,14 +64,14 @@ public:
         explicit ViewCreator(MainWindowPrivate *_d, const QList<View*>& _topViews = QList<View*>()): d(_d), topViews(_topViews.toSet()) {}
         Area::WalkerMode operator() (AreaIndex *index);
     private:
-        MainWindowPrivate *d;
-        QSet<View*> topViews;
+        MainWindowPrivate* const d;
+        const QSet<View*> topViews;
     };
 
     /**Reconstructs the mainwindow according to the current area.*/
     void reconstruct();
     /**Reconstructs the views according to the current area index.*/
-    void reconstructViews(QList<View*> topViews = QList<View*>());    
+    void reconstructViews(const QList<View*>& topViews = QList<View*>());
     /**Clears the area leaving mainwindow empty.*/
     void clearArea();
     
@@ -80,7 +80,7 @@ public:
 
     void activateFirstVisibleView();
 
-    Controller *controller;
+    Controller* const controller;
     Area *area;
     QList<View*> docks;
     QMap<View*, Container*> viewContainers;
@@ -91,7 +91,7 @@ public:
 
     QWidget *centralWidget;
     QWidget* bgCentralWidget;
-    QWidget* viewBarContainer;
+    ViewBarContainer* viewBarContainer;
     QSplitter* splitterCentralWidget;
 
     IdealController *idealController;
@@ -115,10 +115,8 @@ public Q_SLOTS:
     void setTabBarLeftCornerWidget(QWidget* widget);
 
 private Q_SLOTS:
-    void switchToArea(QAction *action);
     void updateAreaSwitcher(Sublime::Area *area);
     void slotDockShown(Sublime::View*, Sublime::Position, bool);
-    void widgetResized(Qt::DockWidgetArea dockArea, int thickness);
     void widgetCloseRequest(QWidget* widget);
 
     void showLeftDock(bool b);
@@ -135,12 +133,11 @@ private:
     Qt::DockWidgetArea positionToDockArea(Position position);
     void cleanCentralWidget();
 
-    MainWindow *m_mainWindow;
+    MainWindow* const m_mainWindow;
     // uses QPointer to make already-deleted splitters detectable
     QMap<AreaIndex*, QPointer<QSplitter> > m_indexSplitters;
 
     QMap<Area*, QAction*> m_areaActions;
-    QMap<QAction*, Area*> m_actionAreas;
     QPointer<QWidget> m_leftTabbarCornerWidget;
     QPointer<QToolBar> m_concentrateToolBar;
     IdealToolBar* m_bottomToolBar;
