@@ -58,9 +58,7 @@ void messageOutput(QtMsgType type, const QMessageLogContext& context, const QStr
     Q_UNUSED(context);
 
     switch (type) {
-#if QT_VERSION >= 0x050500
         case QtInfoMsg: // fall-through
-#endif
         case QtDebugMsg:
             if(verbose)
                 std::cerr << qPrintable(msg) << std::endl;
@@ -85,7 +83,6 @@ Manager::Manager(QCommandLineParser* args) : m_total(0), m_args(args), m_allFile
 
 void Manager::init()
 {
-    QList<QUrl> includes;
     if(m_args->positionalArguments().isEmpty()) {
         std::cerr << "Need file or directory to duchainify" << std::endl;
         QCoreApplication::exit(1);
@@ -253,7 +250,7 @@ void Manager::addToBackgroundParser(const QString& path, TopDUContext::Features
         QDirIterator contents(path);
         while(contents.hasNext()) {
             QString newPath = contents.next();
-            if(!newPath.endsWith('.'))
+            if(!newPath.endsWith(QLatin1Char('.')))
                 addToBackgroundParser(newPath, features);
         }
     }
@@ -274,19 +271,16 @@ using namespace KDevelop;
 
 int main(int argc, char** argv)
 {
+    QApplication app(argc, argv);
+
     KAboutData aboutData( QStringLiteral("duchainify"), i18n( "duchainify" ),
                           QStringLiteral("1"), i18n("DUChain builder application"), KAboutLicense::GPL,
                           i18n( "(c) 2009 David Nolden" ), QString(), QStringLiteral("http://www.kdevelop.org") );
-
-    QApplication app(argc, argv);
     KAboutData::setApplicationData(aboutData);
 
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
 
-    parser.addVersionOption();
-    parser.addHelpOption();
-
     parser.addPositionalArgument(QStringLiteral("paths"), i18n("file or directory"), QStringLiteral("[PATH...]"));
 
     parser.addOption(QCommandLineOption{QStringList{QStringLiteral("w"), QStringLiteral("warnings")}, i18n("Show warnings")});
