@@ -25,11 +25,12 @@
 #include <QUrl>
 #include <QFile>
 #include <QList>
-#include <KLocalizedString>
-#include <KMessageBox>
 #include <interfaces/icore.h>
 #include <interfaces/iuicontroller.h>
-#include <kparts/mainwindow.h>
+
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KParts/MainWindow>
 
 namespace KDevelop {
 
@@ -68,7 +69,7 @@ bool askUser( const QString& mainText,
         auto rejectButton = KStandardGuiItem::cancel();
         rejectButton.setText(rejectText);
         int userAnswer = KMessageBox::questionYesNo( ICore::self()->uiController()->activeMainWindow(),
-                                                     mainText + "\n\n" + mboxAdditionalText,
+                                                     mainText + QLatin1String("\n\n") + mboxAdditionalText,
                                                      mboxTitle,
                                                      okButton,
                                                      rejectButton );
@@ -79,8 +80,7 @@ bool askUser( const QString& mainText,
 bool ensureWritable( const QList<QUrl> &urls )
 {
     QStringList notWritable;
-    foreach (const QUrl& url, urls)
-    {
+    for (const QUrl& url : urls) {
         if (url.isLocalFile())
         {
             QFile file(url.toLocalFile());
@@ -93,7 +93,7 @@ bool ensureWritable( const QList<QUrl> &urls )
     if (!notWritable.isEmpty())
     {
         int answer = KMessageBox::questionYesNoCancel(ICore::self()->uiController()->activeMainWindow(),
-            i18n("You don't have write permissions for the following files; add write permissions for owner before saving?")+"\n\n"+notWritable.join(QStringLiteral("\n")),
+            i18n("You don't have write permissions for the following files; add write permissions for owner before saving?") + QLatin1String("\n\n") + notWritable.join(QLatin1Char('\n')),
             i18n("Some files are write-protected"),
             KStandardGuiItem::yes(), KStandardGuiItem::no(), KStandardGuiItem::cancel());
         if (answer == KMessageBox::Yes) {
