@@ -76,7 +76,7 @@ QVariant VcsBasicEventModel::data(const QModelIndex& idx, int role) const
             return QVariant( ev.revision().revisionValue() );
         case SummaryColumn:
             // show the first line only
-            return QVariant( ev.message().section('\n', 0, 0) );
+            return QVariant( ev.message().section(QLatin1Char('\n'), 0, 0) );
         case AuthorColumn:
             return QVariant( ev.author() );
         case DateColumn:
@@ -166,14 +166,13 @@ void VcsEventLogModel::fetchMore(const QModelIndex& parent)
 
 void VcsEventLogModel::jobReceivedResults(KJob* job)
 {
-    QList<QVariant> l = qobject_cast<KDevelop::VcsJob *>(job)->fetchResults().toList();
+    const QList<QVariant> l = qobject_cast<KDevelop::VcsJob *>(job)->fetchResults().toList();
     if(l.isEmpty() || job->error()!=0) {
         d->done = true;
         return;
     }
     QList<KDevelop::VcsEvent> newevents;
-    foreach( const QVariant &v, l )
-    {
+    for (const QVariant& v : l) {
         if( v.canConvert<KDevelop::VcsEvent>() )
         {
             newevents << v.value<KDevelop::VcsEvent>();
