@@ -49,6 +49,7 @@
 #include <vcs/widgets/vcscommitdialog.h>
 #include <vcs/vcsjob.h>
 #include <vcs/vcsrevision.h>
+#include <vcs/vcslocation.h>
 #include <vcs/vcsdiff.h>
 
 #include "interfaces/idistributedversioncontrol.h"
@@ -107,7 +108,7 @@ public:
     bool allLocalFiles(const QList<QUrl>& urls)
     {
         bool ret=true;
-        foreach(const QUrl &url, urls) {
+        for (const QUrl& url : urls) {
             QFileInfo info(url.toLocalFile());
             ret &= info.isFile();
         }
@@ -251,9 +252,9 @@ void VcsPluginHelper::revertDone(KJob* job)
 void VcsPluginHelper::delayedModificationWarningOn()
 {
     QObject* timer = sender();
-    QList<QUrl> urls = timer->property("urls").value<QList<QUrl>>();
+    const QList<QUrl> urls = timer->property("urls").value<QList<QUrl>>();
 
-    foreach(const QUrl &url, urls) {
+    for (const QUrl& url : urls) {
         IDocument* doc=ICore::self()->documentController()->documentForUrl(url);
 
         if(doc) {
@@ -429,7 +430,7 @@ void VcsPluginHelper::annotationContextMenuAboutToShow( KTextEditor::View* view,
     menu->addAction(d->diffForRevAction);
     menu->addAction(d->diffForRevGlobalAction);
 
-    QAction* copyAction = menu->addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy Revision"));
+    QAction* copyAction = menu->addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy Revision Id"));
     connect(copyAction, &QAction::triggered, this, [rev]() {
         QApplication::clipboard()->setText(rev.revisionValue().toString());
     });
