@@ -36,7 +36,7 @@ VcsRevision VcsRevision::createSpecialRevision( KDevelop::VcsRevision::RevisionS
     return rev;
 }
 
-class VcsRevisionPrivate
+class VcsRevisionPrivate : public QSharedData
 {
     public:
         QVariant value;
@@ -51,22 +51,15 @@ VcsRevision::VcsRevision()
 }
 
 VcsRevision::VcsRevision( const VcsRevision& rhs )
-    : d(new VcsRevisionPrivate)
+    : d(rhs.d)
 {
-    d->value = rhs.d->value;
-    d->internalValues = rhs.d->internalValues;
-    d->type = rhs.d->type;
 }
 
 VcsRevision::~VcsRevision() = default;
 
 VcsRevision& VcsRevision::operator=( const VcsRevision& rhs)
 {
-    if(this == &rhs)
-        return *this;
-    d->value = rhs.d->value;
-    d->type = rhs.d->type;
-    d->internalValues = rhs.d->internalValues;
+    d = rhs.d;
     return *this;
 }
 
@@ -97,7 +90,7 @@ QStringList VcsRevision::keys() const
     return d->internalValues.keys();
 }
 
-QVariant VcsRevision::getValue( const QString& key ) const
+QVariant VcsRevision::value(const QString& key) const
 {
     if( d->internalValues.contains(key) )
     {
@@ -175,6 +168,22 @@ QString VcsRevision::prettyValue() const
 
 uint KDevelop::qHash( const KDevelop::VcsRevision& rev)
 {
-    return rev.revisionValue().toULongLong();
+    const auto revisionValue = rev.revisionValue();
+    switch (rev.revisionType()) {
+        case VcsRevision::GlobalNumber:
+        case VcsRevision::FileNumber:
+            return (revisionValue.type() == QVariant::String ? ::qHash(revisionValue.toString()) :
+                    ::qHash(revisionValue.toULongLong()));
+            break;
+        case VcsRevision::Special:
+            return ::qHash(static_cast<int>(revisionValue.value<KDevelop::VcsRevision::RevisionSpecialType>()));
+            break;
+        case VcsRevision::Date:
+            return ::qHash(revisionValue.toDateTime());
+            break;
+        default:
+            break;
+    }
+    return ::qHash(revisionValue.toString());
 }
 
