@@ -115,7 +115,7 @@ void VCSCommitDiffPatchSource::jobFinished(KJob *job)
     {
         QString details = job ? job->errorText() : QString();
         if (details.isEmpty()) {    //errorText may be empty
-            details = i18n("For more detailed information please see the Version Control toolview");
+            details = i18n("For more detailed information please see the Version Control tool view.");
         }
         KMessageBox::detailedError(nullptr, i18n("Unable to commit"), details, i18n("Commit unsuccessful"));
     }
@@ -137,8 +137,9 @@ VCSDiffPatchSource::VCSDiffPatchSource(VCSDiffUpdater* updater)
     {
         varlist = statusJob->fetchResults();
 
-        foreach( const QVariant &var, varlist.toList() )
-        {
+        const auto vars = varlist.toList();
+        m_infos.reserve(m_infos.size() + vars.size());
+        for (const auto& var : vars) {
             VcsStatusInfo info = var.value<KDevelop::VcsStatusInfo>();
 
             m_infos += info;
@@ -248,8 +249,8 @@ void VCSCommitDiffPatchSource::cancelReview() {
     deleteLater();
 }
 
-bool VCSCommitDiffPatchSource::finishReview(QList< QUrl > selection) {
-
+bool VCSCommitDiffPatchSource::finishReview(const QList<QUrl>& selection)
+{
     QString message;
 
     if (m_commitMessageEdit)
@@ -257,8 +258,10 @@ bool VCSCommitDiffPatchSource::finishReview(QList< QUrl > selection) {
 
     qCDebug(VCS) << "Finishing with selection" << selection;
     QString files;
-    foreach(const QUrl& url, selection)
-        files += "<li>"+ICore::self()->projectController()->prettyFileName(url, KDevelop::IProjectController::FormatPlain) + "</li>";
+    files.reserve(selection.size());
+    for (const QUrl& url : selection) {
+        files += QLatin1String("<li>") + ICore::self()->projectController()->prettyFileName(url, KDevelop::IProjectController::FormatPlain) + QLatin1String("</li>");
+    }
 
     QString text = i18n("<qt>Files will be committed:\n<ul>%1</ul>\nWith message:\n <pre>%2</pre></qt>", files, message);
 
@@ -309,7 +312,10 @@ VcsDiff VCSStandardDiffUpdater::update() const
     return diffJob->fetchResults().value<VcsDiff>();
 }
 
-VCSStandardDiffUpdater::VCSStandardDiffUpdater(IBasicVersionControl* vcs, QUrl url) : m_vcs(vcs), m_url(url) {
+VCSStandardDiffUpdater::VCSStandardDiffUpdater(IBasicVersionControl* vcs, const QUrl& url)
+    : m_vcs(vcs)
+    , m_url(url)
+{
 }
 
 VCSStandardDiffUpdater::~VCSStandardDiffUpdater() {
