@@ -42,8 +42,9 @@
 #include "codegen/clangclasshelper.h"
 #include "codegen/adaptsignatureassistant.h"
 #include "duchain/documentfinderhelpers.h"
-#include "duchain/clangindex.h"
 #include "duchain/navigationwidget.h"
+#include "duchain/clangindex.h"
+#include "duchain/clanghelpers.h"
 #include "duchain/macrodefinition.h"
 #include "duchain/clangparsingenvironmentfile.h"
 #include "duchain/duchainutils.h"
@@ -176,8 +177,10 @@ ClangSupport::ClangSupport(QObject* parent, const QVariantList& )
     , m_refactoring(nullptr)
     , m_index(nullptr)
 {
+    clangDebug() << "Detected Clang version:" << ClangHelpers::clangVersion();
+
     {
-        const auto builtinDir = ClangIntegration::DUChainUtils::clangBuiltinIncludePath();
+        const auto builtinDir = ClangHelpers::clangBuiltinIncludePath();
         const auto headerToCheck = QLatin1String("cpuid.h");
         if (!QFile::exists(builtinDir + QLatin1Char('/') + headerToCheck)) {
             setErrorDescription(i18n("The clang builtin include path \"%1\" is invalid (missing %2 header).\n"
@@ -196,7 +199,6 @@ ClangSupport::ClangSupport(QObject* parent, const QVariantList& )
     m_index.reset(new ClangIndex);
 
     auto model = new KDevelop::CodeCompletion( this, new ClangCodeCompletionModel(m_index.data(), this), name() );
-    // TODO: use direct signal/slot connect syntax for 5.1
     connect(model, &CodeCompletion::registeredToView,
             this, &ClangSupport::disableKeywordCompletion);
     connect(model, &CodeCompletion::unregisteredFromView,
@@ -340,7 +342,7 @@ QPair<QUrl, KTextEditor::Cursor> ClangSupport::specialLanguageObjectJumpCursor(c
     return {{}, KTextEditor::Cursor::invalid()};
 }
 
-QWidget* ClangSupport::specialLanguageObjectNavigationWidget(const QUrl &url, const KTextEditor::Cursor& position)
+QPair<QWidget*, KTextEditor::Range> ClangSupport::specialLanguageObjectNavigationWidget(const QUrl& url, const KTextEditor::Cursor& position)
 {
     DUChainReadLocker lock;
     const QPair<TopDUContextPointer, Use> macroExpansion = macroExpansionForPosition(url, position);
@@ -349,15 +351,18 @@ QWidget* ClangSupport::specialLanguageObjectNavigationWidget(const QUrl &url, co
         const MacroDefinition::Ptr macroDefinition(dynamic_cast<MacroDefinition*>(declaration));
         Q_ASSERT(macroDefinition);
         auto rangeInRevision = macroExpansion.first->transformFromLocalRevision(macroExpansion.second.m_range.start);
-        return new ClangNavigationWidget(macroDefinition, DocumentCursor(IndexedString(url), rangeInRevision));
+        return {
+            new ClangNavigationWidget(macroDefinition, DocumentCursor(IndexedString(url), rangeInRevision)),
+            macroExpansion.second.m_range.castToSimpleRange()
+        };
     }
 
     const QPair<TopDUContextPointer, KTextEditor::Range> import = importedContextForPosition(url, position);
 
     if (import.first) {
-        return import.first->createNavigationWidget();
+        return {import.first->createNavigationWidget(), import.second};
     }
-    return nullptr;
+    return {nullptr, KTextEditor::Range::invalid()};
 }
 
 TopDUContext* ClangSupport::standardContext(const QUrl &url, bool /*proxyContext*/)
