@@ -58,7 +58,11 @@ Signature getDeclarationSignature(const Declaration *functionDecl, const DUConte
     int pos = 0;
     Signature signature;
     const AbstractFunctionDeclaration* abstractFunDecl = dynamic_cast<const AbstractFunctionDeclaration*>(functionDecl);
-    foreach(Declaration * parameter, functionCtxt->localDeclarations()) {
+    const auto localDeclarations = functionCtxt->localDeclarations();
+    const int localDeclarationsCount = localDeclarations.size();
+    signature.defaultParams.reserve(localDeclarationsCount);
+    signature.parameters.reserve(localDeclarationsCount);
+    for (Declaration * parameter : localDeclarations) {
         signature.defaultParams << (includeDefaults ? abstractFunDecl->defaultParameterForArgument(pos).str() : QString());
         signature.parameters << qMakePair(parameter->indexedType(), parameter->identifier().identifier().str());
         ++pos;
@@ -145,7 +149,7 @@ void AdaptSignatureAssistant::textChanged(KTextEditor::Document* doc, const KTex
         clangDebug() << "no other side for signature found";
         return;
     }
-    m_otherSideContext = DUContextPointer(DUChainUtils::getFunctionContext(otherSide));
+    m_otherSideContext = DUContextPointer(DUChainUtils::functionContext(otherSide));
     if (!m_otherSideContext) {
         clangDebug() << "no context for other side found";
         return;
@@ -167,6 +171,7 @@ bool AdaptSignatureAssistant::isUseful() const
 bool AdaptSignatureAssistant::getSignatureChanges(const Signature& newSignature, QList<int>& oldPositions) const
 {
     bool changed = false;
+    oldPositions.reserve(oldPositions.size() + newSignature.parameters.size());
     for (int i = 0; i < newSignature.parameters.size(); ++i) {
         oldPositions.append(-1);
     }
@@ -240,7 +245,7 @@ QList<RenameAction*> AdaptSignatureAssistant::getRenameActions(const Signature &
         }
         Declaration *renamedDecl = m_otherSideContext->localDeclarations()[oldPositions[i]];
         if (newSignature.parameters[i].second != m_oldSignature.parameters[oldPositions[i]].second) {
-            QMap<IndexedString, QList<RangeInRevision> > uses = renamedDecl->uses();
+            const auto uses = renamedDecl->uses();
             if (!uses.isEmpty()) {
                 renameActions << new RenameAction(renamedDecl->identifier(), newSignature.parameters[i].second,
                                                   RevisionedFileRanges::convert(uses));
@@ -265,7 +270,7 @@ void AdaptSignatureAssistant::updateReady(const KDevelop::IndexedString& documen
         clangDebug() << "No function found at" << m_document->url() << m_lastEditPosition;
         return;
     }
-    DUContext *functionCtxt = DUChainUtils::getFunctionContext(functionDecl);
+    DUContext *functionCtxt = DUChainUtils::functionContext(functionDecl);
     if (!functionCtxt) {
         clangDebug() << "No function context found for" << functionDecl->toString();
         return;
