@@ -28,6 +28,7 @@
 
 #include <language/duchain/duchainlock.h>
 #include <language/codegen/documentchangeset.h>
+#include <qtcompat_p.h>
 
 #include <KLocalizedString>
 
@@ -71,11 +72,11 @@ ClangFixits fixitsForDiagnostic(CXDiagnostic diagnostic)
 {
     ClangFixits fixits;
     auto numFixits = clang_getDiagnosticNumFixIts(diagnostic);
+    fixits.reserve(numFixits);
     for (uint i = 0; i < numFixits; ++i) {
         CXSourceRange range;
         const QString replacementText = ClangString(clang_getDiagnosticFixIt(diagnostic, i, &range)).toString();
 
-        auto location = ClangString(clang_formatDiagnostic(diagnostic, CXDiagnostic_DisplaySourceLocation)).toString();
         const auto docRange = ClangRange(range).toDocumentRange();
         auto doc = KDevelop::ICore::self()->documentController()->documentForUrl(docRange.document.toUrl());
         const QString original = doc ? doc->text(docRange) : QString{};
@@ -106,7 +107,7 @@ ClangProblem::ClangProblem(CXDiagnostic diagnostic, CXTranslationUnit unit)
 
     QString description = ClangString(clang_getDiagnosticSpelling(diagnostic)).toString();
     if (!diagnosticOption.isEmpty()) {
-        description.append(QStringLiteral(" [%1]").arg(diagnosticOption));
+        description.append(QLatin1String(" [") + diagnosticOption + QLatin1Char(']'));
     }
     setDescription(prettyDiagnosticSpelling(description));
 
@@ -152,6 +153,7 @@ ClangProblem::ClangProblem(CXDiagnostic diagnostic, CXTranslationUnit unit)
     QVector<IProblem::Ptr> diagnostics;
     auto childDiagnostics = clang_getChildDiagnostics(diagnostic);
     auto numChildDiagnostics = clang_getNumDiagnosticsInSet(childDiagnostics);
+    diagnostics.reserve(numChildDiagnostics);
     for (uint j = 0; j < numChildDiagnostics; ++j) {
         auto childDiagnostic = clang_getDiagnosticInSet(childDiagnostics, j);
         ClangProblem::Ptr problem(new ClangProblem(childDiagnostic, unit));
@@ -184,7 +186,8 @@ ClangFixits ClangProblem::allFixits() const
     ClangFixits result;
     result << m_fixits;
 
-    for (const IProblem::Ptr& diagnostic : diagnostics()) {
+    const auto& diagnostics = this->diagnostics();
+    for (const IProblem::Ptr& diagnostic : diagnostics) {
         const Ptr problem(dynamic_cast<ClangProblem*>(diagnostic.data()));
         Q_ASSERT(problem);
         result << problem->allFixits();
@@ -213,7 +216,7 @@ void ClangFixitAssistant::createActions()
 {
     KDevelop::IAssistant::createActions();
 
-    for (const ClangFixit& fixit : m_fixits) {
+    for (const ClangFixit& fixit : qAsConst(m_fixits)) {
         addAction(IAssistantAction::Ptr(new ClangFixitAction(fixit)));
     }
 }
