@@ -62,7 +62,7 @@ public:
     ParseSessionData(const QVector<UnsavedFile>& unsavedFiles, ClangIndex* index,
                      const ClangParsingEnvironment& environment, Options options = Options());
 
-    ~ParseSessionData();
+    ~ParseSessionData() override;
 
     ClangParsingEnvironment environment() const;
 
@@ -131,7 +131,7 @@ public:
     ClangParsingEnvironment environment() const;
 
 private:
-    Q_DISABLE_COPY(ParseSession);
+    Q_DISABLE_COPY(ParseSession)
 
     ParseSessionData::Ptr d;
 
