@@ -1203,7 +1203,7 @@ void TestDUChain::testReparseChangeEnvironment()
 
 void TestDUChain::testMacroDependentHeader()
 {
-    TestFile header(QStringLiteral("struct MY_CLASS { class Q{Q(); int m;}; int m; };\n"), QStringLiteral("h"));
+    TestFile header(QStringLiteral("struct MY_CLASS { struct Q{Q(); int m;}; int m; };\n"), QStringLiteral("h"));
     TestFile impl("#define MY_CLASS A\n"
                   "#include \"" + header.url().str() + "\"\n"
                   "#undef MY_CLASS\n"
@@ -1950,7 +1950,7 @@ void TestDUChain::testGccCompatibility()
         )"), QStringLiteral("cpp"), project, dir.path());
 
         file.parse();
-        QVERIFY(file.waitForParsed(5000));
+        QVERIFY(file.waitForParsed(50000));
 
         DUChainReadLocker lock;
         QSet<TopDUContext*> checked;
@@ -2086,3 +2086,45 @@ void TestDUChain::testHasInclude()
         }
     }
 }
+
+void TestDUChain::testSameFunctionDefinition()
+{
+    QString source(QStringLiteral(R"(
+        #include <stdio.h>
+        #include <stdlib.h>
+
+        void configure()
+        {
+            printf("do stuff\n");
+        }
+    )"));
+
+    QTemporaryDir dir;
+    auto project = new TestProject(Path(dir.path()), this);
+    m_projectController->addProject(project);
+
+    TestFile file1(source, QStringLiteral("c"), project);
+    TestFile file2(source, QStringLiteral("c"), project);
+    TestFile file3(source, QStringLiteral("c"), project);
+
+    file1.parse(TopDUContext::AllDeclarationsContextsAndUses);
+    file2.parse(TopDUContext::AllDeclarationsContextsAndUses);
+    file3.parse(TopDUContext::AllDeclarationsContextsAndUses);
+
+    QVERIFY(file1.waitForParsed(1000));
+    QVERIFY(file2.waitForParsed(1000));
+    QVERIFY(file3.waitForParsed(1000));
+
+    auto checkFunctionDefinition = [] (TestFile & file) {
+        DUChainReadLocker lock;
+        QCOMPARE(file.topContext()->localDeclarations().count(), 1);
+        auto configureFunc = file.topContext()->localDeclarations().first();
+        QCOMPARE(FunctionDefinition::definition(configureFunc), configureFunc);
+    };
+
+    checkFunctionDefinition(file1);
+    checkFunctionDefinition(file2);
+    checkFunctionDefinition(file3);
+
+    m_projectController->closeAllProjects();
+}
