@@ -37,9 +37,6 @@ private Q_SLOTS:
     void initTestCase();
     void cleanupTestCase();
 
-    void init();
-    void cleanup();
-
     void testClassRename();
 
 private:
