@@ -44,7 +44,7 @@ CMakeServer::CMakeServer(QObject* parent)
         const auto cacheLocation = QStandardPaths::writableLocation(QStandardPaths::CacheLocation);
         QDir::temp().mkpath(cacheLocation);
 
-        QTemporaryFile file(cacheLocation + "/kdevelopcmake");
+        QTemporaryFile file(cacheLocation + QLatin1String("/kdevelopcmake"));
         file.open();
         file.close();
         path = file.fileName();
@@ -82,7 +82,7 @@ CMakeServer::CMakeServer(QObject* parent)
     // we're called with the importing project as our parent, so we can fetch configured
     // cmake executable (project-specific or kdevelop-wide) rather than the system version.
     m_process.setProgram(CMake::currentCMakeExecutable(dynamic_cast<KDevelop::IProject*>(parent)).toLocalFile());
-    m_process.setArguments({"-E", "server", "--experimental", "--pipe=" + path});
+    m_process.setArguments({QStringLiteral("-E"), QStringLiteral("server"), QStringLiteral("--experimental"), QLatin1String("--pipe=") + path});
     KDevelop::ICore::self()->runtimeController()->currentRuntime()->startProcess(&m_process);
 }
 
@@ -137,7 +137,7 @@ void CMakeServer::processOutput()
         const int idx = m_buffer.indexOf(closeTag, openTag.size());
         if (idx >= 0) {
             emitResponse(m_buffer.mid(openTag.size(), idx - openTag.size()));
-            m_buffer = m_buffer.mid(idx + closeTag.size());
+            m_buffer.remove(0, idx + closeTag.size());
         } else {
             break;
         }
@@ -161,8 +161,9 @@ void CMakeServer::handshake(const KDevelop::Path& source, const KDevelop::Path&
 
     const QString generatorVariable = QStringLiteral("CMAKE_GENERATOR");
     const QString homeDirectoryVariable = QStringLiteral("CMAKE_HOME_DIRECTORY");
+    const QString cacheFileDirectoryVariable = QStringLiteral("CMAKE_CACHEFILE_DIR");
     const auto cacheValues = CMake::readCacheValues(KDevelop::Path(build, QStringLiteral("CMakeCache.txt")),
-                                                    {generatorVariable, homeDirectoryVariable});
+                                                    {generatorVariable, homeDirectoryVariable, cacheFileDirectoryVariable});
 
     QString generator = cacheValues.value(generatorVariable);
     if (generator.isEmpty()) {
@@ -179,33 +180,47 @@ void CMakeServer::handshake(const KDevelop::Path& source, const KDevelop::Path&
                    << "wanted to open" << source << "in" << build;
     }
 
-    qCDebug(CMAKE) << "Using generator" << generator << "for project" << source << "in" << build;
+    // prefer to reuse the exact same build dir path to prevent useless recompilation
+    // when we open a symlinked project path
+    QString buildDirectory = cacheValues.value(cacheFileDirectoryVariable);
+    if (buildDirectory.isEmpty()) {
+        buildDirectory = build.toLocalFile();
+    } else if (QFileInfo(buildDirectory).canonicalFilePath() != QFileInfo(build.toLocalFile()).canonicalFilePath()) {
+        qCWarning(CMAKE) << "Build directory mismatch:"
+                   << cacheFileDirectoryVariable << buildDirectory
+                   << "wanted to open" << build;
+        buildDirectory = build.toLocalFile();
+    }
+
+    qCDebug(CMAKE) << "Using generator" << generator << "for project"
+                   << sourceDirectory << "aka" << source
+                   << "in" << buildDirectory << "aka" << build;
 
     sendCommand({
-        {"cookie", {}},
-        {"type", "handshake"},
-        {"major", 1},
-        {"protocolVersion", QJsonObject{{"major", 1}} },
-        {"sourceDirectory", sourceDirectory},
-        {"buildDirectory", build.toLocalFile()},
-        {"generator", generator} //TODO: make it possible to keep whatever they have ATM
+        {QStringLiteral("cookie"), {}},
+        {QStringLiteral("type"), QStringLiteral("handshake")},
+        {QStringLiteral("major"), 1},
+        {QStringLiteral("protocolVersion"), QJsonObject{{QStringLiteral("major"), 1}} },
+        {QStringLiteral("sourceDirectory"), sourceDirectory},
+        {QStringLiteral("buildDirectory"), buildDirectory},
+        {QStringLiteral("generator"), generator}
     });
 }
 
 void CMakeServer::configure(const QStringList& args)
 {
     sendCommand({
-        {"type", "configure"},
-        {"cacheArguments", QJsonArray::fromStringList(args)}
+        {QStringLiteral("type"), QStringLiteral("configure")},
+        {QStringLiteral("cacheArguments"), QJsonArray::fromStringList(args)}
     });
 }
 
 void CMakeServer::compute()
 {
-    sendCommand({ {"type", "compute"} });
+    sendCommand({ {QStringLiteral("type"), QStringLiteral("compute")} });
 }
 
 void CMakeServer::codemodel()
 {
-    sendCommand({ {"type", "codemodel"} });
+    sendCommand({ {QStringLiteral("type"), QStringLiteral("codemodel")} });
 }
