@@ -42,7 +42,7 @@ static QString unescape(const QStringRef& input)
   bool isEscaped = false;
   for (auto it = input.data(), end = it + input.length(); it != end; ++it) {
     QChar c = *it;
-    if (!isEscaped && c == '\\') {
+    if (!isEscaped && c == QLatin1Char('\\')) {
       isEscaped = true;
     } else {
       output.append(c);
@@ -108,19 +108,7 @@ void CMakeServerImportJob::processCodeModel(const QJsonObject &response, CMakePr
                 const auto target = targetObject.toObject();
                 const KDevelop::Path targetDir = rt->pathInHost(KDevelop::Path(target.value(QStringLiteral("sourceDirectory")).toString()));
 
-                CMakeTarget cmakeTarget{
-                    typeToEnum(target),
-                    target.value(QStringLiteral("name")).toString(),
-                    kTransform<KDevelop::Path::List>(target[QLatin1String("artifacts")].toArray(), [](const QJsonValue& val) { return KDevelop::Path(val.toString()); })
-                };
-
-                // ensure we don't add the same target multiple times, for different projects
-                // cf.: https://bugs.kde.org/show_bug.cgi?id=387095
-                auto& dirTargets = data.targets[targetDir];
-                if (dirTargets.contains(cmakeTarget))
-                    continue;
-                dirTargets += cmakeTarget;
-
+                KDevelop::Path::List targetSources;
                 const auto fileGroups = target.value(QStringLiteral("fileGroups")).toArray();
                 for (const auto &fileGroupValue: fileGroups) {
                     const auto fileGroup = fileGroupValue.toObject();
@@ -132,6 +120,7 @@ void CMakeServerImportJob::processCodeModel(const QJsonObject &response, CMakePr
 
                     const auto sourcesArray = fileGroup.value(QStringLiteral("sources")).toArray();
                     const KDevelop::Path::List sources = kTransform<KDevelop::Path::List>(sourcesArray, [targetDir](const QJsonValue& val) { return KDevelop::Path(targetDir, val.toString()); });
+                    targetSources.reserve(targetSources.size() + sources.size());
                     for (const auto& source: sources) {
                         // NOTE: we use the canonical file path to prevent issues with symlinks in the path
                         //       leading to lookup failures
@@ -139,9 +128,26 @@ void CMakeServerImportJob::processCodeModel(const QJsonObject &response, CMakePr
                         const auto canonicalFile = QFileInfo(source.toLocalFile()).canonicalFilePath();
                         const auto sourcePath = localFile.toLocalFile() == canonicalFile ? localFile : KDevelop::Path(canonicalFile);
                         data.compilationData.files[sourcePath] = file;
+                        targetSources << sourcePath;
                     }
                     qCDebug(CMAKE) << "registering..." << sources << file;
                 }
+
+                CMakeTarget cmakeTarget{
+                    typeToEnum(target),
+                    target.value(QStringLiteral("name")).toString(),
+                    kTransform<KDevelop::Path::List>(target[QLatin1String("artifacts")].toArray(), [](const QJsonValue& val) { return KDevelop::Path(val.toString()); }),
+                    targetSources,
+                };
+
+                // ensure we don't add the same target multiple times, for different projects
+                // cf.: https://bugs.kde.org/show_bug.cgi?id=387095
+                auto& dirTargets = data.targets[targetDir];
+                if (dirTargets.contains(cmakeTarget))
+                    continue;
+                dirTargets += cmakeTarget;
+
+                qCDebug(CMAKE) << "adding target" << cmakeTarget.name << "with sources" << cmakeTarget.sources;
             }
         }
     }
