@@ -29,7 +29,7 @@
 
 #include <KShell>
 #include <KLocalizedString>
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 
 #include <project/projectmodel.h>
 #include <interfaces/iproject.h>
@@ -71,7 +71,7 @@ static const QString buildDirCountKey = QStringLiteral("Build Directory Count");
 //the used builddir will change for every runtime
 static QString buildDirIndexKey() {
     const QString currentRuntime = ICore::self()->runtimeController()->currentRuntime()->name();
-    return buildDirIndexKey_ + '-' + currentRuntime;
+    return buildDirIndexKey_ + QLatin1Char('-') + currentRuntime;
 }
 
 namespace Specific
@@ -170,8 +170,7 @@ KDevelop::Path::List resolveSystemDirs(KDevelop::IProject* project, const QStrin
 
     KDevelop::Path::List newList;
     newList.reserve(dirs.size());
-    foreach(const QString& s, dirs)
-    {
+    for (const QString& s : dirs) {
         KDevelop::Path dir;
         if(s.startsWith(QLatin1String("#[bin_dir]")))
         {
@@ -224,8 +223,6 @@ bool checkForNeedingConfigure( KDevelop::IProject* project )
         }
         else
         {
-
-            QString newbuilddir = bd.buildFolder().toLocalFile();
             int addedBuildDirIndex = buildDirCount( project ); // old count is the new index
 
             // Initialize the kconfig items with the values from the dialog, this ensures the settings
@@ -328,11 +325,11 @@ QString findExecutable()
     auto cmake = QStandardPaths::findExecutable(QStringLiteral("cmake"));
 #ifdef Q_OS_WIN
     if (cmake.isEmpty())
-        cmake = QStandardPaths::findExecutable("cmake",{
-            "C:\\Program Files (x86)\\CMake\\bin",
-            "C:\\Program Files\\CMake\\bin",
-            "C:\\Program Files (x86)\\CMake 2.8\\bin",
-            "C:\\Program Files\\CMake 2.8\\bin"});
+        cmake = QStandardPaths::findExecutable(QStringLiteral("cmake"), {
+            QStringLiteral("C:\\Program Files (x86)\\CMake\\bin"),
+            QStringLiteral("C:\\Program Files\\CMake\\bin"),
+            QStringLiteral("C:\\Program Files (x86)\\CMake 2.8\\bin"),
+            QStringLiteral("C:\\Program Files\\CMake 2.8\\bin")});
 #endif
     return cmake;
 }
@@ -628,6 +625,7 @@ QStringList allBuildDirs(KDevelop::IProject* project)
 {
     QStringList result;
     int bdCount = buildDirCount(project);
+    result.reserve(bdCount);
     for (int i = 0; i < bdCount; ++i)
         result += buildDirGroup( project, i ).readEntry( Config::Specific::buildDirPathKey );
     return result;
@@ -649,8 +647,7 @@ QString executeProcess(const QString& execName, const QStringList& args)
     }
 
     QByteArray b = p.readAllStandardOutput();
-    QString t;
-    t.prepend(b.trimmed());
+    QString t = QString::fromUtf8(b.trimmed());
     return t;
 }
 
@@ -689,7 +686,7 @@ QString defaultGenerator()
 
 QVector<Test> importTestSuites(const Path &buildDir)
 {
-    const auto contents = CMakeListsParser::readCMakeFile(buildDir.toLocalFile() + "/CTestTestfile.cmake");
+    const auto contents = CMakeListsParser::readCMakeFile(buildDir.toLocalFile() + QLatin1String("/CTestTestfile.cmake"));
 
     QVector<Test> tests;
     for (const auto& entry: contents) {
