@@ -28,16 +28,17 @@
 QMap<QChar, QChar> whatToScape()
 {
     //Only add those where we're not scaping the next character
-    QMap<QChar, QChar> ret;
-    ret['n']='\n';
-    ret['r']='\r';
-    ret['t']='\t';
+    QMap<QChar, QChar> ret{
+        {QLatin1Char('n'), QLatin1Char('\n')},
+        {QLatin1Char('r'), QLatin1Char('\r')},
+        {QLatin1Char('t'), QLatin1Char('\t')},
+    };
     return ret;
 }
 
 const QMap<QChar, QChar> CMakeFunctionArgument::scapings=whatToScape();
 
-static const QChar scapingChar='\\';
+static const QChar scapingChar = QLatin1Char('\\');
 QString CMakeFunctionArgument::unescapeValue(const QString& value)
 {
     int firstScape=value.indexOf(scapingChar);
@@ -71,25 +72,27 @@ void CMakeFunctionDesc::addArguments( const QStringList& args, bool addEvenIfEmp
 {
     if(addEvenIfEmpty && args.isEmpty())
         arguments += CMakeFunctionArgument();
-    else foreach( const QString& arg, args )
-    {
-        CMakeFunctionArgument cmakeArg( arg );
-        arguments.append( cmakeArg );
+    else {
+        arguments.reserve(arguments.size() + args.size());
+        for (const auto& arg : args) {
+            CMakeFunctionArgument cmakeArg(arg);
+            arguments.append(cmakeArg);
+        }
     }
 }
 
 QString CMakeFunctionDesc::writeBack() const
 {
-    QString output=name+"( ";
-    foreach(const CMakeFunctionArgument& arg, arguments)
-    {
-        QString o = arg.value;
-        if(arg.quoted)
-            o='"'+o+'"';
-        output += o+' ';
+    QStringList args;
+    args.reserve(arguments.size());
+    for (const auto& arg : arguments) {
+        if (arg.quoted) {
+            args.append(QLatin1Char('"') + arg.value + QLatin1Char('"'));
+        } else {
+            args.append(arg.value);
+        }
     }
-    output += ')';
-    return output;
+    return name + QLatin1String("( ") + args.join(QLatin1Char(' ')) + QLatin1String(" )");
 }
 
 namespace CMakeListsParser
