@@ -26,9 +26,6 @@
 #include <QTimer>
 #include <QMenuBar>
 
-#include <kparts/mainwindow.h>
-#include <KTextEditor/Document>
-#include <KTextEditor/View>
 #include <interfaces/icore.h>
 #include <interfaces/idocumentcontroller.h>
 #include "contextbrowserview.h"
@@ -40,13 +37,17 @@
 #include <language/duchain/duchain.h>
 #include <language/duchain/declaration.h>
 #include <language/duchain/navigation/abstractnavigationwidget.h>
-#include <ktexteditor/codecompletioninterface.h>
 #include <language/duchain/functiondefinition.h>
 #include <language/duchain/forwarddeclaration.h>
 
 #include "contextbrowser.h"
 #include "debug.h"
 
+#include <KParts/MainWindow>
+#include <KTextEditor/Document>
+#include <KTextEditor/View>
+#include <KTextEditor/CodeCompletionInterface>
+
 using namespace KDevelop;
 using namespace KTextEditor;
 
@@ -107,6 +108,7 @@ BrowseManager::BrowseManager(ContextBrowserPlugin* controller)
 {
     m_delayedBrowsingTimer = new QTimer(this);
     m_delayedBrowsingTimer->setSingleShot(true);
+    m_delayedBrowsingTimer->setInterval(300);
 
     connect(m_delayedBrowsingTimer, &QTimer::timeout, this, &BrowseManager::eventuallyStartDelayedBrowsing);
 
@@ -174,7 +176,7 @@ bool BrowseManager::eventFilter(QObject * watched, QEvent * event) {
 
     //Eventually start key-browsing
     if(keyEvent && (keyEvent->key() == browseKey || keyEvent->key() == magicModifier) && !m_browsingByKey && keyEvent->type() == QEvent::KeyPress) {
-        m_delayedBrowsingTimer->start(300); // always start the timer, to get consistent behavior regarding the ALT key and the menu activation
+        m_delayedBrowsingTimer->start(); // always start the timer, to get consistent behavior regarding the ALT key and the menu activation
         m_browsingByKey = keyEvent->key();
 
         if(!view) {
@@ -198,7 +200,7 @@ bool BrowseManager::eventFilter(QObject * watched, QEvent * event) {
             // user wants to trigger an action in the code browser
             const int index = keyEvent->key() - Qt::Key_1;
             emit invokeAction(index);
-            stopDelayedBrowsing();
+            emit stopDelayedBrowsing();
             return true;
         }
     }
