@@ -30,7 +30,6 @@
 #include <KToggleAction>
 #include <KLocalizedString>
 #include <KTextEditor/Document>
-#include <KTextEditor/View>
 
 #include <language/duchain/declaration.h>
 #include <language/duchain/topducontext.h>
@@ -77,17 +76,20 @@ void selectUse(ContextBrowserView* view, Direction direction)
     }
 
     OneUseWidget* first = nullptr, *previous = nullptr, *current = nullptr;
-    for (auto item : usesWidget->items()) {
+    const auto& usesWidgetItems = usesWidget->items();
+    for (auto item : usesWidgetItems) {
         auto topContext = dynamic_cast<TopContextUsesWidget*>(item);
         if (!topContext) {
             continue;
         }
-        for (auto item : topContext->items()) {
+        const auto& topContextItems = topContext->items();
+        for (auto item : topContextItems) {
             auto navigationList = dynamic_cast<NavigatableWidgetList*>(item);
             if (!navigationList) {
                 continue;
             }
-            for (auto item : navigationList->items()) {
+            const auto& navigationListItems = navigationList->items();
+            for (auto item : navigationListItems) {
                 auto use = dynamic_cast<OneUseWidget*>(item);
                 if (!use) {
                     continue;
@@ -181,10 +183,10 @@ ContextBrowserView::ContextBrowserView( ContextBrowserPlugin* plugin, QWidget* p
     m_allowLockedUpdate = false;
 
     m_declarationMenuAction = new QAction(QIcon::fromTheme(QStringLiteral("code-class")), QString(), this);
-    m_declarationMenuAction->setToolTip(i18n("Declaration menu"));
+    m_declarationMenuAction->setToolTip(i18n("Show declaration menu"));
     // expose the declaration menu via the context menu; allows hiding the toolbar to save some space
     // (this will not make it behave like a submenu though)
-    m_declarationMenuAction->setText(m_declarationMenuAction->toolTip());
+    m_declarationMenuAction->setText(i18n("Declaration Menu"));
     connect(m_declarationMenuAction, &QAction::triggered, this, &ContextBrowserView::declarationMenu);
     addAction(m_declarationMenuAction);
     m_lockAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("object-unlocked")), i18n("Lock Current View"), this);
@@ -213,7 +215,7 @@ void ContextBrowserView::focusInEvent(QFocusEvent* event) {
 //     parentWidget()->setBackgroundRole(QPalette::ToolTipBase);
 /*    m_layout->removeItem(m_buttons);*/
 
-    return QWidget::focusInEvent(event);
+    QWidget::focusInEvent(event);
 }
 
 void ContextBrowserView::focusOutEvent(QFocusEvent* event) {
@@ -263,7 +265,7 @@ void ContextBrowserView::showEvent(QShowEvent* event)
     TopDUContext* top = m_lastUsedTopContext.data();
     if(top && m_navigationWidgetDeclaration.isValid()) {
         //Update the navigation-widget
-        Declaration* decl = m_navigationWidgetDeclaration.getDeclaration(top);
+        Declaration* decl = m_navigationWidgetDeclaration.declaration(top);
         if(decl)
             setDeclaration(decl, top, true);
     }
@@ -290,7 +292,7 @@ void ContextBrowserView::updateMainWidget(QWidget* widget)
         m_layout->insertWidget(1, widget, 1);
         m_allowLockedUpdate = false;
         setUpdatesEnabled(true);
-        if (widget->metaObject()->indexOfSignal(QMetaObject::normalizedSignature("contextChanged(bool,bool)")) != -1) {
+        if (widget->metaObject()->indexOfSignal(QMetaObject::normalizedSignature("contextChanged(bool,bool)").constData()) != -1) {
             connect(widget, SIGNAL(contextChanged(bool,bool)), this, SLOT(navigationContextChanged(bool,bool)));
         }
     }
@@ -337,7 +339,7 @@ void ContextBrowserView::setDeclaration(KDevelop::Declaration* decl, KDevelop::T
 
     m_navigationWidgetDeclaration = decl->id();
 
-    if (!isLocked() && (isVisible() || force)) {  // NO-OP if toolview is hidden, for performance reasons
+    if (!isLocked() && (isVisible() || force)) {  // NO-OP if tool view is hidden, for performance reasons
 
         QWidget* w = createWidget(decl, topContext);
         updateMainWidget(w);
@@ -373,7 +375,7 @@ void ContextBrowserView::setContext(KDevelop::DUContext* context) {
         m_navigationWidgetDeclaration = DeclarationId();
     }
 
-    if (!isLocked() && isVisible()) { // NO-OP if toolview is hidden, for performance reasons
+    if (!isLocked() && isVisible()) { // NO-OP if tool view is hidden, for performance reasons
 
         QWidget* w = createWidget(context);
         updateMainWidget(w);
