@@ -31,9 +31,9 @@ class MsvcCompiler : public ICompiler
 public:
     MsvcCompiler(const QString& name, const QString& path, bool editable, const QString& factoryName);
 
-    KDevelop::Defines defines(const QString& arguments) const override;
+    KDevelop::Defines defines(Utils::LanguageType type, const QString& arguments) const override;
 
-    KDevelop::Path::List includes(const QString& arguments) const override;
+    KDevelop::Path::List includes(Utils::LanguageType type, const QString& arguments) const override;
 };
 
 #endif // MSVCCOMPILER_H
