@@ -16,6 +16,8 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>. *
  ************************************************************************/
 
+#include "definesandincludesconfigpage.h"
+
 #include <QVBoxLayout>
 #include <QIcon>
 
@@ -29,8 +31,6 @@
 #include <interfaces/idocument.h>
 #include <project/projectmodel.h>
 
-#include "definesandincludesconfigpage.h"
-
 DefinesAndIncludesConfigPage::DefinesAndIncludesConfigPage(KDevelop::IPlugin* plugin, const KDevelop::ProjectConfigOptions& options, QWidget* parent)
     : ProjectConfigPage<CustomDefinesAndIncludes>(plugin, options, parent)
 {
@@ -88,5 +88,5 @@ QString DefinesAndIncludesConfigPage::fullName() const
 
 QIcon DefinesAndIncludesConfigPage::icon() const
 {
-    return QIcon::fromTheme("kdevelop");
+    return QIcon::fromTheme(QStringLiteral("kdevelop"));
 }
