@@ -19,14 +19,11 @@
 
 #include "projectpathswidget.h"
 
-#include <kmessagebox.h>
-
 #include <QFileDialog>
 #include <QPointer>
 #include <QRegExp>
 
 #include <interfaces/iproject.h>
-#include <KLocalizedString>
 
 #include "../compilerprovider/compilerprovider.h"
 #include "../compilerprovider/settingsmanager.h"
@@ -36,6 +33,10 @@
 #include "projectpathsmodel.h"
 #include <debug.h>
 
+#include <KMessageBox>
+#include <KLocalizedString>
+
+
 using namespace KDevelop;
 
 namespace
@@ -54,10 +55,6 @@ ProjectPathsWidget::ProjectPathsWidget( QWidget* parent )
 {
     ui->setupUi( this );
 
-    ui->addPath->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
-    ui->removePath->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
-    ui->batchEdit->setIcon(QIcon::fromTheme(QStringLiteral("format-list-unordered")));
-
     // hack taken from kurlrequester, make the buttons a bit less in height so they better match the url-requester
     ui->addPath->setFixedHeight( ui->projectPaths->sizeHint().height() );
     ui->removePath->setFixedHeight( ui->projectPaths->sizeHint().height() );
@@ -175,7 +172,7 @@ void ProjectPathsWidget::clear()
 
 void ProjectPathsWidget::addProjectPath()
 {
-    const QUrl directory = pathsModel->data(pathsModel->index(0, 0), ProjectPathsModel::FullUrlDataRole).value<QUrl>();
+    const QUrl directory = pathsModel->data(pathsModel->index(0, 0), ProjectPathsModel::FullUrlDataRole).toUrl();
     QPointer<QFileDialog> dlg = new QFileDialog(this, i18n("Select Project Path"), directory.toLocalFile());
     dlg->setFileMode(QFileDialog::Directory);
     dlg->setOption(QFileDialog::ShowDirsOnly);
@@ -224,14 +221,14 @@ void ProjectPathsWidget::batchEdit()
     bool includesTab = ui->languageParameters->currentIndex() == 0;
     if (includesTab) {
         auto includes = pathsModel->data(midx, ProjectPathsModel::IncludesDataRole).toStringList();
-        be.textEdit->setPlainText(includes.join(QStringLiteral("\n")));
+        be.textEdit->setPlainText(includes.join(QLatin1Char('\n')));
 
         dialog->setWindowTitle(i18n("Edit include directories/files"));
     } else {
         auto defines = pathsModel->data(midx, ProjectPathsModel::DefinesDataRole).value<Defines>();
 
         for (auto it = defines.constBegin(); it != defines.constEnd(); it++) {
-            be.textEdit->appendPlainText(it.key() + "=" + it.value());
+            be.textEdit->appendPlainText(it.key() + QLatin1Char('=') + it.value());
         }
 
         dialog->setWindowTitle(i18n("Edit defined macros"));
@@ -243,19 +240,19 @@ void ProjectPathsWidget::batchEdit()
     }
 
     if (includesTab) {
-        auto includes = be.textEdit->toPlainText().split('\n', QString::SkipEmptyParts);
+        auto includes = be.textEdit->toPlainText().split(QLatin1Char('\n'), QString::SkipEmptyParts);
         for (auto& s : includes) {
             s = s.trimmed();
         }
 
         pathsModel->setData(midx, includes, ProjectPathsModel::IncludesDataRole);
     } else {
-        auto list = be.textEdit->toPlainText().split('\n', QString::SkipEmptyParts);
+        auto list = be.textEdit->toPlainText().split(QLatin1Char('\n'), QString::SkipEmptyParts);
         Defines defines;
 
         for (auto& d : list) {
             //This matches: a=b, a=, a
-            QRegExp r("^([^=]+)(=(.*))?$");
+            QRegExp r(QStringLiteral("^([^=]+)(=(.*))?$"));
 
             if (!r.exactMatch(d)) {
                 continue;
