@@ -33,7 +33,7 @@
 #include <QRegularExpression>
 #include <QRegExp>
 
-#include <kprocess.h>
+#include <KProcess>
 #include <KLocalizedString>
 
 #include <serialization/indexedstring.h>
@@ -62,14 +62,13 @@ namespace {
   struct CacheEntry
   {
     CacheEntry()
-      : failed(false)
     { }
     ModificationRevisionSet modificationTime;
     Path::List paths;
     Path::List frameworkDirectories;
     QHash<QString, QString> defines;
     QString errorMessage, longErrorMessage;
-    bool failed;
+    bool failed = false;
     QMap<QString,bool> failedFiles;
     QDateTime failTime;
   };
@@ -93,10 +92,16 @@ namespace {
     {
     }
 
-    QString getCommand(const QString& absoluteFile, const QString& workingDirectory, const QString& makeParameters) const
+    QString createCommand(const QString& absoluteFile, const QString& workingDirectory, const QString& makeParameters) const
     {
       QString relativeFile = Path(workingDirectory).relativePath(Path(absoluteFile));
-      return "make -k --no-print-directory -W \'" + absoluteFile + "\' -W \'" + relativeFile + "\' -n " + makeParameters;
+#ifndef Q_OS_FREEBSD
+      // GNU make implicitly enables "-w" for sub-makes, we don't want that
+      QLatin1String noPrintDirFlag = QLatin1String(" --no-print-directory");
+#else
+      QLatin1String noPrintDirFlag;
+#endif
+      return QLatin1String("make -k") + noPrintDirFlag + QLatin1String(" -W \'") + absoluteFile + QLatin1String("\' -W \'") + relativeFile + QLatin1String("\' -n ") + makeParameters;
     }
 
     bool hasMakefile() const
@@ -107,13 +112,14 @@ namespace {
 
     QStringList possibleTargets(const QString& targetBaseName) const
     {
-      QStringList ret;
+      const QStringList ret{
       ///@todo open the make-file, and read the target-names from there.
       //It would be nice if all targets could be processed in one call, the problem is the exit-status of make, so for now make has to be called multiple times.
-      ret << targetBaseName + ".o";
-      ret << targetBaseName + ".lo";
+        targetBaseName + QLatin1String(".o"),
+        targetBaseName + QLatin1String(".lo"),
       //ret << targetBaseName + ".lo " + targetBaseName + ".o";
-      ret << targetBaseName + ".ko";
+        targetBaseName + QLatin1String(".ko"),
+      };
       return ret;
     }
 
@@ -123,7 +129,7 @@ namespace {
 
 static void mergePaths(KDevelop::Path::List& destList, const KDevelop::Path::List& srcList)
 {
-    foreach (const Path& path, srcList) {
+    for (const Path& path : srcList) {
         if (!destList.contains(path))
             destList.append(path);
     }
@@ -181,19 +187,18 @@ bool MakeFileResolver::executeCommand(const QString& command, const QString& wor
   proc.setWorkingDirectory(workingDirectory);
   proc.setOutputChannelMode(KProcess::MergedChannels);
 
-  QStringList args(command.split(' '));
+  QStringList args(command.split(QLatin1Char(' ')));
   QString prog = args.takeFirst();
   proc.setProgram(prog, args);
 
   int status = proc.execute(processTimeoutSeconds * 1000);
-  result = proc.readAll();
+  result = QString::fromUtf8(proc.readAll());
 
   return status == 0;
 }
 
 MakeFileResolver::MakeFileResolver()
-  : m_isResolving(false)
-  , m_outOfSource(false)
+
 {
 }
 
@@ -215,7 +220,7 @@ QString MakeFileResolver::mapToBuild(const QString &path) const
   if (m_outOfSource) {
     if (wd.startsWith(m_source) && !wd.startsWith(m_build)) {
         //Move the current working-directory out of source, into the build-system
-        wd = QDir::cleanPath(m_build + '/' + wd.mid(m_source.length()));
+        wd = QDir::cleanPath(m_build + QLatin1Char('/') + wd.midRef(m_source.length()));
       }
   }
   return wd;
@@ -244,11 +249,11 @@ PathResolutionResult MakeFileResolver::resolveIncludePath(const QString& file, c
     if (workingDirectory == QLatin1String("."))
       workingDirectory = QString();
     else if (workingDirectory.startsWith(QLatin1String("./")))
-      workingDirectory = workingDirectory.mid(2);
+      workingDirectory.remove(0, 2);
 
     if (!workingDirectory.isEmpty()) {
       u = u.adjusted(QUrl::StripTrailingSlash);
-      u.setPath(u.path() + '/' + workingDirectory);
+      u.setPath(u.path() + QLatin1Char('/') + workingDirectory);
     }
     workingDirectory = u.toLocalFile();
   } else
@@ -267,7 +272,7 @@ PathResolutionResult MakeFileResolver::resolveIncludePath(const QString& file, c
       QString localName = sourceDir.dirName();
 
       if (sourceDir.cdUp() && !fileName.isAbsolute()) {
-        QString checkFor = localName + "/" + file;
+        const QString checkFor = localName + QLatin1Char('/') + file;
         PathResolutionResult oneUp = resolveIncludePath(checkFor, sourceDir.path(), maxStepsUp-1);
         if (oneUp.success) {
           oneUp.mergeWith(resultOnFail);
@@ -332,11 +337,11 @@ PathResolutionResult MakeFileResolver::resolveIncludePath(const QString& file, c
 
   QString absoluteFile = file;
   if (fi.isRelative())
-    absoluteFile = workingDirectory + '/' + file;
+    absoluteFile = workingDirectory + QLatin1Char('/') + file;
   absoluteFile = QDir::cleanPath(absoluteFile);
 
   int dot;
-  if ((dot = file.lastIndexOf('.')) == -1) {
+  if ((dot = file.lastIndexOf(QLatin1Char('.'))) == -1) {
     if (!resultOnFail.errorMessage.isEmpty() || !resultOnFail.paths.isEmpty() || !resultOnFail.frameworkDirectories.isEmpty())
       return resultOnFail;
     else
@@ -347,7 +352,7 @@ PathResolutionResult MakeFileResolver::resolveIncludePath(const QString& file, c
 
   QString wd = dir.path();
   if (QFileInfo(wd).isRelative()) {
-    wd = QDir::cleanPath(QDir::currentPath() + '/' + wd);
+    wd = QDir::cleanPath(QDir::currentPath() + QLatin1Char('/') + wd);
   }
 
   wd = mapToBuild(wd);
@@ -360,7 +365,7 @@ PathResolutionResult MakeFileResolver::resolveIncludePath(const QString& file, c
   ///STEP 3.1: Try resolution using the absolute path
   PathResolutionResult res;
   //Try for each possible target
-  res = resolveIncludePathInternal(absoluteFile, wd, possibleTargets.join(QStringLiteral(" ")), source, maximumInternalResolutionDepth);
+  res = resolveIncludePathInternal(absoluteFile, wd, possibleTargets.join(QLatin1Char(' ')), source, maximumInternalResolutionDepth);
   if (!res) {
     ifTest(cout << "Try for absolute file " << absoluteFile.toLocal8Bit().data() << " and targets " << possibleTargets.join(", ").toLocal8Bit().data()
                  << " failed: " << res.longErrorMessage.toLocal8Bit().data() << endl;)
@@ -408,13 +413,13 @@ PathResolutionResult MakeFileResolver::resolveIncludePath(const QString& file, c
 
 static QRegularExpression includeRegularExpression()
 {
-  static const QRegularExpression expression(
+  static const QRegularExpression expression(QStringLiteral(
     "\\s(--include-dir=|-I\\s*|-isystem\\s+|-iframework\\s+|-F\\s*)("
     "\\'.*\\'|\\\".*\\\"" //Matches "hello", 'hello', 'hello"hallo"', etc.
     "|"
     "((?:\\\\.)?([\\S^\\\\]?))+" //Matches /usr/I\ am\ a\ strange\ path/include
     ")(?=\\s)"
-  );
+  ));
   Q_ASSERT(expression.isValid());
   return expression;
 }
@@ -427,19 +432,17 @@ PathResolutionResult MakeFileResolver::resolveIncludePathInternal(const QString&
   if (maxDepth < 0)
     return PathResolutionResult(false);
 
-  QString processStdout;
-
   QString fullOutput;
-  executeCommand(source.getCommand(file, workingDirectory, makeParameters), workingDirectory, fullOutput);
+  executeCommand(source.createCommand(file, workingDirectory, makeParameters), workingDirectory, fullOutput);
 
   {
-    QRegExp newLineRx("\\\\\\n");
-    fullOutput.replace(newLineRx, QLatin1String(""));
+    QRegExp newLineRx(QStringLiteral("\\\\\\n"));
+    fullOutput.remove(newLineRx);
   }
   ///@todo collect multiple outputs at the same time for performance-reasons
   QString firstLine = fullOutput;
   int lineEnd;
-  if ((lineEnd = fullOutput.indexOf('\n')) != -1)
+  if ((lineEnd = fullOutput.indexOf(QLatin1Char('\n'))) != -1)
     firstLine.truncate(lineEnd); //Only look at the first line of output
 
   /**
@@ -451,17 +454,17 @@ PathResolutionResult MakeFileResolver::resolveIncludePathInternal(const QString&
   ///STEP 1: Test if it is a recursive make-call
   // Do not search for recursive make-calls if we already have include-paths available. Happens in kernel modules.
   if (!includeRegularExpression().match(fullOutput).hasMatch()) {
-    QRegExp makeRx("\\bmake\\s");
+    QRegExp makeRx(QStringLiteral("\\bmake\\s"));
     int offset = 0;
     while ((offset = makeRx.indexIn(firstLine, offset)) != -1) {
       QString prefix = firstLine.left(offset).trimmed();
-      if (prefix.endsWith(QLatin1String("&&")) || prefix.endsWith(';') || prefix.isEmpty()) {
+      if (prefix.endsWith(QLatin1String("&&")) || prefix.endsWith(QLatin1Char(';')) || prefix.isEmpty()) {
         QString newWorkingDirectory = workingDirectory;
         ///Extract the new working-directory
         if (!prefix.isEmpty()) {
           if (prefix.endsWith(QLatin1String("&&")))
             prefix.truncate(prefix.length() - 2);
-          else if (prefix.endsWith(';'))
+          else if (prefix.endsWith(QLatin1Char(';')))
             prefix.truncate(prefix.length() - 1);
 
           ///Now test if what we have as prefix is a simple "cd /foo/bar" call.
@@ -470,9 +473,9 @@ PathResolutionResult MakeFileResolver::resolveIncludePathInternal(const QString&
           //We use the second directory. For t hat reason we search for the last index of "cd "
           int cdIndex = prefix.lastIndexOf(QLatin1String("cd "));
           if (cdIndex != -1) {
-            newWorkingDirectory = prefix.right(prefix.length() - 3 - cdIndex).trimmed();
+            newWorkingDirectory = prefix.mid(cdIndex + 3).trimmed();
             if (QFileInfo(newWorkingDirectory).isRelative())
-              newWorkingDirectory = workingDirectory + '/' + newWorkingDirectory;
+              newWorkingDirectory = workingDirectory + QLatin1Char('/') + newWorkingDirectory;
             newWorkingDirectory = QDir::cleanPath(newWorkingDirectory);
           }
         }
@@ -485,12 +488,12 @@ PathResolutionResult MakeFileResolver::resolveIncludePathInternal(const QString&
         if (d.exists()) {
           ///The recursive working-directory exists.
           QString makeParams = firstLine.mid(offset+5);
-          if (!makeParams.contains(';') && !makeParams.contains(QLatin1String("&&"))) {
+          if (!makeParams.contains(QLatin1Char(';')) && !makeParams.contains(QLatin1String("&&"))) {
             ///Looks like valid parameters
             ///Make the file-name absolute, so it can be referenced from any directory
             QString absoluteFile = file;
             if (QFileInfo(absoluteFile).isRelative())
-              absoluteFile = workingDirectory +  '/' + file;
+              absoluteFile = workingDirectory +  QLatin1Char('/') + file;
             Path absolutePath(absoluteFile);
             ///Try once with absolute, and if that fails with relative path of the file
             SourcePathInformation newSource(newWorkingDirectory);
@@ -521,7 +524,7 @@ PathResolutionResult MakeFileResolver::resolveIncludePathInternal(const QString&
   if (ret.paths.isEmpty() && ret.frameworkDirectories.isEmpty())
     return PathResolutionResult(false, i18n("Could not extract include paths from make output"),
                                 i18n("Folder: \"%1\"  Command: \"%2\"  Output: \"%3\"", workingDirectory,
-                                     source.getCommand(file, workingDirectory, makeParameters), fullOutput));
+                                     source.createCommand(file, workingDirectory, makeParameters), fullOutput));
   return ret;
 }
 
@@ -541,7 +544,7 @@ static QString unescape(const QStringRef& input)
   bool isEscaped = false;
   for (auto it = input.data(), end = it + input.length(); it != end; ++it) {
     QChar c = *it;
-    if (!isEscaped && c == '\\') {
+    if (!isEscaped && c == QLatin1Char('\\')) {
       isEscaped = true;
     } else {
       output.append(c);
@@ -563,15 +566,15 @@ PathResolutionResult MakeFileResolver::processOutput(const QString& fullOutput,
     while (it.hasNext()) {
       const auto match = it.next();
       QString path = match.captured(2);
-      if (path.startsWith('"') || (path.startsWith('\'') && path.length() > 2)) {
+      if (path.startsWith(QLatin1Char('"')) || (path.startsWith(QLatin1Char('\'')) && path.length() > 2)) {
           //probable a quoted path
-          if (path.endsWith(path.left(1))) {
+          if (path.endsWith(path.leftRef(1))) {
             //Quotation is ok, remove it
             path = path.mid(1, path.length() - 2);
           }
       }
       if (QDir::isRelativePath(path))
-        path = workingDirectory + '/' + path;
+        path = workingDirectory + QLatin1Char('/') + path;
       const auto& internedPath = internPath(path);
       const auto& type = match.captured(1);
       const auto isFramework = type.startsWith(QLatin1String("-iframework"))
