@@ -39,6 +39,10 @@
 #include <stdexcept>
 #include <sstream>
 
+#ifdef Q_OS_WIN
+#include <Windows.h>
+#endif
+
 // #define DEBUG_NO_TRY //to get a backtrace to where the exception was thrown
 
 using namespace KDevMI;
@@ -46,8 +50,6 @@ using namespace KDevMI::MI;
 
 MIDebugger::MIDebugger(QObject* parent)
     : QObject(parent)
-    , m_process(nullptr)
-    , m_currentCmd(nullptr)
 {
     m_process = new KProcess(this);
     m_process->setOutputChannelMode(KProcess::SeparateChannels);
@@ -82,12 +84,12 @@ void MIDebugger::execute(MICommand* command)
 
     QByteArray commandUtf8 = commandText.toUtf8();
 
-    m_process->write(commandUtf8, commandUtf8.length());
+    m_process->write(commandUtf8);
     command->markAsSubmitted();
 
     QString prettyCmd = m_currentCmd->cmdToSend();
-    prettyCmd.remove( QRegExp("set prompt \032.\n") );
-    prettyCmd = "(gdb) " + prettyCmd;
+    prettyCmd.remove(QRegExp(QStringLiteral("set prompt \032.\n")));
+    prettyCmd = QLatin1String("(gdb) ") + prettyCmd;
 
     if (m_currentCmd->isUserCommand())
         emit userCommandOutput(prettyCmd);
@@ -102,11 +104,16 @@ bool MIDebugger::isReady() const
 
 void MIDebugger::interrupt()
 {
-    //TODO:win32 Porting needed
+#ifndef Q_OS_WIN
     int pid = m_process->pid();
     if (pid != 0) {
         ::kill(pid, SIGINT);
     }
+#else
+    SetConsoleCtrlHandler(nullptr, true);
+    GenerateConsoleCtrlEvent(0, 0);
+    SetConsoleCtrlHandler(nullptr, false);
+#endif
 }
 
 MICommand* MIDebugger::currentCommand() const
@@ -132,7 +139,7 @@ void MIDebugger::readyReadStandardOutput()
         if (i == -1)
             break;
         QByteArray reply(m_buffer.left(i));
-        m_buffer = m_buffer.mid(i+1);
+        m_buffer.remove(0, i+1);
 
         processLine(reply);
     }
@@ -182,9 +189,9 @@ void MIDebugger::processLine(const QByteArray& line)
             // it's still possible for the user to issue a MI command,
             // emit correct signal
             if (m_currentCmd && m_currentCmd->isUserCommand()) {
-                emit userCommandOutput(QString::fromUtf8(line) + '\n');
+                emit userCommandOutput(QString::fromUtf8(line) + QLatin1Char('\n'));
             } else {
-                emit internalCommandOutput(QString::fromUtf8(line) + '\n');
+                emit internalCommandOutput(QString::fromUtf8(line) + QLatin1Char('\n'));
             }
 
             // protect against wild replies that sometimes returned from gdb without a pending command
@@ -274,9 +281,6 @@ void MIDebugger::processLine(const QByteArray& line)
                 // On-going status information about progress of a slow operation; may be ignored
                 break;
             }
-
-            default:
-                Q_ASSERT(false);
             }
             break;
         }
@@ -314,14 +318,14 @@ void MIDebugger::processLine(const QByteArray& line)
         KMessageBox::detailedSorry(
             qApp->activeWindow(),
             i18nc("<b>Internal debugger error</b>",
-                    "<p>The debugger component encountered internal error while "
-                    "processing reply from gdb. Please submit a bug report. "
+                    "<p>The debugger component encountered an internal error while "
+                    "processing the reply from the debugger. Please submit a bug report. "
                     "The debug session will now end to prevent potential crash"),
             i18n("The exception is: %1\n"
-                "The MI response is: %2", e.what(),
+                "The MI response is: %2", QString::fromUtf8(e.what()),
                 QString::fromLatin1(line)),
             i18n("Internal debugger error"));
-        emit exited(true, e.what());
+        emit exited(true, QString::fromUtf8(e.what()));
     }
     #endif
 }
