@@ -53,7 +53,6 @@
 #include <QApplication>
 #include <QFileInfo>
 #include <QMetaEnum>
-#include <QPointer>
 #include <QRegularExpression>
 #include <QUrl>
 #include <QTimer>
@@ -65,14 +64,8 @@ using namespace KDevMI::MI;
 MIDebugSession::MIDebugSession(MIDebuggerPlugin *plugin)
     : m_procLineMaker(new ProcessLineMaker(this))
     , m_commandQueue(new CommandQueue)
-    , m_sessionState(NotStartedState)
-    , m_debugger(nullptr)
     , m_debuggerState(s_dbgNotStarted | s_appNotStarted)
-    , m_stateReloadInProgress(false)
-    , m_stateReloadNeeded(false)
     , m_tty(nullptr)
-    , m_hasCrashed(false)
-    , m_sourceInitFile(true)
     , m_plugin(plugin)
 {
     // setup signals
@@ -161,10 +154,11 @@ bool MIDebugSession::startDebugger(ILaunchConfiguration *cfg)
                 auto lines = output.split(QRegularExpression(QStringLiteral("[\r\n]")), QString::SkipEmptyParts);
                 for (auto &line : lines) {
                     int p = line.length();
-                    while (p >= 1 && (line[p-1] == '\r' || line[p-1] == '\n'))
+                    while (p >= 1 && (line[p-1] == QLatin1Char('\r') || line[p-1] == QLatin1Char('\n'))) {
                         p--;
+                    }
                     if (p != line.length())
-                        line.remove(p, line.length() - p);
+                        line.truncate(p);
                 }
                 emit inferiorStdoutLines(lines);
             });
@@ -254,12 +248,14 @@ bool MIDebugSession::startDebugging(ILaunchConfiguration* cfg, IExecutePlugin* i
         connect(m_tty.get(), &STTY::ErrOutput, this, &MIDebugSession::inferiorTtyStderr);
     }
     QString tty(m_tty->getSlave());
+#ifndef Q_OS_WIN
     if (tty.isEmpty()) {
         KMessageBox::information(qApp->activeWindow(), m_tty->lastError(), i18n("warning"));
 
         m_tty.reset(nullptr);
         return false;
     }
+#endif
     addCommand(InferiorTtySet, tty);
 
     // Change the working directory to the correct one
@@ -267,7 +263,7 @@ bool MIDebugSession::startDebugging(ILaunchConfiguration* cfg, IExecutePlugin* i
     if (dir.isEmpty()) {
         dir = QFileInfo(executable).absolutePath();
     }
-    addCommand(EnvironmentCd, '"' + dir + '"');
+    addCommand(EnvironmentCd, QLatin1Char('"') + dir + QLatin1Char('"'));
 
     // Set the run arguments
     QStringList arguments = iexec->arguments(cfg, err);
@@ -418,8 +414,8 @@ void MIDebugSession::debuggerStateChange(DBGStateFlags oldState, DBGStateFlags n
 #define STATE_CHECK(name) \
     do { \
         if (delta & name) { \
-            out += ((newState & name) ? " +" : " -"); \
-            out += #name; \
+            out += ((newState & name) ? QLatin1String(" +") : QLatin1String(" -")) \
+                   + QLatin1String(#name); \
             delta &= ~name; \
         } \
     } while (0)
@@ -438,8 +434,7 @@ void MIDebugSession::debuggerStateChange(DBGStateFlags oldState, DBGStateFlags n
         for (unsigned int i = 0; delta != 0 && i < 32; ++i) {
             if (delta & (1 << i))  {
                 delta &= ~(1 << i);
-                out += ((1 << i) & newState) ? " +" : " -";
-                out += QString::number(i);
+                out += (((1 << i) & newState) ? QLatin1String(" +") : QLatin1String(" -")) + QString::number(i);
             }
         }
     }
@@ -560,16 +555,12 @@ void MIDebugSession::stopDebugger()
     emit debuggerUserCommandOutput(QStringLiteral("(gdb) quit"));
 
     // We cannot wait forever, kill gdb after 5 seconds if it's not yet quit
-    QPointer<MIDebugSession> guarded_this(this);
-    QTimer::singleShot(5000, [guarded_this](){
-        if (guarded_this) {
-            if (!guarded_this->debuggerStateIsOn(s_programExited)
-                && guarded_this->debuggerStateIsOn(s_shuttingDown)) {
-                qCDebug(DEBUGGERCOMMON) << "debugger not shutdown - killing";
-                guarded_this->m_debugger->kill();
-                guarded_this->setDebuggerState(s_dbgNotStarted | s_appNotStarted);
-                guarded_this->raiseEvent(debugger_exited);
-            }
+    QTimer::singleShot(5000, this, [this]() {
+        if (!debuggerStateIsOn(s_programExited) && debuggerStateIsOn(s_shuttingDown)) {
+            qCDebug(DEBUGGERCOMMON) << "debugger not shutdown - killing";
+            m_debugger->kill();
+            setDebuggerState(s_dbgNotStarted | s_appNotStarted);
+            raiseEvent(debugger_exited);
         }
     });
 
@@ -884,7 +875,7 @@ void MIDebugSession::executeCmd()
         executeCmd();
         return;
     } else {
-        if (commandText[length-1] != '\n') {
+        if (commandText[length-1] != QLatin1Char('\n')) {
             bad_command = true;
             message = QStringLiteral("Debugger command does not end with newline");
         }
@@ -1027,7 +1018,7 @@ void MIDebugSession::slotInferiorStopped(const MI::AsyncRecord& r)
 
     if (reason == QLatin1String("exited-normally") || reason == QLatin1String("exited")) {
         if (r.hasField(QStringLiteral("exit-code"))) {
-            programNoApp(i18n("Exited with return code: %1", r["exit-code"].literal()));
+            programNoApp(i18n("Exited with return code: %1", r[QStringLiteral("exit-code")].literal()));
         } else {
             programNoApp(i18n("Exited normally"));
         }
@@ -1036,14 +1027,12 @@ void MIDebugSession::slotInferiorStopped(const MI::AsyncRecord& r)
     }
 
     if (reason == QLatin1String("exited-signalled")) {
-        programNoApp(i18n("Exited on signal %1", r["signal-name"].literal()));
+        programNoApp(i18n("Exited on signal %1", r[QStringLiteral("signal-name")].literal()));
         m_stateReloadNeeded = false;
         return;
     }
 
     if (reason == QLatin1String("watchpoint-scope")) {
-        QString number = r[QStringLiteral("wpnum")].literal();
-
         // FIXME: shuld remove this watchpoint
         // But first, we should consider if removing all
         // watchpoinst on program exit is the right thing to
@@ -1094,7 +1083,7 @@ void MIDebugSession::slotInferiorStopped(const MI::AsyncRecord& r)
             const MI::Value& frame = r[QStringLiteral("frame")];
             QString file, line, addr;
 
-            if (frame.hasField(QStringLiteral("fullname"))) file = frame[QStringLiteral("fullname")].literal();;
+            if (frame.hasField(QStringLiteral("fullname"))) file = frame[QStringLiteral("fullname")].literal();
             if (frame.hasField(QStringLiteral("line")))     line = frame[QStringLiteral("line")].literal();
             if (frame.hasField(QStringLiteral("addr")))     addr = frame[QStringLiteral("addr")].literal();
 
@@ -1213,7 +1202,7 @@ void MIDebugSession::explainDebuggerStatus()
         QString extra = i18n("Current command class: '%1'\n"
                              "Current command text: '%2'\n"
                              "Current command original text: '%3'\n",
-                             typeid(*currentCmd_).name(),
+                             QString::fromUtf8(typeid(*currentCmd_).name()),
                              currentCmd_->cmdToSend(),
                              currentCmd_->initialString());
 
@@ -1289,7 +1278,7 @@ void MIDebugSession::defaultErrorHandler(const MI::ResultRecord& result)
         qApp->activeWindow(),
         i18n("<b>Debugger error</b>"
              "<p>Debugger reported the following error:"
-             "<p><tt>%1", result["msg"].literal()),
+             "<p><tt>%1", result[QStringLiteral("msg")].literal()),
         i18n("Debugger error"));
 
     // Error most likely means that some change made in GUI
