@@ -134,7 +134,6 @@ void DisassembleWindow::setDisassemblyFlavor(DisassemblyFlavor flavor)
 {
     switch(flavor)
     {
-    default:
     case DisassemblyFlavorUnknown:
         m_disassemblyFlavorAtt->setChecked(false);
         m_disassemblyFlavorIntel->setChecked(false);
@@ -201,7 +200,7 @@ DisassembleWidget::DisassembleWidget(MIDebuggerPlugin* plugin, QWidget *parent)
         m_disassembleWindow->setUniformRowHeights(true);
         m_disassembleWindow->setRootIsDecorated(false);
 
-        m_disassembleWindow->setHeaderLabels(QStringList() << QLatin1String("") << i18n("Address") << i18n("Function") << i18n("Instruction"));
+        m_disassembleWindow->setHeaderLabels(QStringList{QString(), i18n("Address"), i18n("Function"), i18n("Instruction")});
 
         m_splitter->setStretchFactor(0, 1);
         m_splitter->setContentsMargins(0, 0, 0, 0);
@@ -364,7 +363,7 @@ void DisassembleWidget::disassembleMemoryRegion(const QString& from, const QStri
 
         QString cmd = (to.isEmpty())?
         QStringLiteral("-s %1 -e \"%1 + 256\" -- 0").arg(from ):
-        QStringLiteral("-s %1 -e %2+1 -- 0").arg(from).arg(to); // if both addr set
+        QStringLiteral("-s %1 -e %2+1 -- 0").arg(from, to); // if both addr set
 
         s->addCommand(DataDisassemble, cmd,
                       this, &DisassembleWidget::disassembleMemoryHandler);
@@ -394,12 +393,12 @@ void DisassembleWidget::disassembleMemoryHandler(const ResultRecord& r)
         //We use offset at the same column where function is.
         if(currentFunction == fct){
             if(!fct.isEmpty()){
-                fct = QStringLiteral("+") + offs;
+                fct = QLatin1Char('+') + offs;
             }
         }else { currentFunction = fct; }
 
         m_disassembleWindow->addTopLevelItem(new QTreeWidgetItem(m_disassembleWindow,
-                                                                 QStringList() << QString() << addr << fct << inst));
+                                                                 QStringList{QString(), addr, fct, inst}));
 
         if (i == 0) {
             lower_ = addr.toULong(&ok,16);
