@@ -180,9 +180,8 @@ void DocumentSwitcherPlugin::fillModel( Sublime::MainWindow* window )
             QString path = projectController->prettyFilePath(doc->url(),
                                                                               IProjectController::FormatPlain);
             const bool isPartOfOpenProject = QDir::isRelativePath(path);
-            if( path.endsWith('/') )
-            {
-                path.remove(path.length() - 1, 1);
+            if (path.endsWith(QLatin1Char('/'))) {
+                path.chop(1);
             }
             if( isPartOfOpenProject )
             {
@@ -198,7 +197,7 @@ void DocumentSwitcherPlugin::fillModel( Sublime::MainWindow* window )
                                                             fileInProjectInfo.second);
             } else
             {
-                itemText = itemText + " (" + path + ')';
+                itemText += QLatin1String(" (") + path + QLatin1Char(')');
             }
             project = projectController->findProjectForUrl(doc->url());
         }
@@ -375,7 +374,7 @@ void DocumentSwitcherPlugin::changeView( Sublime::View* view )
         documentLists[mainwindow][area].removeAt( idx );
     }
     qCDebug(PLUGIN_DOCUMENTSWITCHER) << "moving view to front, list should now not contain this view anymore" << view << view->document()->title();
-    qCDebug(PLUGIN_DOCUMENTSWITCHER) << "current area is:" << area << area->title() << "mainwnidow:" << mainwindow << mainwindow->windowTitle();;
+    qCDebug(PLUGIN_DOCUMENTSWITCHER) << "current area is:" << area << area->title() << "mainwindow:" << mainwindow << mainwindow->windowTitle();
     qCDebug(PLUGIN_DOCUMENTSWITCHER) << "idx of this view in list:" << documentLists[mainwindow][area].indexOf( view );
     documentLists[mainwindow][area].prepend( view );
     enableActions();
@@ -398,7 +397,7 @@ void DocumentSwitcherPlugin::removeView( Sublime::View* view )
     }
 
     qCDebug(PLUGIN_DOCUMENTSWITCHER) << "removing view, list should now not contain this view anymore" << view << view->document()->title();
-    qCDebug(PLUGIN_DOCUMENTSWITCHER) << "current area is:" << area << area->title() << "mainwnidow:" << mainwindow << mainwindow->windowTitle();;
+    qCDebug(PLUGIN_DOCUMENTSWITCHER) << "current area is:" << area << area->title() << "mainwindow:" << mainwindow << mainwindow->windowTitle();
     qCDebug(PLUGIN_DOCUMENTSWITCHER) << "idx of this view in list:" << documentLists[mainwindow][area].indexOf( view );
     enableActions();
 }
