@@ -42,11 +42,11 @@
 #include <QLineEdit>
 class la;
 
-Q_DECLARE_METATYPE(KDevelop::IProject*);
+Q_DECLARE_METATYPE(KDevelop::IProject*)
 
 QIcon PlasmoidExecutionConfig::icon() const
 {
-    return QIcon::fromTheme("system-run");
+    return QIcon::fromTheme(QStringLiteral("system-run"));
 }
 
 QStringList readProcess(QProcess* p)
@@ -56,7 +56,7 @@ QStringList readProcess(QProcess* p)
         QByteArray line = p->readLine();
         int nameEnd=line.indexOf(' ');
         if(nameEnd>0) {
-            ret += line.left(nameEnd);
+            ret += QString::fromUtf8(line.left(nameEnd));
         }
     }
     return ret;
@@ -92,9 +92,10 @@ void PlasmoidExecutionConfig::saveToConfiguration( KConfigGroup cfg, KDevelop::I
 {
     Q_UNUSED( project );
     cfg.writeEntry("PlasmoidIdentifier", identifier->lineEdit()->text());
-    QStringList args;
-    args += QStringLiteral("--formfactor");
-    args += formFactor->currentText();
+    QStringList args{
+        QStringLiteral("--formfactor"),
+        formFactor->currentText(),
+    };
     if(!themes->currentText().isEmpty()) {
         args += QStringLiteral("--theme");
         args += themes->currentText();
@@ -177,13 +178,12 @@ KJob* PlasmoidLauncher::start(const QString& launchMode, KDevelop::ILaunchConfig
 
 KJob* PlasmoidLauncher::calculateDependencies(KDevelop::ILaunchConfiguration* cfg)
 {
-    QVariantList deps = KDevelop::stringToQVariant( cfg->config().readEntry( "Dependencies", QString() ) ).toList();
+    const QVariantList deps = KDevelop::stringToQVariant(cfg->config().readEntry("Dependencies", QString())).toList();
     if( !deps.isEmpty() )
     {
         KDevelop::ProjectModel* model = KDevelop::ICore::self()->projectController()->projectModel();
         QList<KDevelop::ProjectBaseItem*> items;
-        foreach( const QVariant& dep, deps )
-        {
+        for (const QVariant& dep : deps) {
             KDevelop::ProjectBaseItem* item = model->itemFromIndex( model->pathToIndex( dep.toStringList() ) );
             if( item )
             {
@@ -250,7 +250,7 @@ QString PlasmoidExecutionConfigType::typeId()
 
 QIcon PlasmoidExecutionConfigType::icon() const
 {
-    return QIcon::fromTheme("plasma");
+    return QIcon::fromTheme(QStringLiteral("plasma"));
 }
 
 static bool canLaunchMetadataFile(const KDevelop::Path &path)
@@ -287,10 +287,10 @@ void PlasmoidExecutionConfigType::configureLaunchFromCmdLineArguments(KConfigGro
 QMenu* PlasmoidExecutionConfigType::launcherSuggestions()
 {
     QList<QAction*> found;
-    QList<KDevelop::IProject*> projects = KDevelop::ICore::self()->projectController()->projects();
-    foreach(KDevelop::IProject* p, projects) {
-        QSet<KDevelop::IndexedString> files = p->fileSet();
-        foreach(const KDevelop::IndexedString& file, files) {
+    const QList<KDevelop::IProject*> projects = KDevelop::ICore::self()->projectController()->projects();
+    for (KDevelop::IProject* p : projects) {
+        const QSet<KDevelop::IndexedString> files = p->fileSet();
+        for (const KDevelop::IndexedString& file : files) {
             KDevelop::Path path(file.str());
             if (path.lastPathSegment() == QLatin1String("metadata.desktop") && canLaunchMetadataFile(path)) {
                 path = path.parent();
@@ -321,7 +321,7 @@ void PlasmoidExecutionConfigType::suggestionTriggered()
     KDevelop::ILauncher* launcherInstance = launchers().at( 0 );
     QPair<QString,QString> launcher = qMakePair( launcherInstance->supportedModes().at(0), launcherInstance->id() );
 
-    QString name = relUrl.mid(relUrl.lastIndexOf('/')+1);
+    QString name = relUrl.mid(relUrl.lastIndexOf(QLatin1Char('/'))+1);
     KDevelop::ILaunchConfiguration* config = KDevelop::ICore::self()->runController()->createLaunchConfiguration(this, launcher, p, name);
     KConfigGroup cfg = config->config();
     cfg.writeEntry("PlasmoidIdentifier", relUrl);
