@@ -33,6 +33,16 @@ class ExternalScriptItem : public QStandardItem
 public:
   ExternalScriptItem();
 
+  /**
+   * The key is supposed to be unique inside the model
+   * @return The key of this script item
+   */
+  QString key() const;
+  /**
+   * Sets the label
+   */
+  void setKey( const QString& key );
+
   /**
    * @return The command to execute.
    */
@@ -198,6 +208,7 @@ public:
    */
   void save() const;
 private:
+  QString m_key;
   QString m_command;
   QString m_workingDirectory;
   SaveMode m_saveMode = SaveNone;
