@@ -29,11 +29,10 @@ using namespace KDevelop;
 struct KDevelop::ClassIdentifierPagePrivate
 {
     ClassIdentifierPagePrivate()
-        : classid(nullptr)
     {
     }
 
-    Ui::NewClassDialog* classid;
+    Ui::NewClassDialog* classid = nullptr;
 };
 
 ClassIdentifierPage::ClassIdentifierPage(QWidget* parent)
@@ -59,8 +58,6 @@ ClassIdentifierPage::ClassIdentifierPage(QWidget* parent)
             d->classid->keditlistwidget->lineEdit(),
             static_cast<void(QWidget::*)()>(&QWidget::setFocus));
 #endif
-
-    emit isValid(false);
 }
 
 ClassIdentifierPage::~ClassIdentifierPage()
