@@ -24,10 +24,6 @@
 
 #include "gdbconfigpage.h"
 
-#include <kconfiggroup.h>
-#include <KLocalizedString>
-#include <kmessagebox.h>
-
 #include <interfaces/idebugcontroller.h>
 #include <interfaces/ilaunchconfiguration.h>
 #include <interfaces/iproject.h>
@@ -43,6 +39,10 @@
 #include <interfaces/iruncontroller.h>
 #include <interfaces/icore.h>
 
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KMessageBox>
+
 using namespace KDevelop;
 namespace Config = KDevMI::GDB::Config;
 
@@ -62,9 +62,9 @@ GdbConfigPage::GdbConfigPage( QWidget* parent )
     connect(ui->kcfg_startWith, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &GdbConfigPage::changed);
 
     //Setup data info for combobox
-    ui->kcfg_startWith->setItemData(0, "ApplicationOutput" );
-    ui->kcfg_startWith->setItemData(1, "GdbConsole" );
-    ui->kcfg_startWith->setItemData(2, "FrameStack" );
+    ui->kcfg_startWith->setItemData(0, QStringLiteral("ApplicationOutput"));
+    ui->kcfg_startWith->setItemData(1, QStringLiteral("GdbConsole"));
+    ui->kcfg_startWith->setItemData(2, QStringLiteral("FrameStack"));
 }
 
 GdbConfigPage::~GdbConfigPage()
