@@ -239,12 +239,12 @@ private:
 #define COMPARE_DATA(index, expected) \
     do { if(!compareData((index), (expected), __FILE__, __LINE__)) return; } while (0)
 
-bool compareData(QModelIndex index, const QString& expected, const char *file, int line)
+bool compareData(const QModelIndex& index, const QString& expected, const char *file, int line)
 {
     QString s = index.model()->data(index, Qt::DisplayRole).toString();
     if (s != expected) {
         QTest::qFail(qPrintable(QString("'%0' didn't match expected '%1' in %2:%3")
-                                .arg(s).arg(expected).arg(file).arg(line)),
+                                .arg(s, expected, file).arg(line)),
                      file, line);
         return false;
     }
@@ -626,6 +626,10 @@ void GdbTest::testBreakOnReadBreakpoint2()
 
     session->run();
     WAIT_FOR_STATE(session, DebugSession::PausedState);
+    if(session->line() == 22) { // some GDB versions break 3 times on this line
+        session->run();
+        WAIT_FOR_STATE(session, DebugSession::PausedState);
+    }
     QCOMPARE(session->line(), 24);
 
     session->run();
@@ -677,11 +681,11 @@ void GdbTest::testInsertBreakpointWhileRunning()
     WAIT_FOR_STATE(session, DebugSession::ActiveState);
     QTest::qWait(2000);
     qDebug() << "adding breakpoint";
-    KDevelop::Breakpoint *b = breakpoints()->addCodeBreakpoint(QUrl::fromLocalFile(fileName), 25);
+    KDevelop::Breakpoint *b = breakpoints()->addCodeBreakpoint(QUrl::fromLocalFile(fileName), 30); // ++i;
     QTest::qWait(500);
     WAIT_FOR_STATE(session, DebugSession::PausedState);
     QTest::qWait(500);
-    QCOMPARE(session->line(), 25);
+    QCOMPARE(session->line(), 30); // ++i;
     b->setDeleted();
     session->run();
     WAIT_FOR_STATE(session, DebugSession::EndedState);
@@ -698,16 +702,16 @@ void GdbTest::testInsertBreakpointWhileRunningMultiple()
     WAIT_FOR_STATE(session, DebugSession::ActiveState);
     QTest::qWait(2000);
     qDebug() << "adding breakpoint";
-    KDevelop::Breakpoint *b1 = breakpoints()->addCodeBreakpoint(QUrl::fromLocalFile(fileName), 24);
-    KDevelop::Breakpoint *b2 = breakpoints()->addCodeBreakpoint(QUrl::fromLocalFile(fileName), 25);
+    KDevelop::Breakpoint *b1 = breakpoints()->addCodeBreakpoint(QUrl::fromLocalFile(fileName), 29); // static int i=0;
+    KDevelop::Breakpoint *b2 = breakpoints()->addCodeBreakpoint(QUrl::fromLocalFile(fileName), 30); // ++i;
     QTest::qWait(500);
     WAIT_FOR_STATE(session, DebugSession::PausedState);
     QTest::qWait(500);
-    QCOMPARE(session->line(), 24);
+    QCOMPARE(session->line(), 29); // static int i=0;
     session->run();
     WAIT_FOR_STATE(session, DebugSession::PausedState);
     QTest::qWait(500);
-    QCOMPARE(session->line(), 25);
+    QCOMPARE(session->line(), 30); // ++i;
     b1->setDeleted();
     b2->setDeleted();
     session->run();
@@ -787,15 +791,15 @@ void GdbTest::testShowStepInSource()
     {
         QCOMPARE(showStepInSourceSpy.count(), 3);
         QList<QVariant> arguments = showStepInSourceSpy.takeFirst();
-        QCOMPARE(arguments.first().value<QUrl>(), QUrl::fromLocalFile(debugeeFileName));
+        QCOMPARE(arguments.first().toUrl(), QUrl::fromLocalFile(debugeeFileName));
         QCOMPARE(arguments.at(1).toInt(), 29);
 
         arguments = showStepInSourceSpy.takeFirst();
-        QCOMPARE(arguments.first().value<QUrl>(), QUrl::fromLocalFile(debugeeFileName));
+        QCOMPARE(arguments.first().toUrl(), QUrl::fromLocalFile(debugeeFileName));
         QCOMPARE(arguments.at(1).toInt(), 22);
 
         arguments = showStepInSourceSpy.takeFirst();
-        QCOMPARE(arguments.first().value<QUrl>(), QUrl::fromLocalFile(debugeeFileName));
+        QCOMPARE(arguments.first().toUrl(), QUrl::fromLocalFile(debugeeFileName));
         QCOMPARE(arguments.at(1).toInt(), 23);
     }
 }
@@ -947,18 +951,18 @@ void GdbTest::testStackSwitchThread()
 
     TestFrameStackModel *stackModel = session->frameStackModel();
 
-    breakpoints()->addCodeBreakpoint(QUrl::fromLocalFile(fileName), 38);
+    breakpoints()->addCodeBreakpoint(QUrl::fromLocalFile(fileName), 40); // t3.start();
     QVERIFY(session->startDebugging(&cfg, m_iface));
     WAIT_FOR_STATE_AND_IDLE(session, DebugSession::PausedState);
 
-    QCOMPARE(stackModel->rowCount(), 4);
+    QVERIFY(stackModel->rowCount() > 2);
 
     QModelIndex tIdx = stackModel->index(0,0);
     COMPARE_DATA(tIdx, "#1 at main");
     QCOMPARE(stackModel->rowCount(tIdx), 1);
     COMPARE_DATA(stackModel->index(0, 0, tIdx), "0");
     COMPARE_DATA(stackModel->index(0, 1, tIdx), "main");
-    COMPARE_DATA(stackModel->index(0, 2, tIdx), fileName+":39");
+    COMPARE_DATA(stackModel->index(0, 2, tIdx), fileName+":41"); // QThread::usleep(500000);
 
     tIdx = stackModel->index(1,0);
     QVERIFY(stackModel->data(tIdx).toString().startsWith("#2 at "));
@@ -974,6 +978,11 @@ void GdbTest::testStackSwitchThread()
 void GdbTest::testAttach()
 {
     SKIP_IF_ATTACH_FORBIDDEN();
+#ifdef Q_OS_FREEBSD
+    // Despite successful attach GDB MI spits out a error message "Can't allocate registers". This gets caught by KDevMI layer and gets interpreted as error.
+    // Upstream PR: https://sourceware.org/bugzilla/show_bug.cgi?id=23464
+    QSKIP("GDB on FreeBSD produces an unexpected error message, on which KDevelop chokes");
+#endif
 
     QString fileName = findSourceFile(QStringLiteral("debugeeslow.cpp"));
 
@@ -987,13 +996,13 @@ void GdbTest::testAttach()
     session->attachToProcess(debugeeProcess.pid());
     WAIT_FOR_STATE(session, DebugSession::PausedState);
 
-    breakpoints()->addCodeBreakpoint(QUrl::fromLocalFile(fileName), 34);
+    breakpoints()->addCodeBreakpoint(QUrl::fromLocalFile(fileName), 39); // } after foo();
     QTest::qWait(100);
     session->run();
     QTest::qWait(2000);
     WAIT_FOR_STATE(session, DebugSession::PausedState);
-    if (session->line() < 34 || session->line() < 35) {
-        QCOMPARE(session->line(), 34);
+    if (session->line() < 39 || session->line() < 40) {
+        QCOMPARE(session->line(), 39);
     }
 
     session->run();
@@ -1003,8 +1012,11 @@ void GdbTest::testAttach()
 void GdbTest::testManualAttach()
 {
     SKIP_IF_ATTACH_FORBIDDEN();
-
-    QString fileName = findSourceFile(QStringLiteral("debugeeslow.cpp"));
+#ifdef Q_OS_FREEBSD
+    // Despite successful attach GDB MI spits out a error message "Can't allocate registers". This gets caught by KDevMI layer and gets interpreted as error.
+    // Upstream PR: https://sourceware.org/bugzilla/show_bug.cgi?id=23464
+    QSKIP("GDB on FreeBSD produces an unexpected error message, on which KDevelop chokes");
+#endif
 
     KProcess debugeeProcess;
     debugeeProcess << QStringLiteral("nice") << findExecutable(QStringLiteral("debuggee_debugeeslow")).toLocalFile();
@@ -1483,7 +1495,7 @@ void GdbTest::testInsertAndRemoveBreakpointWhileRunning()
     WAIT_FOR_STATE(session, DebugSession::ActiveState);
     QTest::qWait(2000);
     qDebug() << "adding breakpoint";
-    KDevelop::Breakpoint *b = breakpoints()->addCodeBreakpoint(QUrl::fromLocalFile(fileName), 25);
+    KDevelop::Breakpoint *b = breakpoints()->addCodeBreakpoint(QUrl::fromLocalFile(fileName), 30); // ++i;
     b->setDeleted();
     WAIT_FOR_STATE(session, DebugSession::EndedState);
 }
@@ -1817,11 +1829,12 @@ void GdbTest::testCatchpoint()
     QCOMPARE(session->line(), 29);
 
     session->addCommand(MI::NonMI, QStringLiteral("catch throw"));
+    WAIT_FOR_STATE_AND_IDLE(session, DebugSession::PausedState);
     session->run();
-    WAIT_FOR_STATE(session, DebugSession::PausedState);
+    WAIT_FOR_STATE_AND_IDLE(session, DebugSession::PausedState);
     QTest::qWait(1000);
 
-    const QList<KDevelop::FrameStackModel::FrameItem> frames = fsModel->frames(fsModel->currentThread());
+    const QVector<KDevelop::FrameStackModel::FrameItem> frames = fsModel->frames(fsModel->currentThread());
     QVERIFY(frames.size() >= 2);
     // frame 0 is somewhere inside libstdc++
     QCOMPARE(frames[1].file, QUrl::fromLocalFile(findSourceFile("debugeeexception.cpp")));
@@ -1849,7 +1862,7 @@ void GdbTest::testThreadAndFrameInfo()
 
     QSignalSpy outputSpy(session, &TestDebugSession::debuggerUserCommandOutput);
 
-    session->addCommand(new MI::UserCommand(MI::ThreadInfo,QLatin1String("")));
+    session->addCommand(new MI::UserCommand(MI::ThreadInfo, QString()));
     session->addCommand(new MI::UserCommand(MI::StackListLocals, QStringLiteral("0")));
     WAIT_FOR_STATE_AND_IDLE(session, DebugSession::PausedState); // wait for command finish
 
@@ -1986,7 +1999,7 @@ void GdbTest::testRegularExpressionBreakpoint()
         WAIT_FOR_STATE(session, DebugSession::PausedState);
         QCOMPARE(breakpoints()->breakpoints().count(), 3);
 
-        session->addCommand(MI::BreakDelete, QLatin1String(""));
+        session->addCommand(MI::BreakDelete, QString());
         session->run();
         WAIT_FOR_STATE(session, DebugSession::EndedState);
 }
@@ -1996,11 +2009,11 @@ void GdbTest::testChangeBreakpointWhileRunning() {
     TestDebugSession *session = new TestDebugSession;
 
     TestLaunchConfiguration c(findExecutable(QStringLiteral("debuggee_debugeeslow")));
-    KDevelop::Breakpoint* b = breakpoints()->addCodeBreakpoint(QStringLiteral("debugeeslow.cpp:25"));
+    KDevelop::Breakpoint* b = breakpoints()->addCodeBreakpoint(QStringLiteral("debugeeslow.cpp:30"));
     session->startDebugging(&c, m_iface);
 
     WAIT_FOR_STATE_AND_IDLE(session, DebugSession::PausedState);
-    QVERIFY(session->currentLine() >= 24 && session->currentLine() <= 26 );
+    QVERIFY(session->currentLine() >= 29 && session->currentLine() <= 31 );
     session->run();
     WAIT_FOR_STATE(session, DebugSession::ActiveState);
     b->setData(KDevelop::Breakpoint::EnableColumn, Qt::Unchecked);
