@@ -17,7 +17,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <KMessageBox>
+#include <ghproviderwidget.h>
 
 #include <QLabel>
 #include <QListView>
@@ -29,15 +29,16 @@
 #include <interfaces/icore.h>
 #include <interfaces/iplugincontroller.h>
 #include <vcs/interfaces/ibasicversioncontrol.h>
-#include <KLocalizedString>
+#include <vcs/vcslocation.h>
 
 #include <ghaccount.h>
 #include <ghdialog.h>
 #include <ghresource.h>
 #include <ghlineedit.h>
 #include <ghprovidermodel.h>
-#include <ghproviderwidget.h>
 
+#include <KLocalizedString>
+#include <KMessageBox>
 
 using namespace KDevelop;
 namespace gh
@@ -74,7 +75,7 @@ ProviderWidget::ProviderWidget(QWidget *parent)
     fillCombo();
     topLayout->addWidget(m_combo);
 
-    QPushButton *settings = new QPushButton(QIcon::fromTheme(QStringLiteral("configure")), QLatin1String(""), this);
+    QPushButton *settings = new QPushButton(QIcon::fromTheme(QStringLiteral("configure")), QString(), this);
     settings->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Fixed);
     settings->setToolTip(i18n("Click this button to configure your GitHub account"));
     connect(settings, &QPushButton::clicked, this, &ProviderWidget::showSettings);
@@ -93,13 +94,13 @@ KDevelop::VcsJob * ProviderWidget::createWorkingCopy(const QUrl &dest)
 
     auto plugin = ICore::self()->pluginController()->pluginForExtension(QStringLiteral("org.kdevelop.IBasicVersionControl"), QStringLiteral("kdevgit"));
     if (!plugin) {
-        KMessageBox::error(0, i18n("The Git plugin could not be loaded which is required to import a GitHub project."), i18n("GitHub Provider Error"));
+        KMessageBox::error(nullptr, i18n("The Git plugin could not be loaded which is required to import a GitHub project."), i18n("GitHub Provider Error"));
         return nullptr;
     }
 
     QString url = pos.data(ProviderModel::VcsLocationRole).toString();
     if (m_account->validAccount())
-      url = "https://" + m_account->token() + "@" + url.mid(8);
+      url = QLatin1String("https://") + m_account->token() + QLatin1Char('@') + url.midRef(8);
     QUrl real = QUrl(url);
     VcsLocation loc(real);
 
@@ -118,7 +119,7 @@ void ProviderWidget::fillCombo()
         m_combo->setCurrentIndex(2);
     }
     const QStringList &orgs = m_account->orgs();
-    foreach (const QString &org, orgs)
+    for (const QString& org : orgs)
         m_combo->addItem(org, 2);
 }
 
