@@ -17,20 +17,20 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <ghresource.h>
+
+#include <debug.h>
+#include <ghprovidermodel.h>
+
+#include <KIO/Scheduler>
+#include <KIO/TransferJob>
+#include <KIO/StoredTransferJob>
 
 #include <QUrl>
-#include <kio/scheduler.h>
-#include <kio/transferjob.h>
-#include <kio/storedtransferjob.h>
 #include <QJsonDocument>
 #include <QHostInfo>
 #include <QDateTime>
 
-#include <debug.h>
-#include <ghresource.h>
-#include <ghprovidermodel.h>
-
-
 namespace gh
 {
 /// Base url for the Github API v3.
@@ -43,8 +43,8 @@ KIO::StoredTransferJob* createHttpAuthJob(const QString &httpHeader)
     url.setPath(url.path() + QLatin1String("/authorizations"));
 
     // generate a unique token, see bug 372144
-    const QString tokenName = "KDevelop Github Provider : "
-        + QHostInfo::localHostName() + " - "
+    const QString tokenName = QLatin1String("KDevelop Github Provider : ")
+        + QHostInfo::localHostName() + QLatin1String(" - ")
         + QDateTime::currentDateTimeUtc().toString();
     const QByteArray data = QByteArrayLiteral("{ \"scopes\": [\"repo\"], \"note\": \"") + tokenName.toUtf8() + QByteArrayLiteral("\" }");
 
@@ -78,7 +78,7 @@ void Resource::getOrgs(const QString &token)
 void Resource::authenticate(const QString &name, const QString &password)
 {
     auto job = createHttpAuthJob(QLatin1String("Authorization: Basic ") + QString::fromUtf8(QByteArray(name.toUtf8() + ':' + password.toUtf8()).toBase64()));
-    job->addMetaData("PropagateHttpHeader","true");
+    job->addMetaData(QStringLiteral("PropagateHttpHeader"), QStringLiteral("true"));
     connect(job, &KIO::StoredTransferJob::result,
             this, &Resource::slotAuthenticate);
     job->start();
@@ -95,9 +95,10 @@ void Resource::twoFactorAuthenticate(const QString &transferHeader, const QStrin
 void Resource::revokeAccess(const QString &id, const QString &name, const QString &password)
 {
     QUrl url = baseUrl;
-    url.setPath(url.path() + "/authorizations/" + id);
+    url.setPath(url.path() + QLatin1String("/authorizations/") + id);
     KIO::TransferJob *job = KIO::http_delete(url, KIO::HideProgressInfo);
-    job->addMetaData(QStringLiteral("customHTTPHeader"), QLatin1String("Authorization: Basic ") + QString (name + ':' + password).toUtf8().toBase64());
+    const auto passwordBase64 = QString::fromLatin1(QString(name + QLatin1Char(':') + password).toUtf8().toBase64());
+    job->addMetaData(QStringLiteral("customHTTPHeader"), QLatin1String("Authorization: Basic ") + passwordBase64);
     /* And we don't care if it's successful ;) */
     job->start();
 }
@@ -109,7 +110,7 @@ KIO::TransferJob * Resource::getTransferJob(const QString &path, const QString &
     url.setPath(url.path() + path);
     KIO::TransferJob *job = KIO::get(url, KIO::Reload, KIO::HideProgressInfo);
     if (!token.isEmpty())
-        job->addMetaData(QStringLiteral("customHTTPHeader"), "Authorization: token " + token);
+        job->addMetaData(QStringLiteral("customHTTPHeader"), QLatin1String("Authorization: token ") + token);
     return job;
 }
 
@@ -119,9 +120,9 @@ void Resource::retrieveRepos(const QByteArray &data)
     QJsonDocument doc = QJsonDocument::fromJson(data, &error);
 
     if (error.error == 0) {
-        QVariantList map = doc.toVariant().toList();
+        const QVariantList list = doc.toVariant().toList();
         m_model->clear();
-        foreach (const QVariant &it, map) {
+        for (const QVariant& it : list) {
             const QVariantMap &map = it.toMap();
             Response res;
             res.name = map.value(QStringLiteral("name")).toString();
@@ -146,8 +147,9 @@ void Resource::retrieveOrgs(const QByteArray &data)
     QJsonDocument doc = QJsonDocument::fromJson(data, &error);
 
     if (error.error == 0) {
-        QVariantList json = doc.toVariant().toList();
-        foreach (QVariant it, json) {
+        const QVariantList json = doc.toVariant().toList();
+        res.reserve(json.size());
+        for (const QVariant& it : json) {
             QVariantMap map = it.toMap();
             res << map.value(QStringLiteral("login")).toString();
         }
