@@ -104,7 +104,7 @@ public:
                              KDevelop::IBasicVersionControl::RecursionMode recursion = KDevelop::IBasicVersionControl::Recursive) override;
 
     KDevelop::VcsJob* diff(const QUrl& fileOrDirectory, const KDevelop::VcsRevision& srcRevision, const KDevelop::VcsRevision& dstRevision,
-                                   KDevelop::VcsDiff::Type, RecursionMode recursion) override;
+                                   RecursionMode recursion) override;
 
     KDevelop::VcsJob* log( const QUrl& localLocation, const KDevelop::VcsRevision& rev, unsigned long limit) override;
     KDevelop::VcsJob* log(const QUrl& localLocation, const KDevelop::VcsRevision& rev, const KDevelop::VcsRevision& limit) override;
@@ -125,11 +125,11 @@ public:
     KDevelop::VcsJob* mergeBranch(const QUrl& repository, const QString& branchName) override;
 
     //graph helpers
-    QList<DVcsEvent> getAllCommits(const QString &repo) override;
+    QVector<KDevelop::DVcsEvent> allCommits(const QString& repo) override;
 
     //used in log
-    void parseLogOutput(const KDevelop::DVcsJob * job,
-                        QList<DVcsEvent>& commits) const override;
+    void parseLogOutput(const KDevelop::DVcsJob* job,
+                        QVector<KDevelop::DVcsEvent>& commits) const override;
 
     void additionalMenuEntries(QMenu* menu, const QList<QUrl>& urls) override;
     
