@@ -154,9 +154,9 @@ void GitInitTest::addFiles()
     VERIFYJOB(j);
 
     //Now let's create several files and try "git add file1 file2 file3"
-    QStringList files = QStringList() << QStringLiteral("file1") << QStringLiteral("file2") << QStringLiteral("la la");
+    const QStringList files{QStringLiteral("file1"), QStringLiteral("file2"), QStringLiteral("la la")};
     QList<QUrl> multipleFiles;
-    foreach(const QString& file, files) {
+    for (const QString& file : files) {
         QVERIFY(writeFile(gitTest_BaseDir() + file, file));
         multipleFiles << QUrl::fromLocalFile(gitTest_BaseDir() + file);
     }
@@ -438,12 +438,12 @@ void GitInitTest::revHistory()
     addFiles();
     commitFiles();
 
-    QList<DVcsEvent> commits = m_plugin->getAllCommits(gitTest_BaseDir());
+    QVector<KDevelop::DVcsEvent> commits = m_plugin->allCommits(gitTest_BaseDir());
     QVERIFY(!commits.isEmpty());
     QStringList logMessages;
 
     for (int i = 0; i < commits.count(); ++i)
-        logMessages << commits[i].getLog();
+        logMessages << commits[i].log();
 
     QCOMPARE(commits.count(), 2);
 
@@ -451,15 +451,15 @@ void GitInitTest::revHistory()
 
     QCOMPARE(logMessages[1], QStringLiteral("Test commit"));
 
-    QVERIFY(commits[1].getParents().isEmpty());  //0 is later than 1!
+    QVERIFY(commits[1].parents().isEmpty());  //0 is later than 1!
 
-    QVERIFY(!commits[0].getParents().isEmpty()); //initial commit is on the top
+    QVERIFY(!commits[0].parents().isEmpty()); //initial commit is on the top
 
-    QVERIFY(commits[1].getCommit().contains(QRegExp("^\\w{,40}$")));
+    QVERIFY(commits[1].commit().contains(QRegExp("^\\w{,40}$")));
 
-    QVERIFY(commits[0].getCommit().contains(QRegExp("^\\w{,40}$")));
+    QVERIFY(commits[0].commit().contains(QRegExp("^\\w{,40}$")));
 
-    QVERIFY(commits[0].getParents()[0].contains(QRegExp("^\\w{,40}$")));
+    QVERIFY(commits[0].parents()[0].contains(QRegExp("^\\w{,40}$")));
 }
 
 void GitInitTest::testAnnotation()
@@ -574,7 +574,7 @@ void GitInitTest::testDiff()
 
     VcsRevision srcrev = VcsRevision::createSpecialRevision(VcsRevision::Base);
     VcsRevision dstrev = VcsRevision::createSpecialRevision(VcsRevision::Working);
-    VcsJob* j = m_plugin->diff(QUrl::fromLocalFile(gitTest_BaseDir()), srcrev, dstrev, VcsDiff::DiffUnified, IBasicVersionControl::Recursive);
+    VcsJob* j = m_plugin->diff(QUrl::fromLocalFile(gitTest_BaseDir()), srcrev, dstrev, IBasicVersionControl::Recursive);
     VERIFYJOB(j);
 
     KDevelop::VcsDiff d = j->fetchResults().value<KDevelop::VcsDiff>();
