@@ -28,7 +28,6 @@
 #include <KLocalizedString>
 #include <KParts/MainWindow>
 #include <KTextEditor/Document>
-#include <KTextEditor/Cursor>
 #include <KTextEditor/View>
 
 #include <interfaces/icore.h>
@@ -36,6 +35,7 @@
 #include <interfaces/idocument.h>
 #include <interfaces/idocumentcontroller.h>
 #include <interfaces/iproject.h>
+#include <interfaces/contextmenuextension.h>
 #include <project/projectmodel.h>
 #include <util/path.h>
 #include <language/interfaces/editorcontext.h>
@@ -59,12 +59,11 @@ static QString patternFromSelection(const KDevelop::IDocument* doc)
     // Before anything, this removes line feeds from the
     // beginning and the end.
     int len = pattern.length();
-    if (len > 0 && pattern[0] == '\n')
-    {
+    if (len > 0 && pattern[0] == QLatin1Char('\n')) {
         pattern.remove(0, 1);
         len--;
     }
-    if (len > 0 && pattern[len-1] == '\n')
+    if (len > 0 && pattern[len-1] == QLatin1Char('\n'))
         pattern.truncate(len-1);
     return pattern;
 }
