@@ -92,7 +92,7 @@ void LldbVariable::formatChanged()
             QPointer<LldbVariable> guarded_this(this);
             m_debugSession->addCommand(
                 VarSetFormat,
-                QStringLiteral(" %1 %2 ").arg(varobj()).arg(format2str(format())),
+                QStringLiteral(" %1 %2 ").arg(varobj(), format2str(format())),
                 [guarded_this](const ResultRecord &r){
                     if(guarded_this && r.hasField(QStringLiteral("changelist"))) {
                         if (r[QStringLiteral("changelist")].size() > 0) {
@@ -109,11 +109,11 @@ QString LldbVariable::formatValue(const QString& value) const
     // Data formatter emits value with unicode escape sequence for string and char,
     // translate them back.
     // Only check with first char is enough, as unquote will do the rest check
-    if (value.startsWith('"')) {
+    if (value.startsWith(QLatin1Char('"'))) {
         return Utils::quote(Utils::unquote(value, true));
-    } else if (value.startsWith('\'')) {
-        return Utils::quote(Utils::unquote(value, true, '\''), '\'');
-    } else if (value.startsWith('b')) {
+    } else if (value.startsWith(QLatin1Char('\''))) {
+        return Utils::quote(Utils::unquote(value, true, QLatin1Char('\'')), QLatin1Char('\''));
+    } else if (value.startsWith(QLatin1Char('b'))) {
         // this is a byte array, don't translate unicode, simply return without 'b' prefix
         return value.mid(1);
     }
