@@ -50,7 +50,8 @@ LldbDebuggerPlugin::LldbDebuggerPlugin(QObject *parent, const QVariantList &)
     setXMLFile(QStringLiteral("kdevlldbui.rc"));
 
     auto pluginController = core()->pluginController();
-    for(auto plugin : pluginController->allPluginsForExtension(QStringLiteral("org.kdevelop.IExecutePlugin"))) {
+    const auto plugins = pluginController->allPluginsForExtension(QStringLiteral("org.kdevelop.IExecutePlugin"));
+    for (auto plugin : plugins) {
         setupExecutePlugin(plugin, true);
     }
 
@@ -67,7 +68,8 @@ LldbDebuggerPlugin::LldbDebuggerPlugin(QObject *parent, const QVariantList &)
 
 void LldbDebuggerPlugin::unload()
 {
-    for(auto plugin : core()->pluginController()->allPluginsForExtension(QStringLiteral("org.kdevelop.IExecutePlugin"))) {
+    const auto plugins = core()->pluginController()->allPluginsForExtension(QStringLiteral("org.kdevelop.IExecutePlugin"));
+    for (auto plugin : plugins) {
         setupExecutePlugin(plugin, false);
     }
     Q_ASSERT(m_launchers.isEmpty());
@@ -100,7 +102,7 @@ void LldbDebuggerPlugin::setupExecutePlugin(KDevelop::IPlugin* plugin, bool load
     }
 }
 
-void LldbDebuggerPlugin::setupToolviews()
+void LldbDebuggerPlugin::setupToolViews()
 {
     m_consoleFactory = new DebuggerToolFactory<NonInterruptDebuggerConsoleView>(this,
                             QStringLiteral("org.kdevelop.debugger.LldbConsole"), Qt::BottomDockWidgetArea);
@@ -112,10 +114,10 @@ void LldbDebuggerPlugin::setupToolviews()
     */
 }
 
-void LldbDebuggerPlugin::unloadToolviews()
+void LldbDebuggerPlugin::unloadToolViews()
 {
     if (m_consoleFactory) {
-        qCDebug(DEBUGGERLLDB) << "Removing toolview";
+        qCDebug(DEBUGGERLLDB) << "Removing tool view";
         core()->uiController()->removeToolView(m_consoleFactory);
         m_consoleFactory = nullptr;
     }
