@@ -38,6 +38,7 @@
 #include <interfaces/idebugcontroller.h>
 #include <interfaces/ilaunchconfiguration.h>
 #include <util/environmentprofilelist.h>
+#include <qtcompat_p.h>
 
 #include <KConfigGroup>
 #include <KLocalizedString>
@@ -52,6 +53,7 @@
 
 using namespace KDevMI::LLDB;
 using namespace KDevMI::MI;
+using namespace KDevMI;
 using namespace KDevelop;
 
 struct ExecRunHandler : public MICommandHandler
@@ -75,7 +77,7 @@ struct ExecRunHandler : public MICommandHandler
                     --m_remainRetry;
                     // resend the command again.
                     ++m_activeCommands;
-                    m_session->addCommand(ExecRun, QStringLiteral(""),
+                    m_session->addCommand(ExecRun, QString(),
                                           this, // use *this as handler, so we can track error times
                                           CmdMaybeStartsRunning | CmdHandlesError);
                     return;
@@ -99,24 +101,20 @@ struct ExecRunHandler : public MICommandHandler
 
 DebugSession::DebugSession(LldbDebuggerPlugin *plugin)
     : MIDebugSession(plugin)
-    , m_breakpointController(nullptr)
-    , m_variableController(nullptr)
-    , m_frameStackModel(nullptr)
     , m_formatterPath()
-    , m_hasCorrectCLIOutput(false)
 {
     m_breakpointController = new BreakpointController(this);
     m_variableController = new VariableController(this);
     m_frameStackModel = new LldbFrameStackModel(this);
 
-    if (m_plugin) m_plugin->setupToolviews();
+    if (m_plugin) m_plugin->setupToolViews();
 
     connect(this, &DebugSession::stateChanged, this, &DebugSession::handleSessionStateChange);
 }
 
 DebugSession::~DebugSession()
 {
-    if (m_plugin) m_plugin->unloadToolviews();
+    if (m_plugin) m_plugin->unloadToolViews();
 }
 
 BreakpointController *DebugSession::breakpointController() const
@@ -174,7 +172,7 @@ void DebugSession::initializeDebugger()
                                                QStringLiteral("kdevlldb/formatters/all.py"));
     }
     if (!formatterPath.isEmpty()) {
-        addCommand(MI::NonMI, "command script import " + KShell::quoteArg(formatterPath));
+        addCommand(MI::NonMI, QLatin1String("command script import ") + KShell::quoteArg(formatterPath));
     }
 
 
@@ -201,13 +199,13 @@ void DebugSession::configInferior(ILaunchConfiguration *cfg, IExecutePlugin *iex
         auto remoteDir = grp.readEntry(Config::LldbRemotePathEntry, QString());
         auto remoteExe = QDir(remoteDir).filePath(QFileInfo(executable).fileName());
 
-        filesymbols += " -r " + Utils::quote(remoteExe);
+        filesymbols += QLatin1String(" -r ") + Utils::quote(remoteExe);
 
         addCommand(MI::FileExecAndSymbols, filesymbols,
                    this, &DebugSession::handleFileExecAndSymbols,
                    CmdHandlesError);
 
-        addCommand(MI::TargetSelect, "remote " + connStr,
+        addCommand(MI::TargetSelect, QLatin1String("remote ") + connStr,
                    this, &DebugSession::handleTargetSelect, CmdHandlesError);
 
         // ensure executable is on remote end
@@ -231,11 +229,12 @@ void DebugSession::configInferior(ILaunchConfiguration *cfg, IExecutePlugin *iex
     const auto &envVariables = environmentProfiles.variables(envProfileName);
     if (!envVariables.isEmpty()) {
         QStringList vars;
+        vars.reserve(envVariables.size());
         for (auto it = envVariables.constBegin(), ite = envVariables.constEnd(); it != ite; ++it) {
             vars.append(QStringLiteral("%0=%1").arg(it.key(), Utils::quote(it.value())));
         }
         // actually using lldb command 'settings set target.env-vars' which accepts multiple values
-        addCommand(GdbSet, "environment " + vars.join(QStringLiteral(" ")));
+        addCommand(GdbSet, QLatin1String("environment ") + vars.join(QLatin1Char(' ')));
     }
 
     // Break on start: can't use "-exec-run --start" because in lldb-mi
@@ -300,7 +299,7 @@ bool DebugSession::execInferior(ILaunchConfiguration *cfg, IExecutePlugin *, con
         // run custom config script right before we starting the inferior,
         // so the user has the freedom to change everything.
         if (configLldbScript.isValid()) {
-            addCommand(MI::NonMI, "command source -s 0 " + KShell::quoteArg(configLldbScript.toLocalFile()));
+            addCommand(MI::NonMI, QLatin1String("command source -s 0 ") + KShell::quoteArg(configLldbScript.toLocalFile()));
         }
 
         addCommand(MI::ExecRun, QString(), new ExecRunHandler(this),
@@ -317,7 +316,7 @@ bool DebugSession::loadCoreFile(ILaunchConfiguration *,
                CmdHandlesError);
     raiseEvent(connected_to_program);
 
-    addCommand(new CliCommand(NonMI, "target create -c " + Utils::quote(corefile),
+    addCommand(new CliCommand(NonMI, QLatin1String("target create -c ") + Utils::quote(corefile),
                               this, &DebugSession::handleCoreFile,
                               CmdHandlesError));
     return true;
@@ -375,7 +374,7 @@ void DebugSession::handleCoreFile(const QStringList &s)
                 i18n("<b>Failed to load core file</b>"
                 "<p>Debugger reported the following error:"
                 "<p><tt>%1",
-                s.join('\n')),
+                s.join(QLatin1Char('\n'))),
                 i18n("Startup error"));
             stopDebugger();
             return;
@@ -421,7 +420,7 @@ void DebugSession::handleVersion(const QStringList& s)
 
 // minimal version is 3.8.1
 #ifdef Q_OS_OSX
-    QRegularExpression rx("^lldb-(\\d+).(\\d+).(\\d+)\\b", QRegularExpression::MultilineOption);
+    QRegularExpression rx(QStringLiteral("^lldb-(\\d+).(\\d+).(\\d+)\\b"), QRegularExpression::MultilineOption);
     // lldb 3.8.1 reports version 350.99.0 on OS X
     const int min_ver[] = {350, 99, 0};
 #else
@@ -480,7 +479,7 @@ void DebugSession::updateAllVariables()
         }
     }
 
-    for (auto var : toplevels) {
+    for (auto var : qAsConst(toplevels)) {
         var->refetch();
     }
 }
