@@ -962,7 +962,7 @@ void LldbTest::testRegularExpressionBreakpoint()
 
     QCOMPARE(breakpoints()->breakpoints().count(), 3);
 
-    session->addCommand(MI::BreakDelete, QLatin1String(""));
+    session->addCommand(MI::BreakDelete, QString());
     session->run();
     WAIT_FOR_STATE(session, DebugSession::EndedState);
 }
@@ -1058,15 +1058,15 @@ void LldbTest::testShowStepInSource()
     {
         QCOMPARE(showStepInSourceSpy.count(), 3);
         QList<QVariant> arguments = showStepInSourceSpy.takeFirst();
-        QCOMPARE(arguments.first().value<QUrl>(), QUrl::fromLocalFile(m_debugeeFileName));
+        QCOMPARE(arguments.first().toUrl(), QUrl::fromLocalFile(m_debugeeFileName));
         QCOMPARE(arguments.at(1).toInt(), 29);
 
         arguments = showStepInSourceSpy.takeFirst();
-        QCOMPARE(arguments.first().value<QUrl>(), QUrl::fromLocalFile(m_debugeeFileName));
+        QCOMPARE(arguments.first().toUrl(), QUrl::fromLocalFile(m_debugeeFileName));
         QCOMPARE(arguments.at(1).toInt(), 22);
 
         arguments = showStepInSourceSpy.takeFirst();
-        QCOMPARE(arguments.first().value<QUrl>(), QUrl::fromLocalFile(m_debugeeFileName));
+        QCOMPARE(arguments.first().toUrl(), QUrl::fromLocalFile(m_debugeeFileName));
         QCOMPARE(arguments.at(1).toInt(), 23);
     }
 }
@@ -1898,6 +1898,6 @@ void KDevMI::LLDB::LldbTest::testEnvironmentCd()
     QCOMPARE(outputLines, QStringList() << path.toLocalFile());
 }
 
-QTEST_MAIN(KDevMI::LLDB::LldbTest);
+QTEST_MAIN(KDevMI::LLDB::LldbTest)
 
 #include "test_lldb.moc"
