@@ -27,6 +27,7 @@
 #include <interfaces/icore.h>
 #include <interfaces/idocumentationcontroller.h>
 
+#include <QStringListModel>
 #include <limits>
 
 namespace {
@@ -40,8 +41,6 @@ using namespace KDevelop;
 ManPageModel::ManPageModel(QObject* parent)
     : QAbstractItemModel(parent)
     , m_indexModel(new QStringListModel(this))
-    , m_loaded(false)
-    , m_nbSectionLoaded(0)
 {
     QMetaObject::invokeMethod(const_cast<ManPageModel*>(this), "initModel", Qt::QueuedConnection);
 }
@@ -182,7 +181,7 @@ void ManPageModel::showItem(const QModelIndex& idx)
     if (idx.isValid() && idx.internalId() != INVALID_ID) {
         QString sectionUrl = m_sectionList.at(idx.internalId()).first;
         QString page = manPage(sectionUrl, idx.row());
-        IDocumentation::Ptr newDoc(new ManPageDocumentation(page, QUrl(sectionUrl + '/' + page)));
+        IDocumentation::Ptr newDoc(new ManPageDocumentation(page, QUrl(sectionUrl + QLatin1Char('/') + page)));
         ICore::self()->documentationController()->showDocumentation(newDoc);
     }
 }
