@@ -25,7 +25,6 @@
 #include <QMenu>
 #include <QMimeDatabase>
 #include <QMimeType>
-#include <QSignalMapper>
 #include <QVariantList>
 
 #include <KSharedConfig>
@@ -88,8 +87,7 @@ bool canOpenDefault(const QString& mimeType)
 }
 
 OpenWithPlugin::OpenWithPlugin ( QObject* parent, const QVariantList& )
-    : IPlugin ( QStringLiteral("kdevopenwith"), parent ),
-    m_actionMap( nullptr )
+    : IPlugin ( QStringLiteral("kdevopenwith"), parent )
 {
 }
 
@@ -105,7 +103,6 @@ KDevelop::ContextMenuExtension OpenWithPlugin::contextMenuExtension(KDevelop::Co
     }
 
     m_urls.clear();
-    m_actionMap.reset();
     m_services.clear();
 
     FileContext* filectx = dynamic_cast<FileContext*>( context );
@@ -128,9 +125,6 @@ KDevelop::ContextMenuExtension OpenWithPlugin::contextMenuExtension(KDevelop::Co
         return KDevelop::ContextMenuExtension();
     }
 
-    m_actionMap.reset(new QSignalMapper( this ));
-    connect( m_actionMap.data(), static_cast<void(QSignalMapper::*)(const QString&)>(&QSignalMapper::mapped), this, &OpenWithPlugin::open );
-
     // Ok, lets fetch the mimetype for the !!first!! url and the relevant services
     // TODO: Think about possible alternatives to using the mimetype of the first url.
     QMimeType mimetype = QMimeDatabase().mimeTypeForUrl(m_urls.first());
@@ -140,8 +134,8 @@ KDevelop::ContextMenuExtension OpenWithPlugin::contextMenuExtension(KDevelop::Co
     QList<QAction*> appActions = actionsForServiceType(QStringLiteral("Application"), parent);
 
     OpenWithContext subContext(m_urls, mimetype);
-    QList<ContextMenuExtension> extensions = ICore::self()->pluginController()->queryPluginsForContextMenuExtensions( &subContext, parent);
-    foreach( const ContextMenuExtension& ext, extensions ) {
+    const QList<ContextMenuExtension> extensions = ICore::self()->pluginController()->queryPluginsForContextMenuExtensions( &subContext, parent);
+    for (const ContextMenuExtension& ext : extensions) {
         appActions += ext.actions(ContextMenuExtension::OpenExternalGroup);
         partActions += ext.actions(ContextMenuExtension::OpenEmbeddedGroup);
     }
@@ -186,14 +180,14 @@ KDevelop::ContextMenuExtension OpenWithPlugin::contextMenuExtension(KDevelop::Co
 
 QList<QAction*> OpenWithPlugin::actionsForServiceType(const QString& serviceType, QWidget* parent)
 {
-    KService::List list = KMimeTypeTrader::self()->query( m_mimeType, serviceType );
+    const KService::List list = KMimeTypeTrader::self()->query( m_mimeType, serviceType );
     KService::Ptr pref = KMimeTypeTrader::self()->preferredService( m_mimeType, serviceType );
 
     m_services += list;
     QList<QAction*> actions;
     QAction* standardAction = nullptr;
     const QString defaultId = defaultForMimeType(m_mimeType);
-    foreach( KService::Ptr svc, list ) {
+    for (auto& svc : list) {
         QAction* act = new QAction(isTextEditor(svc) ? i18n("Default Editor") : svc->name(), parent);
         act->setIcon( QIcon::fromTheme( svc->icon() ) );
         if (svc->storageId() == defaultId || (defaultId.isEmpty() && isTextEditor(svc))) {
@@ -201,8 +195,8 @@ QList<QAction*> OpenWithPlugin::actionsForServiceType(const QString& serviceType
             font.setBold(true);
             act->setFont(font);
         }
-        connect(act, &QAction::triggered, m_actionMap.data(), static_cast<void(QSignalMapper::*)()>(&QSignalMapper::map));
-        m_actionMap->setMapping( act, svc->storageId() );
+        const QString sid = svc->storageId();
+        connect(act, &QAction::triggered, this, [this, sid]() { open(sid); } );
         actions << act;
         if ( isTextEditor(svc) ) {
             standardAction = act;
