@@ -41,10 +41,10 @@
 #include <libkomparediff2/kompare.h>
 #include <libkomparediff2/diffsettings.h>
 
-#include <ktexteditor/document.h>
-#include <ktexteditor/modificationinterface.h>
-#include <ktexteditor/movingrange.h>
-#include <ktexteditor/view.h>
+#include <KTextEditor/Document>
+#include <KTextEditor/ModificationInterface>
+#include <KTextEditor/MovingRange>
+#include <KTextEditor/View>
 
 ///Whether arbitrary exceptions that occurred while diff-parsing within the library should be caught
 #define CATCHLIBDIFF
@@ -207,7 +207,7 @@ void PatchReviewPlugin::removeHighlighting( const QUrl& file ) {
 void PatchReviewPlugin::notifyPatchChanged() {
     if (m_patch) {
         qCDebug(PLUGIN_PATCHREVIEW) << "notifying patch change: " << m_patch->file();
-        m_updateKompareTimer->start( 500 );
+        m_updateKompareTimer->start();
     } else {
         m_updateKompareTimer->stop();
     }
@@ -302,7 +302,7 @@ void PatchReviewPlugin::updateKompareModel() {
     } catch ( const QString & str ) {
         KMessageBox::error( nullptr, str, i18n( "Kompare Model Update" ) );
     } catch ( const char * str ) {
-        KMessageBox::error( nullptr, str, i18n( "Kompare Model Update" ) );
+        KMessageBox::error( nullptr, QLatin1String(str), i18n( "Kompare Model Update" ) );
     }
     removeHighlighting();
     m_modelList.reset( nullptr );
@@ -394,7 +394,8 @@ void PatchReviewPlugin::cancelReview() {
     }
 }
 
-void PatchReviewPlugin::finishReview( QList<QUrl> selection ) {
+void PatchReviewPlugin::finishReview(const QList<QUrl>& selection)
+{
     if( m_patch && m_patch->finishReview( selection ) ) {
         closeReview();
     }
@@ -422,7 +423,7 @@ void PatchReviewPlugin::switchToEmptyReviewArea()
 QUrl PatchReviewPlugin::urlForFileModel( const Diff2::DiffModel* model )
 {
     KDevelop::Path path(QDir::cleanPath(m_patch->baseDir().toLocalFile()));
-    QVector<QString> destPath = KDevelop::Path("/"+model->destinationPath()).segments();
+    QVector<QString> destPath = KDevelop::Path(QLatin1Char('/') + model->destinationPath()).segments();
     if (destPath.size() >= (int)m_depth) {
         destPath = destPath.mid(m_depth);
     }
@@ -527,6 +528,7 @@ PatchReviewPlugin::PatchReviewPlugin( QObject *parent, const QVariantList & )
 
     m_updateKompareTimer = new QTimer( this );
     m_updateKompareTimer->setSingleShot( true );
+    m_updateKompareTimer->setInterval(500);
     connect( m_updateKompareTimer, &QTimer::timeout, this, &PatchReviewPlugin::updateKompareModel );
 
     m_finishReview = new QAction(i18n("Finish Review"), this);
