@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "perforceplugin.h"
+#include "ui/perforceimportmetadatawidget.h"
 #include "debug.h"
 
 #include "qtcompat_p.h"
@@ -27,7 +28,7 @@
 #include <QProcessEnvironment>
 #include <QMenu>
 
-#include <kmessagebox.h>
+#include <KMessageBox>
 #include <vcs/vcsjob.h>
 #include <vcs/vcsrevision.h>
 #include <vcs/vcsstatusinfo.h>
@@ -65,7 +66,7 @@ QString toRevisionName(const KDevelop::VcsRevision& rev, const QString& currentR
                 case VcsRevision::Previous:
                     Q_ASSERT(!currentRevision.isEmpty());
                     tmp.setNum(previous);
-                    tmp.prepend("#");
+                    tmp.prepend(QLatin1Char('#'));
                     return tmp;
                 case VcsRevision::Start:
                     return QString();
@@ -74,8 +75,7 @@ QString toRevisionName(const KDevelop::VcsRevision& rev, const QString& currentR
             }
             break;
         case VcsRevision::GlobalNumber:
-            tmp.append("#");
-            tmp.append(rev.revisionValue().toString());
+            tmp.append(QLatin1Char('#') + rev.revisionValue().toString());
             return tmp;
         case VcsRevision::Date:
         case VcsRevision::FileNumber:
@@ -135,9 +135,9 @@ QString PerforcePlugin::name() const
     return i18n("Perforce");
 }
 
-KDevelop::VcsImportMetadataWidget* PerforcePlugin::createImportMetadataWidget(QWidget* /*parent*/)
+KDevelop::VcsImportMetadataWidget* PerforcePlugin::createImportMetadataWidget(QWidget* parent)
 {
-    return nullptr;
+    return new PerforceImportMetadataWidget(parent);
 }
 
 bool PerforcePlugin::isValidRemoteRepositoryUrl(const QUrl& remoteLocation)
@@ -195,11 +195,11 @@ QString PerforcePlugin::getRepositoryName(const QFileInfo& curFile)
     QScopedPointer<DVcsJob> job(p4fstatJob(curFile, KDevelop::OutputJob::Silent));
     if (job->exec() && job->status() == KDevelop::VcsJob::JobSucceeded) {
         if (!job->output().isEmpty()) {
-            QStringList outputLines = job->output().split('\n', QString::SkipEmptyParts);
-            foreach(const QString & line, outputLines) {
+            const QStringList outputLines = job->output().split('\n', QString::SkipEmptyParts);
+            for (const QString& line : outputLines) {
                 int idx(line.indexOf(DEPOT_FILE_STR));
                 if (idx != -1) {
-                    ret = line.right(line.size() - DEPOT_FILE_STR.size());
+                    ret = line.mid(DEPOT_FILE_STR.size());
                     return ret;
                 }
             }
@@ -304,7 +304,7 @@ KDevelop::VcsJob* PerforcePlugin::commit(const QString& message, const QList<QUr
     return job;
 }
 
-KDevelop::VcsJob* PerforcePlugin::diff(const QUrl& fileOrDirectory, const KDevelop::VcsRevision& srcRevision, const KDevelop::VcsRevision& dstRevision, KDevelop::VcsDiff::Type , KDevelop::IBasicVersionControl::RecursionMode /*recursion*/)
+KDevelop::VcsJob* PerforcePlugin::diff(const QUrl& fileOrDirectory, const KDevelop::VcsRevision& srcRevision, const KDevelop::VcsRevision& dstRevision, KDevelop::IBasicVersionControl::RecursionMode /*recursion*/)
 {
     QFileInfo curFile(fileOrDirectory.toLocalFile());
     QString depotSrcFileName = getRepositoryName(curFile);
@@ -316,8 +316,7 @@ KDevelop::VcsJob* PerforcePlugin::diff(const QUrl& fileOrDirectory, const KDevel
     switch (dstRevision.revisionType()) {
     case VcsRevision::FileNumber:
     case VcsRevision::GlobalNumber:
-        depotDstFileName.append("#");
-        depotDstFileName.append(dstRevision.prettyValue());
+        depotDstFileName.append(QLatin1Char('#') + dstRevision.prettyValue());
         *job << m_perforceExecutable << "diff2" << "-u" << depotSrcFileName << depotDstFileName;
         break;
     case VcsRevision::Special:
@@ -514,7 +513,7 @@ QList<QVariant> PerforcePlugin::getQvariantFromLogOutput(QStringList const& outp
     int indexofAt;
     int changeNumber = 0;
     
-    foreach(const QString & line, outputLines) {
+    for (const QString& line : outputLines) {
         if (!line.startsWith(LOGENTRY_START) && !line.startsWith(DEPOTMESSAGE_START)  && !line.startsWith('\t')) {
             currentFileName = line;
         }
@@ -553,9 +552,8 @@ QList<QVariant> PerforcePlugin::getQvariantFromLogOutput(QStringList const& outp
 
 void PerforcePlugin::parseP4StatusOutput(DVcsJob* job)
 {
-    QStringList outputLines = job->output().split('\n', QString::SkipEmptyParts);
+    const QStringList outputLines = job->output().split('\n', QString::SkipEmptyParts);
     QVariantList statuses;
-    QList<QUrl> processedFiles;
     static const QString ACTION_STR(QStringLiteral("... action "));
     static const QString CLIENT_FILE_STR(QStringLiteral("... clientFile "));
 
@@ -563,10 +561,10 @@ void PerforcePlugin::parseP4StatusOutput(DVcsJob* job)
 
     VcsStatusInfo status;
     status.setState(VcsStatusInfo::ItemUserState);
-    foreach(const QString & line, outputLines) {
+    for (const QString& line : outputLines) {
         int idx(line.indexOf(ACTION_STR));
         if (idx != -1) {
-            QString curr = line.right(line.size() - ACTION_STR.size());
+            QString curr = line.mid(ACTION_STR.size());
 
             if (curr == QLatin1String("edit")) {
                 status.setState(VcsStatusInfo::ItemModified);
@@ -579,7 +577,7 @@ void PerforcePlugin::parseP4StatusOutput(DVcsJob* job)
         }
         idx = line.indexOf(CLIENT_FILE_STR);
         if (idx != -1) {
-            QUrl fileUrl = QUrl::fromLocalFile(line.right(line.size() - CLIENT_FILE_STR.size()));
+            QUrl fileUrl = QUrl::fromLocalFile(line.mid(CLIENT_FILE_STR.size()));
 
             status.setUrl(fileUrl);
         }
@@ -645,8 +643,7 @@ void PerforcePlugin::parseP4AnnotateOutput(DVcsJob *job)
 
     QStringList lines = job->output().split('\n');
 
-    size_t lineNumber(0);
-    QMap<QString, VcsAnnotationLine> definedRevisions;
+    int lineNumber = 0;
     QMap<qlonglong, VcsEvent>::iterator currentEvent;
     bool convertToIntOk(false);
     int globalRevisionInt(0);
