@@ -73,7 +73,7 @@ QVector<KDevelop::IProblem::Ptr> ProblemReporterModel::problems(const QSet<KDeve
     QVector<IProblem::Ptr> result;
     DUChainReadLocker lock;
 
-    foreach (const IndexedString& doc, docs) {
+    for (const IndexedString& doc : docs) {
         if (doc.isEmpty())
             continue;
 
@@ -81,7 +81,9 @@ QVector<KDevelop::IProblem::Ptr> ProblemReporterModel::problems(const QSet<KDeve
         if (!ctx)
             continue;
 
-        foreach (const ProblemPointer& p, DUChainUtils::allProblemsForContext(ctx)) {
+        const auto allProblems = DUChainUtils::allProblemsForContext(ctx);
+        result.reserve(result.size() + allProblems.size());
+        for (const ProblemPointer& p : allProblems) {
             result.append(p);
         }
     }
@@ -95,7 +97,7 @@ void ProblemReporterModel::forceFullUpdate()
 
     QSet<IndexedString> documents = store()->documents()->get();
     if (showImports())
-        documents += store()->documents()->getImports();
+        documents += store()->documents()->imports();
 
     DUChainReadLocker lock(DUChain::lock());
     foreach (const IndexedString& document, documents) {
@@ -140,7 +142,7 @@ void ProblemReporterModel::problemsUpdated(const KDevelop::IndexedString& url)
 
     // skip update for urls outside current scope
     if (!store()->documents()->get().contains(url) &&
-        !(showImports() && store()->documents()->getImports().contains(url)))
+        !(showImports() && store()->documents()->imports().contains(url)))
         return;
 
     /// m_minTimer will expire in MinTimeout unless some other parsing job finishes in this period.
@@ -159,7 +161,7 @@ void ProblemReporterModel::rebuildProblemList()
     QVector<IProblem::Ptr> allProblems = problems(store()->documents()->get());
 
     if (showImports())
-        allProblems += problems(store()->documents()->getImports());
+        allProblems += problems(store()->documents()->imports());
 
     store()->setProblems(allProblems);
 
