@@ -25,7 +25,6 @@
 #include <QAction>
 #include <QLineEdit>
 #include <QMenu>
-#include <QSignalMapper>
 #include <QTabWidget>
 #include <QTimer>
 #include <QVBoxLayout>
@@ -34,6 +33,7 @@
 #include <interfaces/ilanguagecontroller.h>
 #include <shell/problemconstants.h>
 #include <shell/problemmodelset.h>
+#include <util/expandablelineedit.h>
 #include "problemtreeview.h"
 #include "problemmodel.h"
 
@@ -95,30 +95,11 @@ void ProblemsView::setupActions()
         }
         addAction(m_scopeMenu);
 
-        QSignalMapper* scopeMapper = new QSignalMapper(this);
-        scopeMapper->setMapping(m_currentDocumentAction, CurrentDocument);
-        scopeMapper->setMapping(openDocumentsAction, OpenDocuments);
-        scopeMapper->setMapping(currentProjectAction, CurrentProject);
-        scopeMapper->setMapping(allProjectAction, AllProjects);
-        connect(m_currentDocumentAction, &QAction::triggered, scopeMapper,
-                static_cast<void (QSignalMapper::*)()>(&QSignalMapper::map));
-        connect(openDocumentsAction, &QAction::triggered, scopeMapper,
-                static_cast<void (QSignalMapper::*)()>(&QSignalMapper::map));
-        connect(currentProjectAction, &QAction::triggered, scopeMapper,
-                static_cast<void (QSignalMapper::*)()>(&QSignalMapper::map));
-        connect(allProjectAction, &QAction::triggered, scopeMapper,
-                static_cast<void (QSignalMapper::*)()>(&QSignalMapper::map));
-
-        {
-            scopeMapper->setMapping(actions.last(), BypassScopeFilter);
-            connect(actions.last(), &QAction::triggered, scopeMapper,
-                    static_cast<void (QSignalMapper::*)()>(&QSignalMapper::map));
-        }
-
-        connect(scopeMapper, static_cast<void (QSignalMapper::*)(int)>(&QSignalMapper::mapped),
-                this, [this](int index) {
-            setScope(index);
-        });
+        connect(m_currentDocumentAction, &QAction::triggered, this, [this](){ setScope(CurrentDocument); });
+        connect(openDocumentsAction, &QAction::triggered, this, [this](){ setScope(OpenDocuments); });
+        connect(currentProjectAction, &QAction::triggered, this, [this](){ setScope(CurrentProject); });
+        connect(allProjectAction, &QAction::triggered, this, [this](){ setScope(AllProjects); });
+        connect(actions.last(), &QAction::triggered, this, [this](){ setScope(BypassScopeFilter); });
     }
 
     {
@@ -188,43 +169,27 @@ void ProblemsView::setupActions()
         addAction(m_groupingMenu);
 
         noGroupingAction->setChecked(true);
-        QSignalMapper* groupingMapper = new QSignalMapper(this);
-        groupingMapper->setMapping(noGroupingAction, NoGrouping);
-        groupingMapper->setMapping(pathGroupingAction, PathGrouping);
-        groupingMapper->setMapping(severityGroupingAction, SeverityGrouping);
 
-        connect(noGroupingAction, &QAction::triggered, groupingMapper,
-                static_cast<void (QSignalMapper::*)()>(&QSignalMapper::map));
-        connect(pathGroupingAction, &QAction::triggered, groupingMapper,
-                static_cast<void (QSignalMapper::*)()>(&QSignalMapper::map));
-        connect(severityGroupingAction, &QAction::triggered, groupingMapper,
-                static_cast<void (QSignalMapper::*)()>(&QSignalMapper::map));
-
-        connect(groupingMapper, static_cast<void (QSignalMapper::*)(int)>(&QSignalMapper::mapped),
-                this, [this](int index) {
-            currentView()->model()->setGrouping(index);
-        });
+        connect(noGroupingAction, &QAction::triggered, this, [this](){ currentView()->model()->setGrouping(NoGrouping); });
+        connect(pathGroupingAction, &QAction::triggered, this, [this](){ currentView()->model()->setGrouping(PathGrouping); });
+        connect(severityGroupingAction, &QAction::triggered, this, [this](){ currentView()->model()->setGrouping(SeverityGrouping); });
     }
 
     {
         QTimer* filterTimer = new QTimer(this);
         filterTimer->setSingleShot(true);
+        filterTimer->setInterval(500);
 
         connect(filterTimer, &QTimer::timeout, this, [this]() {
             setFilter(m_filterEdit->text());
         });
 
-        m_filterEdit = new QLineEdit(this);
+        m_filterEdit = new KExpandableLineEdit(this);
         m_filterEdit->setClearButtonEnabled(true);
         m_filterEdit->setPlaceholderText(i18n("Search..."));
 
-        QSizePolicy p(m_filterEdit->sizePolicy());
-        p.setHorizontalPolicy(QSizePolicy::Fixed);
-        m_filterEdit->setSizePolicy(p);
-
-        connect(m_filterEdit, &QLineEdit::textChanged, this, [filterTimer](const QString&) {
-            filterTimer->start(500);
-        });
+        connect(m_filterEdit, &QLineEdit::textChanged,
+                filterTimer, static_cast<void (QTimer::*)()>(&QTimer::start));
 
         QWidgetAction* filterAction = new QWidgetAction(this);
         filterAction->setDefaultWidget(m_filterEdit);
@@ -402,8 +367,8 @@ void ProblemsView::onCurrentChanged(int idx)
     if (idx == -1)
         return;
 
-    setFilter(QStringLiteral(""), m_prevTabIdx);
-    setFilter(QStringLiteral(""));
+    setFilter(QString(), m_prevTabIdx);
+    setFilter(QString());
     m_prevTabIdx = idx;
 
     updateActions();
