@@ -27,9 +27,7 @@ using namespace KDevelop;
 
 Filter::Filter()
     : targets(Files | Folders)
-    , type(Exclusive)
 {
-
 }
 
 Filter::Filter(const SerializedFilter& filter)
@@ -38,11 +36,11 @@ Filter::Filter(const SerializedFilter& filter)
     , type(filter.type)
 {
     QString pattern = filter.pattern;
-    if (!filter.pattern.startsWith('/') && !filter.pattern.startsWith('*')) {
+    if (!filter.pattern.startsWith(QLatin1Char('/')) && !filter.pattern.startsWith(QLatin1Char('*'))) {
         // implicitly match against trailing relative path
         pattern.prepend(QLatin1String("*/"));
     }
-    if (pattern.endsWith('/') && targets != Filter::Files) {
+    if (pattern.endsWith(QLatin1Char('/')) && targets != Filter::Files) {
         // implicitly match against folders
         targets = Filter::Folders;
         pattern.chop(1);
@@ -52,7 +50,7 @@ Filter::Filter(const SerializedFilter& filter)
 
 SerializedFilter::SerializedFilter()
     : targets(Filter::Files | Filter::Folders)
-    , type(Filter::Exclusive)
+
 {
 
 }
@@ -70,6 +68,7 @@ namespace KDevelop {
 SerializedFilters defaultFilters()
 {
     SerializedFilters ret;
+    ret.reserve(20);
 
     // filter hidden files
     ret << SerializedFilter(QStringLiteral(".*"), Filter::Targets(Filter::Files | Filter::Folders));
@@ -82,7 +81,7 @@ SerializedFilters defaultFilters()
         QStringLiteral(".git"), QStringLiteral("CVS"), QStringLiteral(".svn"), QStringLiteral("_svn"),
         QStringLiteral("SCCS"), QStringLiteral("_darcs"), QStringLiteral(".hg"), QStringLiteral(".bzr"), QStringLiteral("__pycache__")
     };
-    foreach(const QString& folder, invalidFolders) {
+    for (const QString& folder : invalidFolders) {
         ret << SerializedFilter(folder, Filter::Folders);
     }
 
@@ -99,7 +98,7 @@ SerializedFilters defaultFilters()
         // python cache and object files
         QStringLiteral("*.pyc"), QStringLiteral("*.pyo")
     };
-    foreach(const QString& filePattern, filePatterns) {
+    for (const QString& filePattern : filePatterns) {
         ret << SerializedFilter(filePattern, Filter::Files);
     }
 
@@ -144,7 +143,7 @@ void writeFilters(const SerializedFilters& filters, KSharedConfigPtr config)
     KConfigGroup group = config->group("Filters");
     group.writeEntry("size", filters.size());
     int i = 0;
-    foreach(const SerializedFilter& filter, filters) {
+    for (const SerializedFilter& filter : filters) {
         KConfigGroup subGroup = group.group(QByteArray::number(i++));
         subGroup.writeEntry("pattern", filter.pattern);
         subGroup.writeEntry("targets", static_cast<int>(filter.targets));
@@ -157,7 +156,7 @@ Filters deserialize(const SerializedFilters& filters)
 {
     Filters ret;
     ret.reserve(filters.size());
-    foreach(const SerializedFilter& filter, filters) {
+    for (const SerializedFilter& filter : filters) {
         ret << Filter(filter);
     }
     return ret;
