@@ -34,7 +34,6 @@
 #include <KLocalizedString>
 
 #include <project/projectmodel.h>
-#include <language/duchain/duchainutils.h>
 #include <interfaces/contextmenuextension.h>
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/iproject.h>
@@ -50,23 +49,20 @@
 #include "projectmodelsaver.h"
 #include "projectmodelitemdelegate.h"
 #include "debug.h"
-#include <language/duchain/duchainlock.h>
-#include <language/duchain/duchain.h>
-#include <language/util/navigationtooltip.h>
 #include <project/projectutils.h>
 #include <widgetcolorizer.h>
 
 using namespace KDevelop;
 
 namespace {
-const char settingsConfigGroup[] = "ProjectTreeView";
+
+QString settingsConfigGroup() { return QStringLiteral("ProjectTreeView"); }
 
 QList<ProjectFileItem*> fileItemsWithin(const QList<ProjectBaseItem*>& items)
 {
     QList<ProjectFileItem*> fileItems;
     fileItems.reserve(items.size());
-    foreach(ProjectBaseItem* item, items)
-    {
+    for (ProjectBaseItem* item : items) {
         if (ProjectFileItem *file = item->file())
             fileItems.append(file);
         else if (item->folder())
@@ -165,19 +161,19 @@ void ProjectTreeView::dropEvent(QDropEvent* event)
 
             QString seq = QKeySequence( Qt::ShiftModifier ).toString();
             seq.chop(1); // chop superfluous '+'
-            QAction* move = new QAction(i18n( "&Move Here" ) + '\t' + seq, &dropMenu);
+            QAction* move = new QAction(i18n("&Move Here") + QLatin1Char('\t') + seq, &dropMenu);
             move->setIcon(QIcon::fromTheme(QStringLiteral("go-jump")));
             dropMenu.addAction(move);
 
             seq = QKeySequence( Qt::ControlModifier ).toString();
             seq.chop(1);
-            QAction* copy = new QAction(i18n( "&Copy Here" ) + '\t' + seq, &dropMenu);
+            QAction* copy = new QAction(i18n("&Copy Here") + QLatin1Char('\t') + seq, &dropMenu);
             copy->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
             dropMenu.addAction(copy);
 
             dropMenu.addSeparator();
 
-            QAction* cancel = new QAction(i18n( "C&ancel" ) + '\t' + QKeySequence( Qt::Key_Escape ).toString(), &dropMenu);
+            QAction* cancel = new QAction(i18n("C&ancel") + QLatin1Char('\t') + QKeySequence(Qt::Key_Escape).toString(), &dropMenu);
             cancel->setIcon(QIcon::fromTheme(QStringLiteral("process-stop")));
             dropMenu.addAction(cancel);
 
@@ -195,6 +191,7 @@ void ProjectTreeView::dropEvent(QDropEvent* event)
             QList<ProjectBaseItem*> usefulItems = topLevelItemsWithin(selectionCtxt->items());
             filterDroppedItems(usefulItems, destItem);
             Path::List paths;
+            paths.reserve(usefulItems.size());
             foreach (ProjectBaseItem* i, usefulItems) {
                 paths << i->path();
             }
@@ -230,13 +227,13 @@ void ProjectTreeView::dropEvent(QDropEvent* event)
 
             QString seq = QKeySequence( Qt::ControlModifier ).toString();
             seq.chop(1);
-            QAction* addToTarget = new QAction(i18n( "&Add to Target" ) + '\t' + seq, &dropMenu);
+            QAction* addToTarget = new QAction(i18n("&Add to Target") + QLatin1Char('\t') + seq, &dropMenu);
             addToTarget->setIcon(QIcon::fromTheme(QStringLiteral("edit-link")));
             dropMenu.addAction(addToTarget);
 
             dropMenu.addSeparator();
 
-            QAction* cancel = new QAction(i18n( "C&ancel" ) + '\t' + QKeySequence( Qt::Key_Escape ).toString(), &dropMenu);
+            QAction* cancel = new QAction(i18n("C&ancel") + QLatin1Char('\t') + QKeySequence(Qt::Key_Escape).toString(), &dropMenu);
             cancel->setIcon(QIcon::fromTheme(QStringLiteral("process-stop")));
             dropMenu.addAction(cancel);
 
@@ -339,7 +336,7 @@ void ProjectTreeView::popupContextMenu( const QPoint &pos )
     QMenu menu( this );
 
     KDevelop::ProjectItemContextImpl context(itemlist);
-    QList<ContextMenuExtension> extensions = ICore::self()->pluginController()->queryPluginsForContextMenuExtensions(&context, &menu);
+    const QList<ContextMenuExtension> extensions = ICore::self()->pluginController()->queryPluginsForContextMenuExtensions(&context, &menu);
 
     QList<QAction*> buildActions;
     QList<QAction*> vcsActions;
@@ -348,8 +345,7 @@ void ProjectTreeView::popupContextMenu( const QPoint &pos )
     QList<QAction*> projectActions;
     QList<QAction*> fileActions;
     QList<QAction*> runActions;
-    foreach( const ContextMenuExtension& ext, extensions )
-    {
+    for (const ContextMenuExtension& ext : extensions) {
         buildActions += ext.actions(ContextMenuExtension::BuildGroup);
         fileActions += ext.actions(ContextMenuExtension::FileGroup);
         projectActions += ext.actions(ContextMenuExtension::ProjectGroup);
@@ -406,7 +402,7 @@ void ProjectTreeView::saveState( IProject* project )
     }
 
     KConfigGroup configGroup( ICore::self()->activeSession()->config(),
-                              QString( settingsConfigGroup ).append( project->name() ) );
+                              settingsConfigGroup() + project->name() );
 
     ProjectModelSaver saver;
     saver.setProject( project );
@@ -421,7 +417,7 @@ void ProjectTreeView::restoreState( IProject* project )
     }
 
     KConfigGroup configGroup( ICore::self()->activeSession()->config(),
-                              QString( settingsConfigGroup ).append( project->name() ) );
+                              settingsConfigGroup() + project->name() );
     ProjectModelSaver saver;
     saver.setProject( project );
     saver.setView( this );
@@ -433,7 +429,8 @@ void ProjectTreeView::rowsInserted( const QModelIndex& parent, int start, int en
     QTreeView::rowsInserted( parent, start, end );
 
     if ( !parent.model() ) {
-        for ( const auto& project: selectedProjects() ) {
+        const auto& projects = selectedProjects();
+        for (const auto& project: projects) {
             restoreState( project->project() );
         }
     }
@@ -442,7 +439,8 @@ void ProjectTreeView::rowsInserted( const QModelIndex& parent, int start, int en
 void ProjectTreeView::rowsAboutToBeRemoved( const QModelIndex& parent, int start, int end )
 {
     if ( !parent.model() ) {
-        for ( const auto& project: selectedProjects() ) {
+        const auto& projects = selectedProjects();
+        for (const auto& project : projects) {
             saveState( project->project() );
         }
     }
@@ -459,46 +457,6 @@ void ProjectTreeView::aboutToShutdown()
     }
 }
 
-bool ProjectTreeView::event(QEvent* event)
-{
-    if(event->type()==QEvent::ToolTip)
-    {
-        QHelpEvent* helpEvent = static_cast<QHelpEvent*>(event);
-        QModelIndex idxView = indexAt(helpEvent->pos());
-
-        ProjectBaseItem* it = idxView.data(ProjectModel::ProjectItemRole).value<ProjectBaseItem*>();
-        QModelIndex idx;
-        if(it)
-            idx = it->index();
-
-        if((m_idx!=idx || !m_tooltip) && it && it->file())
-        {
-            m_idx=idx;
-            ProjectFileItem* file=it->file();
-            KDevelop::DUChainReadLocker lock(KDevelop::DUChain::lock());
-            TopDUContext* top= DUChainUtils::standardContextForUrl(file->path().toUrl());
-
-            if(m_tooltip)
-                m_tooltip->close();
-
-            if(top)
-            {
-                QWidget* navigationWidget = top->createNavigationWidget();
-                if( navigationWidget )
-                {
-                    m_tooltip = new KDevelop::NavigationToolTip(this, helpEvent->globalPos() + QPoint(40, 0), navigationWidget);
-                    m_tooltip->resize( navigationWidget->sizeHint() + QSize(10, 10) );
-                    qCDebug(PLUGIN_PROJECTMANAGERVIEW) << "tooltip size" << m_tooltip->size();
-                    ActiveToolTip::showToolTip(m_tooltip);
-                    return true;
-                }
-            }
-        }
-    }
-
-    return QAbstractItemView::event(event);
-}
-
 void ProjectTreeView::keyPressEvent(QKeyEvent* event)
 {
     if (event->key() == Qt::Key_Return && currentIndex().isValid() && state()!=QAbstractItemView::EditingState)
