@@ -23,8 +23,8 @@
 
 #include <QIcon>
 
-#include <kio/deletejob.h>
-#include <klocalizedstring.h>
+#include <KIO/DeleteJob>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KJobWidgets>
 
@@ -45,12 +45,6 @@ QMakeBuilderPreferences::QMakeBuilderPreferences(KDevelop::IPlugin* plugin,
     m_prefsUi = new Ui::QMakeConfig;
     m_prefsUi->setupUi(this);
 
-    // display icons instead of text
-    m_prefsUi->addButton->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
-    m_prefsUi->addButton->setText(QString());
-    m_prefsUi->removeButton->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
-    m_prefsUi->removeButton->setText(QString());
-
     m_chooserUi = new QMakeBuildDirChooser(m_project);
     auto groupBoxLayout = new QVBoxLayout(m_prefsUi->groupBox);
     groupBoxLayout->addWidget(m_chooserUi);
