@@ -104,7 +104,7 @@ QHash<QString, QString> QMakeConfig::queryQMake(const QString& qmakeExecutable,
 
     const int rc = p.execute();
     if (rc != 0) {
-        qCWarning(KDEV_QMAKE) << "failed to execute qmake query " << p.program().join(QStringLiteral(" ")) << "return code was:" << rc;
+        qCWarning(KDEV_QMAKE) << "failed to execute qmake query " << p.program().join(QLatin1Char(' ')) << "return code was:" << rc;
         return QHash<QString, QString>();
     }
 
@@ -112,7 +112,7 @@ QHash<QString, QString> QMakeConfig::queryQMake(const QString& qmakeExecutable,
     QTextStream stream(&p);
     while (!stream.atEnd()) {
         const QString line = stream.readLine();
-        const int colon = line.indexOf(':');
+        const int colon = line.indexOf(QLatin1Char(':'));
         if (colon == -1) {
             continue;
         }
@@ -121,7 +121,7 @@ QHash<QString, QString> QMakeConfig::queryQMake(const QString& qmakeExecutable,
         const auto value = line.mid(colon + 1);
         hash.insert(key, value);
     }
-    qCDebug(KDEV_QMAKE) << "Ran qmake (" << p.program().join(QStringLiteral(" ")) << "), found:" << hash;
+    qCDebug(KDEV_QMAKE) << "Ran qmake (" << p.program().join(QLatin1Char(' ')) << "), found:" << hash;
     return hash;
 }
 
@@ -130,8 +130,9 @@ QString QMakeConfig::findBasicMkSpec(const QHash<QString, QString>& qmakeVars)
     QStringList paths;
     if (qmakeVars.contains(QStringLiteral("QMAKE_MKSPECS"))) {
         // qt4
-        foreach (const QString& dir, qmakeVars["QMAKE_MKSPECS"].split(QtCompat::listSeparator())) {
-            paths << dir + "/default/qmake.conf";
+        const auto mkspecDirs = qmakeVars[QStringLiteral("QMAKE_MKSPECS")].split(QtCompat::listSeparator());
+        foreach (const QString& dir, mkspecDirs) {
+            paths << dir + QLatin1String("/default/qmake.conf");
         }
     } else if (!qmakeVars.contains(QStringLiteral("QMAKE_MKSPECS")) && qmakeVars.contains(QStringLiteral("QMAKE_SPEC"))) {
         QString path;
@@ -148,10 +149,10 @@ QString QMakeConfig::findBasicMkSpec(const QHash<QString, QString>& qmakeVars)
             // cross compilation
             path = qmakeVars[QStringLiteral("QT_HOST_DATA")];
         } else {
-            Q_ASSERT(qmakeVars.contains("QT_INSTALL_PREFIX"));
+            Q_ASSERT(qmakeVars.contains(QStringLiteral("QT_INSTALL_PREFIX")));
             path = qmakeVars[QStringLiteral("QT_INSTALL_PREFIX")];
         }
-        path += "/mkspecs/" + qmakeVars[QStringLiteral("QMAKE_SPEC")] + "/qmake.conf";
+        path += QLatin1String("/mkspecs/") + qmakeVars[QStringLiteral("QMAKE_SPEC")] + QLatin1String("/qmake.conf");
         paths << path;
     }
 
