@@ -28,7 +28,7 @@
 #include <QList>
 #include <QUrl>
 
-#include <kio/global.h>
+#include <KIO/Global>
 #include <KConfigGroup>
 #include <KDirWatch>
 #include <KLocalizedString>
@@ -77,8 +77,6 @@ K_PLUGIN_FACTORY_WITH_JSON(QMakeSupportFactory, "kdevqmakemanager.json", registe
 QMakeProjectManager::QMakeProjectManager(QObject* parent, const QVariantList&)
     : AbstractFileManagerPlugin(QStringLiteral("kdevqmakemanager"), parent)
     , IBuildSystemManager()
-    , m_builder(nullptr)
-    , m_runQMake(nullptr)
 {
     IPlugin* i = core()->pluginController()->pluginForExtension(QStringLiteral("org.kdevelop.IQMakeBuilder"));
     Q_ASSERT(i);
@@ -121,7 +119,7 @@ Path QMakeProjectManager::buildDirectory(ProjectBaseItem* item) const
         } else {
             // build sub-item
             foreach (QMakeProjectFile* pro, qmakeItem->projectFiles()) {
-                if (QDir(pro->absoluteDir()) == QFileInfo(qmakeItem->path().toUrl().toLocalFile() + '/').absoluteDir()
+                if (QDir(pro->absoluteDir()) == QFileInfo(qmakeItem->path().toUrl().toLocalFile() + QLatin1Char('/')).absoluteDir()
                     || pro->hasSubProject(qmakeItem->path().toUrl().toLocalFile())) {
                     // get path from project root and it to buildDir
                     dir = QMakeConfig::buildDirFromSrc(qmakeItem->project(), Path(pro->absoluteDir()));
@@ -149,7 +147,6 @@ ProjectFolderItem* QMakeProjectManager::createFolderItem(IProject* project, cons
 
 ProjectFolderItem* QMakeProjectManager::projectRootItem(IProject* project, const Path& path)
 {
-    QFileInfo fi(path.toLocalFile());
     QDir dir(path.toLocalFile());
 
     auto item = new QMakeFolderItem(project, path);
@@ -187,8 +184,7 @@ ProjectFolderItem* QMakeProjectManager::buildFolderItem(IProject* project, const
 {
     // find .pro or .pri files in dir
     QDir dir(path.toLocalFile());
-    QStringList projectFiles = dir.entryList(QStringList() << QStringLiteral("*.pro")
-                                                           << QStringLiteral("*.pri"),
+    const QStringList projectFiles = dir.entryList(QStringList{QStringLiteral("*.pro"), QStringLiteral("*.pri")},
                                              QDir::Files);
     if (projectFiles.isEmpty()) {
         return nullptr;
@@ -203,7 +199,7 @@ ProjectFolderItem* QMakeProjectManager::buildFolderItem(IProject* project, const
         return nullptr;
     }
 
-    foreach (const QString& file, projectFiles) {
+    for (const QString& file : projectFiles) {
         const QString absFile = dir.absoluteFilePath(file);
 
         // TODO: multiple includes by different .pro's
@@ -382,7 +378,7 @@ Path::List QMakeProjectManager::collectDirectories(ProjectBaseItem* item, const
         foreach (QMakeProjectFile* pro, folder->projectFiles()) {
             if (pro->files().contains(item->path().toLocalFile())) {
                 const QStringList directories = collectIncludes ? pro->includeDirectories() : pro->frameworkDirectories();
-                foreach (const QString& dir, directories) {
+                for (const QString& dir : directories) {
                     Path path(dir);
                     if (!list.contains(path)) {
                         list << path;
@@ -394,7 +390,7 @@ Path::List QMakeProjectManager::collectDirectories(ProjectBaseItem* item, const
             // fallback for new files, use all possible include dirs
             foreach (QMakeProjectFile* pro, folder->projectFiles()) {
                 const QStringList directories = collectIncludes ? pro->includeDirectories() : pro->frameworkDirectories();
-                foreach (const QString& dir, directories) {
+                for (const QString& dir : directories) {
                     Path path(dir);
                     if (!list.contains(path)) {
                         list << path;
@@ -467,7 +463,7 @@ QMakeCache* QMakeProjectManager::findQMakeCache(IProject* project, const Path& p
 
     if (curdir.exists(QStringLiteral(".qmake.cache"))) {
         qCDebug(KDEV_QMAKE) << "Found QMake cache in " << curdir.absolutePath();
-        return new QMakeCache(curdir.canonicalPath() + "/.qmake.cache");
+        return new QMakeCache(curdir.canonicalPath() + QLatin1String("/.qmake.cache"));
     }
     return nullptr;
 }
