@@ -37,7 +37,7 @@
 
 #include <algorithm>
 
-QTEST_MAIN(TestQMakeFile);
+QTEST_MAIN(TestQMakeFile)
 
 typedef QHash<QString, QString> DefineHash;
 
@@ -232,9 +232,9 @@ void TestQMakeFile::defines()
 
     QVERIFY(file.read());
 
-    QList<QMakeProjectFile::DefinePair> list = file.defines();
+    const QList<QMakeProjectFile::DefinePair> list = file.defines();
     QCOMPARE(list.size(), expectedDefines.size());
-    foreach (QMakeProjectFile::DefinePair define, list) {
+    for (const QMakeProjectFile::DefinePair& define : list) {
         QVERIFY(expectedDefines.find(define.first) != expectedDefines.end());
         QCOMPARE(define.second, expectedDefines[define.first]);
     }
@@ -246,7 +246,7 @@ void TestQMakeFile::defines_data()
     QTest::addColumn<DefineHash>("expectedDefines");
     {
         DefineHash list;
-        list.insert(QStringLiteral("VAR1"), QLatin1String(""));
+        list.insert(QStringLiteral("VAR1"), QString());
         QTest::newRow("Simple define") << "DEFINES += VAR1" << list;
     }
     {
@@ -257,7 +257,7 @@ void TestQMakeFile::defines_data()
     {
         DefineHash list;
         list.insert(QStringLiteral("ANSWER"), QStringLiteral("42"));
-        list.insert(QStringLiteral("ANOTHER_DEFINE"), QLatin1String(""));
+        list.insert(QStringLiteral("ANOTHER_DEFINE"), QString());
         QTest::newRow("Multiple defines") << "DEFINES += ANSWER=42 ANOTHER_DEFINE" << list;
     }
 }
