@@ -53,10 +53,11 @@ DeclarationBuilder::DeclarationBuilder(ParseSession* session)
 
 ReferencedTopDUContext DeclarationBuilder::build(const IndexedString& url,
                                                  QmlJS::AST::Node* node,
-                                                 ReferencedTopDUContext updateContext)
+                                                 const ReferencedTopDUContext& updateContext_)
 {
     Q_ASSERT(m_session->url() == url);
 
+    ReferencedTopDUContext updateContext(updateContext_);
     // The declaration builder needs to run twice, so it can resolve uses of e.g. functions
     // which are called before they are defined (which is easily possible, due to JS's dynamic nature).
     if (!m_prebuilding) {
@@ -698,7 +699,7 @@ void DeclarationBuilder::declareComponent(QmlJS::AST::UiObjectInitializer* node,
                                           const RangeInRevision &range,
                                           const Identifier &name)
 {
-    QString baseClass = QmlJS::getQMLAttributeValue(node->members, QStringLiteral("prototype")).value.section('/', -1, -1);
+    QString baseClass = QmlJS::getQMLAttributeValue(node->members, QStringLiteral("prototype")).value.section(QLatin1Char('/'), -1, -1);
 
     // Declare the component itself
     StructureType::Ptr type(new StructureType);
@@ -712,7 +713,7 @@ void DeclarationBuilder::declareComponent(QmlJS::AST::UiObjectInitializer* node,
         decl->setClassType(ClassDeclarationData::Interface);
         decl->clearBaseClasses();
 
-        if (!baseClass.isNull()) {
+        if (!baseClass.isEmpty()) {
             addBaseClass(decl, baseClass);
         }
 
@@ -731,7 +732,7 @@ void DeclarationBuilder::declareMethod(QmlJS::AST::UiObjectInitializer* node,
     QString type_name = QmlJS::getQMLAttributeValue(node->members, QStringLiteral("type")).value;
     QmlJS::FunctionType::Ptr type(new QmlJS::FunctionType);
 
-    if (type_name.isNull()) {
+    if (type_name.isEmpty()) {
         type->setReturnType(typeFromName(QStringLiteral("void")));
     } else {
         type->setReturnType(typeFromName(type_name));
@@ -804,7 +805,7 @@ void DeclarationBuilder::declareComponentSubclass(QmlJS::AST::UiObjectInitialize
                                                   QmlJS::AST::UiQualifiedId* qualifiedId)
 {
     Identifier name(
-        QmlJS::getQMLAttributeValue(node->members, QStringLiteral("name")).value.section('/', -1, -1)
+        QmlJS::getQMLAttributeValue(node->members, QStringLiteral("name")).value.section(QLatin1Char('/'), -1, -1)
     );
     DUContext::ContextType contextType = DUContext::Class;
 
@@ -940,9 +941,8 @@ DeclarationBuilder::ExportLiteralsAndNames DeclarationBuilder::exportedNames(Qml
         }
 
         // String literal like "Namespace/Class version".
-        QStringList nameAndVersion = stringliteral->value.toString().section('/', -1, -1).split(' ');
+        QStringList nameAndVersion = stringliteral->value.toString().section(QLatin1Char('/'), -1, -1).split(QLatin1Char(' '));
         QString name = nameAndVersion.at(0);
-        QString version = (nameAndVersion.count() > 1 ? nameAndVersion.at(1) : QStringLiteral("1.0"));
 
         if (!knownNames.contains(name)) {
             knownNames.insert(name);
@@ -960,7 +960,7 @@ void DeclarationBuilder::declareExports(const ExportLiteralsAndNames& exports,
     DUChainWriteLocker lock;
 
     // Create the exported versions of the component
-    for (auto exp : exports) {
+    for (auto& exp : exports) {
         QmlJS::AST::StringLiteral* literal = exp.first;
         QString name = exp.second;
         StructureType::Ptr type(new StructureType);
@@ -1007,10 +1007,10 @@ void DeclarationBuilder::importDirectory(const QString& directory, QmlJS::AST::U
     if (dir.isDir()) {
         // Import all the files in the given directory
         entries = QDir(directory).entryInfoList(
-            QStringList()
-                << (QLatin1String("*.") + currentFilePath.section(QLatin1Char('.'), -1, -1))
-                << QStringLiteral("*.qmltypes")
-                << QStringLiteral("*.so"),
+            QStringList{
+                (QLatin1String("*.") + currentFilePath.section(QLatin1Char('.'), -1, -1)),
+                QStringLiteral("*.qmltypes"),
+                QStringLiteral("*.so")},
             QDir::Files
         );
     } else if (dir.isFile()) {
@@ -1063,7 +1063,7 @@ void DeclarationBuilder::importModule(QmlJS::AST::UiImport* node)
 
     while (part) {
         if (!uri.isEmpty()) {
-            uri.append('.');
+            uri.append(QLatin1Char('.'));
         }
 
         uri.append(part->name.toString());
@@ -1082,7 +1082,7 @@ bool DeclarationBuilder::visit(QmlJS::AST::UiImport* node)
 {
     if (node->importUri) {
         importModule(node);
-    } else if (!node->fileName.isNull() && node->fileName != QLatin1String(".")) {
+    } else if (!node->fileName.isEmpty() && node->fileName != QLatin1String(".")) {
         QUrl currentFileUrl = currentContext()->topContext()->url().toUrl();
         QUrl importUrl = QUrl(node->fileName.toString());
 
