@@ -35,7 +35,7 @@ class QtHelpProviderAbstract : public QObject, public KDevelop::IDocumentationPr
     Q_INTERFACES( KDevelop::IDocumentationProvider )
 public:
     QtHelpProviderAbstract(QObject *parent, const QString &collectionFileName, const QVariantList & args);
-    virtual ~QtHelpProviderAbstract();
+    ~QtHelpProviderAbstract() override;
     KDevelop::IDocumentation::Ptr documentationForDeclaration (KDevelop::Declaration*) const override;
 
     KDevelop::IDocumentation::Ptr documentationForIndex(const QModelIndex& idx) const override;
@@ -50,9 +50,7 @@ public:
 
     HelpNetworkAccessManager* networkAccess() const;
 public Q_SLOTS:
-    void jumpedTo(const QUrl& newUrl) const;
-Q_SIGNALS:
-    void addHistory(const KDevelop::IDocumentation::Ptr& doc) const override;
+    void jumpedTo(const QUrl& newUrl);
 protected:
     QHelpEngine m_engine;
     HelpNetworkAccessManager* const m_nam;
