@@ -36,7 +36,6 @@ class ProjectFileItem;
 struct ProjectFile
 {
     ProjectFile()
-        : outsideOfProject(false)
     {}
     KDevelop::Path path;
     // project root folder url
@@ -46,7 +45,7 @@ struct ProjectFile
     KDevelop::IndexedString indexedPath;
     // true for files which reside outside of the project root
     // this happens e.g. for generated files in out-of-source build folders
-    bool outsideOfProject;
+    bool outsideOfProject = false;
 };
 
 inline bool operator<(const ProjectFile& left, const ProjectFile& right)
@@ -104,6 +103,11 @@ public:
     {
         return data.path;
     }
+
+    inline KDevelop::Path itemPrefixPath(const ProjectFile& data) const
+    {
+        return data.projectPath;
+    }
 };
 
 /**
@@ -128,7 +132,7 @@ private:
     // project files sorted by their url
     // this is done so we can limit ourselves to a relatively fast
     // filtering without any expensive sorting in reset().
-    QList<ProjectFile> m_projectFiles;
+    QVector<ProjectFile> m_projectFiles;
 };
 
 /**
