@@ -22,7 +22,7 @@
 #include <QTreeView>
 #include <QTimer>
 
-#include <ktexteditor/codecompletionmodel.h>
+#include <KTextEditor/CodeCompletionModel>
 #include <typeinfo>
 
 #include "expandingtree/expandingtree.h"
@@ -40,6 +40,7 @@ QuickOpenModel::QuickOpenModel(QWidget* parent) : ExpandingWidgetModel(parent)
 {
     m_resetTimer = new QTimer(this);
     m_resetTimer->setSingleShot(true);
+    m_resetTimer->setInterval(0);
     connect(m_resetTimer, &QTimer::timeout, this, &QuickOpenModel::resetTimer);
 }
 
@@ -51,7 +52,7 @@ void QuickOpenModel::setExpandingWidgetHeightIncrease(int pixels)
 QStringList QuickOpenModel::allScopes() const
 {
     QStringList scopes;
-    foreach (const ProviderEntry& provider, m_providers) {
+    for (const ProviderEntry& provider : m_providers) {
         foreach (const QString& scope, provider.scopes) {
             if (!scopes.contains(scope)) {
                 scopes << scope;
@@ -65,7 +66,7 @@ QStringList QuickOpenModel::allScopes() const
 QStringList QuickOpenModel::allTypes() const
 {
     QSet<QString> types;
-    foreach (const ProviderEntry& provider, m_providers) {
+    for (const ProviderEntry& provider : m_providers) {
         types += provider.types;
     }
 
@@ -261,7 +262,7 @@ int QuickOpenModel::rowCount(const QModelIndex& i) const
     }
 
     int count = 0;
-    foreach (const ProviderEntry& provider, m_providers) {
+    for (const ProviderEntry& provider : m_providers) {
         if (provider.enabled) {
             count += provider.provider->itemCount();
         }
@@ -273,7 +274,7 @@ int QuickOpenModel::rowCount(const QModelIndex& i) const
 int QuickOpenModel::unfilteredRowCount() const
 {
     int count = 0;
-    foreach (const ProviderEntry& provider, m_providers) {
+    for (const ProviderEntry& provider : m_providers) {
         if (provider.enabled) {
             count += provider.provider->unfilteredItemCount();
         }
@@ -404,7 +405,7 @@ QuickOpenDataPointer QuickOpenModel::getItem(int row, bool noReset) const
 
     Q_ASSERT(row < rowCount(QModelIndex()));
 
-    foreach (const ProviderEntry& provider, m_providers) {
+    for (const ProviderEntry& provider : m_providers) {
         if (!provider.enabled) {
             continue;
         }
@@ -414,7 +415,7 @@ QuickOpenDataPointer QuickOpenModel::getItem(int row, bool noReset) const
 
             if (!noReset && provider.provider->itemCount() != itemCount) {
                 qCDebug(PLUGIN_QUICKOPEN) << "item-count in provider has changed, resetting model";
-                m_resetTimer->start(0);
+                m_resetTimer->start();
                 m_resetBehindRow = rowOffset + row; //Don't reset everything, only everything behind this position
             }
 
@@ -436,7 +437,7 @@ QuickOpenDataPointer QuickOpenModel::getItem(int row, bool noReset) const
 QSet<IndexedString> QuickOpenModel::fileSet() const
 {
     QSet<IndexedString> merged;
-    foreach (const ProviderEntry& provider, m_providers) {
+    for (const ProviderEntry& provider : m_providers) {
         if (m_enabledScopes.isEmpty() || !(m_enabledScopes & provider.scopes).isEmpty()) {
             if (QuickOpenFileSetInterface* iface = dynamic_cast<QuickOpenFileSetInterface*>(provider.provider)) {
                 QSet<IndexedString> ifiles = iface->files();
