@@ -25,10 +25,14 @@
 #include <QTest>
 #include <QTemporaryFile>
 
-QTEST_MAIN(TestQuickOpen);
+QTEST_MAIN(TestQuickOpen)
 
 using namespace KDevelop;
 
+using ItemList = QVector<DUChainItem>;
+using StringList = QVector<QString>;
+
+
 TestQuickOpen::TestQuickOpen(QObject* parent)
     : QuickOpenTestBase(Core::Default, parent)
 {
@@ -36,8 +40,6 @@ TestQuickOpen::TestQuickOpen(QObject* parent)
 
 void TestQuickOpen::testDuchainFilter()
 {
-    using ItemList = QList<DUChainItem>;
-
     QFETCH(ItemList, items);
     QFETCH(QString, filter);
     QFETCH(ItemList, filtered);
@@ -59,8 +61,6 @@ void TestQuickOpen::testDuchainFilter()
 
 void TestQuickOpen::testDuchainFilter_data()
 {
-    using ItemList = QList<DUChainItem>;
-
     QTest::addColumn<ItemList>("items");
     QTest::addColumn<QString>("filter");
     QTest::addColumn<ItemList>("filtered");
@@ -92,63 +92,70 @@ void TestQuickOpen::testDuchainFilter_data()
 
 void TestQuickOpen::testAbbreviations()
 {
-    QFETCH(QStringList, items);
+    QFETCH(StringList, items);
     QFETCH(QString, filter);
-    QFETCH(QStringList, filtered);
+    QFETCH(StringList, filtered);
 
     PathTestFilter filterItems;
     filterItems.setItems(items);
     filterItems.setFilter(filter.split('/', QString::SkipEmptyParts));
-    QCOMPARE(QStringList(filterItems.filteredItems()), filtered);
+    QCOMPARE(filterItems.filteredItems(), filtered);
 }
 
 void TestQuickOpen::testAbbreviations_data()
 {
-    QTest::addColumn<QStringList>("items");
+    QTest::addColumn<StringList>("items");
     QTest::addColumn<QString>("filter");
-    QTest::addColumn<QStringList>("filtered");
+    QTest::addColumn<StringList>("filtered");
 
-    const QStringList items = QStringList()
-                              << QStringLiteral("/foo/bar/caz/a.h")
-                              << QStringLiteral("/KateThing/CMakeLists.txt")
-                              << QStringLiteral("/FooBar/FooBar/Footestfoo.h");
+    const StringList items = {
+        QStringLiteral("/foo/bar/caz/a.h"),
+        QStringLiteral("/KateThing/CMakeLists.txt"),
+        QStringLiteral("/FooBar/FooBar/Footestfoo.h") };
 
-    QTest::newRow("path_segments") << items << "fbc" << (QStringList());
-    QTest::newRow("path_segment_abbrev") << items << "cmli" << (QStringList() << items.at(1));
-    QTest::newRow("path_segment_old") << items << "kate/cmake" << (QStringList() << items.at(1));
-    QTest::newRow("path_segment_multi_mixed") << items << "ftfoo.h" << (QStringList() << items.at(2));
+    QTest::newRow("path_segments") << items << "fbc" << StringList();
+    QTest::newRow("path_segment_abbrev") << items << "cmli" << StringList({ items.at(1) });
+    QTest::newRow("path_segment_old") << items << "kate/cmake" << StringList({ items.at(1) });
+    QTest::newRow("path_segment_multi_mixed") << items << "ftfoo.h" << StringList({ items.at(2) });
 }
 
 void TestQuickOpen::testSorting()
 {
-    QFETCH(QStringList, items);
+    QFETCH(StringList, items);
     QFETCH(QString, filter);
-    QFETCH(QStringList, filtered);
+    QFETCH(StringList, filtered);
 
+    const auto filterList = filter.split('/', QString::SkipEmptyParts);
     PathTestFilter filterItems;
     filterItems.setItems(items);
-    filterItems.setFilter(filter.split('/', QString::SkipEmptyParts));
-    QEXPECT_FAIL("bar7", "empty parts are skipped", Continue);
-    QCOMPARE(QStringList(filterItems.filteredItems()), filtered);
+    filterItems.setFilter(filterList);
+    QEXPECT_FAIL("bar7", "empty parts are skipped", Abort);
+    if (filterItems.filteredItems() != filtered)
+        qWarning() << filterItems.filteredItems() << filtered;
+    QCOMPARE(filterItems.filteredItems(), filtered);
+
+    // check whether sorting is stable
+    filterItems.setFilter(filterList);
+    QCOMPARE(filterItems.filteredItems(), filtered);
 }
 
 void TestQuickOpen::testSorting_data()
 {
-    QTest::addColumn<QStringList>("items");
+    QTest::addColumn<StringList>("items");
     QTest::addColumn<QString>("filter");
-    QTest::addColumn<QStringList>("filtered");
+    QTest::addColumn<StringList>("filtered");
 
-    const QStringList items = QStringList()
-                              << QStringLiteral("/foo/a.h")
-                              << QStringLiteral("/foo/ab.h")
-                              << QStringLiteral("/foo/bc.h")
-                              << QStringLiteral("/bar/a.h");
+    const StringList items({
+        QStringLiteral("/foo/a.h"),
+        QStringLiteral("/foo/ab.h"),
+        QStringLiteral("/foo/bc.h"),
+        QStringLiteral("/bar/a.h")});
 
     {
         QTest::newRow("no-filter") << items << QString() << items;
     }
     {
-        const QStringList filtered = QStringList() << QStringLiteral("/bar/a.h");
+        const StringList filtered = { QStringLiteral("/bar/a.h") };
         QTest::newRow("bar1") << items << QStringLiteral("bar") << filtered;
         QTest::newRow("bar2") << items << QStringLiteral("/bar") << filtered;
         QTest::newRow("bar3") << items << QStringLiteral("/bar/") << filtered;
@@ -161,38 +168,38 @@ void TestQuickOpen::testSorting_data()
         QTest::newRow("bar10") << items << QStringLiteral("b/a.") << filtered;
     }
     {
-        const QStringList filtered = QStringList() << QStringLiteral("/foo/a.h") << QStringLiteral("/foo/ab.h");
+        const StringList filtered = { QStringLiteral("/foo/a.h"), QStringLiteral("/foo/ab.h") };
         QTest::newRow("foo_a1") << items << QStringLiteral("foo/a") << filtered;
         QTest::newRow("foo_a2") << items << QStringLiteral("/f/a") << filtered;
     }
     {
         // now matches ab.h too because of abbreviation matching, but should be sorted last
-        const QStringList filtered = QStringList() << QStringLiteral("/foo/a.h") << QStringLiteral("/bar/a.h") << QStringLiteral("/foo/ab.h");
+        const StringList filtered = { QStringLiteral("/foo/a.h"), QStringLiteral("/bar/a.h"), QStringLiteral("/foo/ab.h") };
         QTest::newRow("a_h") << items << QStringLiteral("a.h") << filtered;
     }
     {
-        const QStringList base = QStringList() << QStringLiteral("/foo/a_test") << QStringLiteral("/foo/test_b_1") << QStringLiteral("/foo/test_b");
-        const QStringList sorted = QStringList() << QStringLiteral("/foo/test_b") << QStringLiteral("/foo/test_b_1");
+        const StringList base = { QStringLiteral("/foo/a_test"), QStringLiteral("/foo/test_b_1"), QStringLiteral("/foo/test_b") };
+        const StringList sorted = { QStringLiteral("/foo/test_b"), QStringLiteral("/foo/test_b_1") };
         QTest::newRow("prefer_exact") << base << QStringLiteral("test_b") << sorted;
     }
     {
         // from commit: 769491f06a4560a4798592ff060675ffb0d990a6
         const QString file = QStringLiteral("/myProject/someStrangePath/anItem.cpp");
-        const QStringList base = QStringList() << QStringLiteral("/foo/a") << file;
-        const QStringList filtered = QStringList() << file;
+        const StringList base = { QStringLiteral("/foo/a"), file };
+        const StringList filtered = { file };
         QTest::newRow("strange") << base << QStringLiteral("strange/item") << filtered;
     }
     {
-        const QStringList base = QStringList() << QStringLiteral("/foo/a_test") << QStringLiteral("/foo/test_b_1")
-                                               << QStringLiteral("/foo/test_b") << QStringLiteral("/foo/test/a");
-        const QStringList sorted = QStringList() << QStringLiteral("/foo/test_b_1") << QStringLiteral("/foo/test_b")
-                                                 << QStringLiteral("/foo/a_test") << QStringLiteral("/foo/test/a");
+        const StringList base = { QStringLiteral("/foo/a_test"), QStringLiteral("/foo/test_b_1"),
+                                    QStringLiteral("/foo/test_b"), QStringLiteral("/foo/test/a") };
+        const StringList sorted = { QStringLiteral("/foo/test_b_1"), QStringLiteral("/foo/test_b"),
+                                      QStringLiteral("/foo/a_test"), QStringLiteral("/foo/test/a") };
         QTest::newRow("prefer_start1") << base << QStringLiteral("test") << sorted;
         QTest::newRow("prefer_start2") << base << QStringLiteral("foo/test") << sorted;
     }
     {
-        const QStringList base = QStringList() << QStringLiteral("/muh/kuh/asdf/foo") << QStringLiteral("/muh/kuh/foo/asdf");
-        const QStringList reverse = QStringList() << QStringLiteral("/muh/kuh/foo/asdf") << QStringLiteral("/muh/kuh/asdf/foo");
+        const StringList base = { QStringLiteral("/muh/kuh/asdf/foo"), QStringLiteral("/muh/kuh/foo/asdf") };
+        const StringList reverse = { QStringLiteral("/muh/kuh/foo/asdf"), QStringLiteral("/muh/kuh/asdf/foo") };
         QTest::newRow("prefer_start3") << base << QStringLiteral("f") << base;
         QTest::newRow("prefer_start4") << base << QStringLiteral("/fo") << base;
         QTest::newRow("prefer_start5") << base << QStringLiteral("/foo") << base;
@@ -202,7 +209,94 @@ void TestQuickOpen::testSorting_data()
         QTest::newRow("prefer_start9") << base << QStringLiteral("asdf") << reverse;
     }
     {
-        QTest::newRow("duplicate") << (QStringList() << QStringLiteral("/muh/kuh/asdf/foo")) << QStringLiteral("kuh/kuh") << QStringList();
+        QTest::newRow("duplicate") << StringList({ QStringLiteral("/muh/kuh/asdf/foo") }) << QStringLiteral("kuh/kuh") << StringList();
+    }
+    {
+        const StringList fuzzyItems = {
+            QStringLiteral("/foo/bar.h"),
+            QStringLiteral("/foo/fooXbar.h"),
+            QStringLiteral("/foo/fXoXoXbXaXr.h"),
+            QStringLiteral("/bar/FOOxBAR.h")
+        };
+
+        QTest::newRow("fuzzy1") << fuzzyItems << QStringLiteral("br") << fuzzyItems;
+        QTest::newRow("fuzzy2") << fuzzyItems << QStringLiteral("foo/br") << StringList({
+            QStringLiteral("/foo/bar.h"),
+            QStringLiteral("/foo/fooXbar.h"),
+            QStringLiteral("/foo/fXoXoXbXaXr.h")
+        });
+        QTest::newRow("fuzzy3") << fuzzyItems << QStringLiteral("b/br") << StringList({
+            QStringLiteral("/bar/FOOxBAR.h")
+        });
+        QTest::newRow("fuzzy4") << fuzzyItems << QStringLiteral("br/br") << StringList();
+        QTest::newRow("fuzzy5") << fuzzyItems << QStringLiteral("foo/bar") << StringList({
+            QStringLiteral("/foo/bar.h"),
+            QStringLiteral("/foo/fooXbar.h"),
+            QStringLiteral("/foo/fXoXoXbXaXr.h")
+        });
+        QTest::newRow("fuzzy6") << fuzzyItems << QStringLiteral("foobar") << StringList({
+            QStringLiteral("/foo/fooXbar.h"),
+            QStringLiteral("/foo/fXoXoXbXaXr.h"),
+            QStringLiteral("/bar/FOOxBAR.h")
+        });
+    }
+    {
+        const StringList a = {
+            QStringLiteral("/home/user/src/code/user/something"),
+            QStringLiteral("/home/user/src/code/home/else"),
+        };
+        const StringList b = {
+            QStringLiteral("/home/user/src/code/home/else"),
+            QStringLiteral("/home/user/src/code/user/something"),
+        };
+        QTest::newRow("prefer_multimatch_a_home") << a << QStringLiteral("home") << b;
+        QTest::newRow("prefer_multimatch_b_home") << b << QStringLiteral("home") << b;
+        QTest::newRow("prefer_multimatch_a_user") << a << QStringLiteral("user") << a;
+        QTest::newRow("prefer_multimatch_b_user") << b << QStringLiteral("user") << a;
+    }
+    {
+        const StringList a = {
+            QStringLiteral("/home/user/project/A/file"),
+            QStringLiteral("/home/user/project/B/project/A/file"),
+            QStringLiteral("/home/user/project/user/C/D/E"),
+        };
+        const StringList b = {
+            QStringLiteral("/home/user/project/B/project/A/file"),
+            QStringLiteral("/home/user/project/A/file"),
+        };
+        const StringList c = {
+            QStringLiteral("/home/user/project/user/C/D/E"),
+            QStringLiteral("/home/user/project/A/file"),
+            QStringLiteral("/home/user/project/B/project/A/file"),
+        };
+        QTest::newRow("prefer_multimatch_a_project/file") << a << QStringLiteral("project/file") << b;
+        QTest::newRow("prefer_multimatch_b_project/file") << b << QStringLiteral("project/file") << b;
+        QTest::newRow("prefer_multimatch_a_project/le") << a << QStringLiteral("project/le") << b;
+        QTest::newRow("prefer_multimatch_b_project/le") << b << QStringLiteral("project/le") << b;
+        QTest::newRow("prefer_multimatch_a_project/a/file") << a << QStringLiteral("project/a/file") << b;
+        QTest::newRow("prefer_multimatch_b_project/a/file") << b << QStringLiteral("project/a/file") << b;
+        QTest::newRow("prefer_multimatch_a_project_user") << a << QStringLiteral("user") << c;
+        QTest::newRow("prefer_multimatch_c_project_user") << c << QStringLiteral("user") << c;
+    }
+}
+
+void TestQuickOpen::testStableSort()
+{
+    const StringList items = {
+        QStringLiteral("a/c/CMakeLists.txt"),
+        QStringLiteral("a/d/CMakeLists.txt"),
+        QStringLiteral("b/e/CMakeLists.txt"),
+        QStringLiteral("b/f/CMakeLists.txt")
+    };
+    PathTestFilter filterItems;
+    filterItems.setItems(items);
+
+    QStringList filter = {QString()};
+    const auto cmakeListsString = QStringLiteral("CMakeLists.txt");
+    for (auto c : cmakeListsString) {
+        filter[0].append(c);
+        filterItems.setFilter(filter);
+        QCOMPARE(filterItems.filteredItems(), items);
     }
 }
 
