@@ -44,6 +44,7 @@
 
 #include <outputview/ioutputviewmodel.h>
 #include <util/focusedtreeview.h>
+#include <util/expandablelineedit.h>
 
 #include "outputmodel.h"
 #include "toolviewdata.h"
@@ -101,9 +102,6 @@ OutputWidget::OutputWidget(QWidget* parent, const ToolViewData* tvdata)
         addAction(m_nextAction);
     }
 
-    addAction(dynamic_cast<QAction*>(data->plugin->actionCollection()->action(QStringLiteral("prev_error"))));
-    addAction(dynamic_cast<QAction*>(data->plugin->actionCollection()->action(QStringLiteral("next_error"))));
-
     m_activateOnSelect = new KToggleAction( QIcon(), i18n("Select activated Item"), this );
     m_activateOnSelect->setChecked( true );
     m_focusOnSelect = new KToggleAction( QIcon(), i18n("Focus when selecting Item"), this );
@@ -155,9 +153,7 @@ OutputWidget::OutputWidget(QWidget* parent, const ToolViewData* tvdata)
         separator->setSeparator(true);
         addAction(separator);
 
-        m_filterInput = new QLineEdit();
-        m_filterInput->setMaximumWidth(150);
-        m_filterInput->setMinimumWidth(100);
+        m_filterInput = new KExpandableLineEdit(this);
         m_filterInput->setPlaceholderText(i18n("Search..."));
         m_filterInput->setClearButtonEnabled(true);
         m_filterInput->setToolTip(i18n("Enter a wild card string to filter the output view"));
@@ -615,13 +611,13 @@ void OutputWidget::copySelection()
         return;
 
     QClipboard *cb = QApplication::clipboard();
-    QModelIndexList indexes = view->selectionModel()->selectedRows();
-    QString content;
-    Q_FOREACH( const QModelIndex& index, indexes) {
-      content += index.data().toString() + '\n';
+    const QModelIndexList indexes = view->selectionModel()->selectedRows();
+    QStringList content;
+    content.reserve(indexes.size());
+    for (const QModelIndex& index : indexes) {
+        content += index.data().toString();
     }
-    content.chop(1);
-    cb->setText(content);
+    cb->setText(content.join(QLatin1Char('\n')));
 }
 
 void OutputWidget::selectAll()
