@@ -37,14 +37,13 @@
 #include "iruncontroller.h"
 
 #include "svnclient.h"
-#include "svncatjob.h"
 
 ///@todo The subversion library returns borked diffs, where the headers are at the end. This function
 ///           takes those headers, and moves them into the correct place to create a valid working diff.
 ///           Find the source of this problem.
 QString repairDiff(const QString& diff) {
     qCDebug(PLUGIN_SVN) << "diff before repair:" << diff;
-    QStringList lines = diff.split('\n');
+    QStringList lines = diff.split(QLatin1Char('\n'));
     QMap<QString, QString> headers;
     for(int a = 0; a < lines.size()-1; ++a) {
         if(lines[a].startsWith(QLatin1String("Index: ")) && lines[a+1].startsWith(QLatin1String("====="))) {
@@ -53,13 +52,13 @@ QString repairDiff(const QString& diff) {
             qCDebug(PLUGIN_SVN) << "found header for" << fileName;
             lines[a] = QString();
             if(lines[a+1].startsWith(QLatin1String("======"))) {
-                headers[fileName] += '\n' + lines[a+1];
+                headers[fileName] += QLatin1Char('\n') + lines[a+1];
             lines[a+1] = QString();
             }
         }
     }
 
-    QRegExp spaceRegExp("\\s");
+    QRegExp spaceRegExp(QStringLiteral("\\s"));
 
     for(int a = 0; a < lines.size()-1; ++a) {
         if(lines[a].startsWith(QLatin1String("--- "))) {
@@ -69,7 +68,7 @@ QString repairDiff(const QString& diff) {
                 qCDebug(PLUGIN_SVN) << "checking for" << file;
                 if(headers.contains(file)) {
                     qCDebug(PLUGIN_SVN) << "adding header for" << file << ":" << headers[file];
-                    lines[a] = headers[file] + '\n' + lines[a];
+                    lines[a] = headers[file] + QLatin1Char('\n') + lines[a];
                 }
             }
         }
@@ -82,9 +81,7 @@ QString repairDiff(const QString& diff) {
 //@TODO: Handle raw diffs by using SvnCatJob to fetch both files/revisions
 
 SvnInternalDiffJob::SvnInternalDiffJob( SvnJobBase* parent )
-    : SvnInternalJobBase( parent ), m_recursive( true ),
-      m_ignoreAncestry( false ), m_ignoreContentType( false ),
-      m_noDiffOnDelete( false )
+    : SvnInternalJobBase( parent )
 {
     m_pegRevision.setRevisionValue( KDevelop::VcsRevision::Head,
                                     KDevelop::VcsRevision::Special );
@@ -153,7 +150,7 @@ void SvnInternalDiffJob::run(ThreadWeaver::JobPointer /*self*/, ThreadWeaver::Th
         diff = repairDiff(diff);
         emit gotDiff( diff );
 
-    }catch( svn::ClientException ce )
+    }catch( const svn::ClientException& ce )
     {
         qCDebug(PLUGIN_SVN) << "Exception while doing a diff: "
                 << m_source.localUrl() << m_source.repositoryServer() << m_srcRevision.prettyValue()
@@ -261,7 +258,7 @@ SvnDiffJob::SvnDiffJob( KDevSvnPlugin* parent )
     : SvnJobBaseImpl( parent, KDevelop::OutputJob::Silent )
 {
     setType( KDevelop::VcsJob::Add );
-    connect( m_job, &SvnInternalDiffJob::gotDiff,
+    connect( m_job.data(), &SvnInternalDiffJob::gotDiff,
                 this, &SvnDiffJob::setDiff, Qt::QueuedConnection );
 
     setObjectName(i18n("Subversion Diff"));
@@ -338,103 +335,7 @@ void SvnDiffJob::setDiff( const QString& diff )
 {
     m_diff = KDevelop::VcsDiff();
     m_diff.setBaseDiff(QUrl::fromLocalFile(QStringLiteral("/")));
-    m_diff.setType( KDevelop::VcsDiff::DiffUnified );
-
-    m_diff.setContentType( KDevelop::VcsDiff::Text );
     m_diff.setDiff( diff );
 
-    QRegExp fileRe("(?:^|\n)Index: ([^\n]+)\n");
-
-    QStringList paths;
-    int pos = 0;
-
-    while( ( pos = fileRe.indexIn( diff, pos ) ) != -1 )
-    {
-        paths << fileRe.cap(1);
-        pos += fileRe.matchedLength();
-    }
-
-    if (paths.isEmpty()) {
-        internalJobDone();
-        emit resultsReady( this );
-        return;
-    }
-
-    foreach( const QString &s, paths )
-    {
-        if( !s.isEmpty() )
-        {
-            SvnCatJob* job = new SvnCatJob( m_part );
-            KDevelop::VcsLocation l = m_job->source();
-            if( l.type() == KDevelop::VcsLocation::LocalLocation )
-            {
-                l.setLocalUrl( QUrl::fromLocalFile( s ) );
-            }else
-            {
-                QString repoLocation = QUrl( l.repositoryServer() ).toString( QUrl::PreferLocalFile | QUrl::StripTrailingSlash );
-                QFileInfo fi( repoLocation );
-                if( s == fi.fileName() )
-                {
-                    l.setRepositoryServer( l.repositoryServer() );
-                }else
-                {
-                    l.setRepositoryServer( l.repositoryServer() + '/' + s );
-                }
-            }
-
-            job->setSource( l );
-            job->setPegRevision( m_job->pegRevision() );
-            job->setSrcRevision( m_job->srcRevision() );
-
-            m_catJobMap[job] = l;
-
-            connect( job, &KDevelop::VcsJob::resultsReady, this, &SvnDiffJob::addLeftText );
-            connect( job, &KJob::result, this, &SvnDiffJob::removeJob );
-
-            KDevelop::ICore::self()->runController()->registerJob(job);
-        }
-    }
-}
-
-void SvnDiffJob::addLeftText( KDevelop::VcsJob* job )
-{
-    if( m_catJobMap.contains( job ) )
-    {
-        QVariant v = job->fetchResults();
-        m_diff.addLeftText( m_catJobMap[job], v.toString() );
-        m_catJobMap.remove(job);
-        // KJobs delete themselves when finished
-    }
-    if( m_catJobMap.isEmpty() )
-    {
-        internalJobDone();
-        emit resultsReady( this );
-    }
-}
-
-void SvnDiffJob::removeJob( KJob* job )
-{
-    if( job->error() != 0 )
-    {
-        KDevelop::VcsJob* j = dynamic_cast<KDevelop::VcsJob*>( job );
-        if( j )
-        {
-            if( m_catJobMap.contains( j ) )
-            {
-                m_catJobMap.remove(j);
-                // KJobs delete themselves when finished
-            }
-        }
-    }
-
-    if( m_catJobMap.isEmpty() )
-    {
-        internalJobDone();
-        emit resultsReady( this );
-    }
-}
-
-void SvnDiffJob::setDiffType( KDevelop::VcsDiff::Type type )
-{
-    m_diffType = type;
+    emit resultsReady( this );
 }
